/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.application.impl.admin;

import java.util.Date;

import javax.persistence.DiscriminatorValue;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.application.impl.common.UserSession;

/**
 * The Class LanguageAgencyActionEvent.
 */
@Entity
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
@DiscriminatorValue("LanguageAgencyActionEvent")
public class LanguageAgencyActionEvent extends AbstractAgencyActionEvent {

    /**
     * The Enum Operation.
     */
    public enum Operation {

        /** The Add language content. */
		AddLanguageContent,

        /** The Delete. */
        Delete,

/** The Update. */
Update

    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The language id. */
    private Long languageId;

    /** The operation. */
    private Operation operation;

    /**
     * Instantiates a new language agency action event.
     */
    public LanguageAgencyActionEvent() {
    }

    /**
     * Instantiates a new language agency action event.
     *
     * @param createdDate the created date
     * @param userSession the user session
     * @param agencyId the agency id
     * @param languageId the language id
     * @param operation the operation
     */
    public LanguageAgencyActionEvent(final Date createdDate,
            final UserSession userSession, final Long agencyId,
            final Long languageId, Operation operation) {
        super(createdDate, userSession, agencyId);
        this.languageId = languageId;
        this.operation = operation;
    }

    /**
     * Gets the language id.
     *
     * @return the language id
     */
    public Long getLanguageId() {
        return languageId;
    }

    /**
     * Gets the operation.
     *
     * @return the operation
     */
    @Enumerated(EnumType.STRING)
    public Operation getOperation() {
        return operation;
    }

    /**
     * Sets the language id.
     *
     * @param languageId the new language id
     */
    public void setLanguageId(Long languageId) {
        this.languageId = languageId;
    }

    /**
     * Sets the operation.
     *
     * @param operation the new operation
     */
    public void setOperation(Operation operation) {
        this.operation = operation;
    }

}
