/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.application.impl.common;

import java.util.Date;

import javax.persistence.DiscriminatorColumn;
import javax.persistence.DiscriminatorType;
import javax.persistence.DiscriminatorValue;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Inheritance;
import javax.persistence.InheritanceType;
import javax.persistence.ManyToOne;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.Transient;
import javax.persistence.Version;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.core.impl.BaseEntity;

/**
 * The Class AbstractActionEvent.
 */
@Entity
@Inheritance(strategy = InheritanceType.SINGLE_TABLE)
@DiscriminatorColumn(name = "actioneventtype", discriminatorType = DiscriminatorType.STRING)
@DiscriminatorValue("AbstractActionEvent")
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public abstract class AbstractActionEvent extends BaseEntity implements
        ActionEvent {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The created date. */
    private Date createdDate;

    /** The execution time. */
    private Long executionTime;

    /** The id. */
    private Long id;
    
    /** The user session. */
    private UserSession userSession;

    /** The version. */
    private Long version=1L;

    /**
     * Instantiates a new abstract action event.
     */
    public AbstractActionEvent() {
    }

    /**
     * Instantiates a new abstract action event.
     *
     * @param createdDate the created date
     * @param userSession the user session
     */
    public AbstractActionEvent(final Date createdDate,
            final UserSession userSession) {
        this.createdDate = createdDate;
        this.userSession = userSession;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.model.application.ActionEvent#computeExutionTime()
     */
    @Transient
    public void computeExutionTime() {
        setExecutionTime(new Date().getTime() - getCreatedDate().getTime());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.model.application.ActionEvent#getCreatedDate()
     */
    @Temporal(TemporalType.TIMESTAMP)
    public Date getCreatedDate() {
        return createdDate;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.model.application.ActionEvent#getExecutionTime()
     */
    public Long getExecutionTime() {
        return executionTime;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.model.core.BaseEntity#getId()
     */
    @Override
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    public Long getId() {
        return id;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.model.application.ActionEvent#getUserSession()
     */
    @ManyToOne
    public UserSession getUserSession() {
        return userSession;
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.model.core.BaseEntity#getVersion()
     */
    @Override
    @Version
    public Long getVersion() {
        return version;
    }

    /**
     * Sets the created date.
     *
     * @param createdDate the new created date
     */
    public void setCreatedDate(Date createdDate) {
        this.createdDate = createdDate;
    }

    /**
     * Sets the execution time.
     *
     * @param executionTime the new execution time
     */
    public void setExecutionTime(Long executionTime) {
        this.executionTime = executionTime;
    }

    /**
     * Sets the id.
     *
     * @param id the new id
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * Sets the user session.
     *
     * @param userSession the new user session
     */
    public void setUserSession(UserSession userSession) {
        this.userSession = userSession;
    }

    /**
     * Sets the version.
     *
     * @param version the new version
     */
    public void setVersion(Long version) {
        this.version = version;
    }
}
