/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.application.impl.common;

import javax.persistence.DiscriminatorValue;
import javax.persistence.Entity;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.core.impl.AbstractResource;

/**
 * The Class AbstractAgencyConfiguration.
 */
@Entity
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
@DiscriminatorValue("AbstractAgencyConfiguration")
public abstract class AbstractAgencyConfiguration extends AbstractResource {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;
    
    /** The active by default. */
    private boolean activeByDefault;

    /** The name. */
    private String name;
    
    /** The usage order. */
    private int usageOrder;

    /**
     * Instantiates a new abstract agency configuration.
     */
    public AbstractAgencyConfiguration() {
        super();
        setResourceType(ResourceType.Configuration);
    }


    /**
     * Gets the active by default.
     *
     * @return the active by default
     */
	public boolean getActiveByDefault() {
		return activeByDefault;
	}


    /**
     * Gets the name.
     *
     * @return the name
     */
    public String getName() {
        return name;
    }
        
	/**
	 * Gets the usage order.
	 *
	 * @return the usage order
	 */
	public int getUsageOrder() {
		return usageOrder;
	}

	/**
	 * Sets the active by default.
	 *
	 * @param activeByDefault the new active by default
	 */
	public void setActiveByDefault(boolean activeByDefault) {
		this.activeByDefault = activeByDefault;
	}

	/**
	 * Sets the name.
	 *
	 * @param name the new name
	 */
    public void setName(String name) {
        this.name = name;
    }

	/**
	 * Sets the usage order.
	 *
	 * @param usageOrder the new usage order
	 */
	public void setUsageOrder(int usageOrder) {
		this.usageOrder = usageOrder;
	}
}
