/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.application.impl.common;

import java.util.Date;

import javax.persistence.DiscriminatorValue;
import javax.persistence.Entity;
import javax.persistence.Lob;

/**
 * The Class ApplicationErrorActionEvent.
 */
@Entity
@DiscriminatorValue("ApplicationErrorActionEvent")
public class ApplicationErrorActionEvent extends AbstractActionEvent {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The error message. */
    private String errorMessage;
    
    /** The stack trace. */
    private String stackTrace;
    
    /**
     * Instantiates a new application error action event.
     */
    public ApplicationErrorActionEvent() {
    }

    /**
     * Instantiates a new application error action event.
     *
     * @param createdDate the created date
     * @param userSession the user session
     * @param stackTrace the stack trace
     * @param errorMessage the error message
     */
    public ApplicationErrorActionEvent(final Date createdDate, final UserSession userSession, final String stackTrace,final String errorMessage) {
        super(createdDate, userSession);
        this.stackTrace = stackTrace;
        this.errorMessage = errorMessage;
    }
    
    /**
     * Gets the error message.
     *
     * @return the error message
     */
    public String getErrorMessage() {
        return errorMessage;
    }

    /**
     * Gets the stack trace.
     *
     * @return the stack trace
     */
    @Lob
    public String getStackTrace() {
        return stackTrace;
    }

    /**
     * Sets the error message.
     *
     * @param errorMessage the new error message
     */
    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    /**
     * Sets the stack trace.
     *
     * @param stackTrace the new stack trace
     */
    public void setStackTrace(String stackTrace) {
        this.stackTrace = stackTrace;
    }
}
