/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.application.impl.common;

import javax.persistence.Column;
import javax.persistence.DiscriminatorValue;
import javax.persistence.Entity;
import javax.persistence.Lob;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.core.impl.AbstractResource;

/**
 * The Class ImageContent.
 */
@Entity
@Cache(usage = CacheConcurrencyStrategy.READ_ONLY)
@DiscriminatorValue("ImageContent")
public class ImageContent extends AbstractResource {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The file name. */
    private String fileName;
    
    /** The image content. */
    private byte[] imageContent;
    
    /** The mimetype. */   
    private String mimetype;

    /**
     * Instantiates a new image content.
     */
    public ImageContent() {
        super();
        setResourceType(ResourceType.Image);
    }

	/**
	 * Gets the file name.
	 *
	 * @return the file name
	 */
	public String getFileName() {
		return fileName;
	}

	/**
	 * Gets the image content.
	 *
	 * @return the image content
	 */
    @Lob
    @Column(length=2097105200)
	public byte[] getImageContent() {
		return imageContent;
	}

	/**
	 * Gets the mimetype.
	 *
	 * @return the mimetype
	 */
	public String getMimetype() {
		return mimetype;
	}

	/**
	 * Sets the file name.
	 *
	 * @param fileName the new file name
	 */
	public void setFileName(String fileName) {
		this.fileName = fileName;
	}

	/**
	 * Sets the image content.
	 *
	 * @param imageContent the new image content
	 */
	public void setImageContent(byte[] imageContent) {
		this.imageContent = imageContent;
	}

	/**
	 * Sets the mimetype.
	 *
	 * @param mimetype the new mimetype
	 */
	public void setMimetype(String mimetype) {
		this.mimetype = mimetype;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "ImageContent [fileName=" + fileName + ", mimetype=" + mimetype
				+ "]";
	}

}
