/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.application.impl.common;

import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.ManyToOne;
import javax.persistence.Version;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.core.impl.BaseEntity;
import com.hack23.cia.model.sweden.impl.ParliamentMember;

/**
 * The Class Player.
 */
@Entity
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public class Player extends BaseEntity {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = -1381199844545595026L;

    /** The id. */
    private Long id;

    /** The shadow parliament member. */
    private ParliamentMember shadowParliamentMember;

    /** The user. */
    private User user;
    
    /** The version. */
    private Long version=1L;

    /**
     * Instantiates a new player.
     */
    public Player() {
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.model.core.BaseEntity#getId()
     */
    @Override
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    public Long getId() {
        return id;
    }


    /**
     * Gets the shadow parliament member.
     *
     * @return the shadow parliament member
     */
    @ManyToOne
	public ParliamentMember getShadowParliamentMember() {
		return shadowParliamentMember;
	}

    /**
     * Gets the user.
     *
     * @return the user
     */
    @ManyToOne
	public User getUser() {
		return user;
	}

    /* (non-Javadoc)
     * @see com.hack23.cia.model.core.BaseEntity#getVersion()
     */
    @Override
    @Version
    public Long getVersion() {
        return version;
    }

    /**
     * Sets the id.
     *
     * @param id the new id
     */
    public void setId(final Long id) {
        this.id = id;
    }

	/**
	 * Sets the shadow parliament member.
	 *
	 * @param shadowParliamentMember the new shadow parliament member
	 */
	public void setShadowParliamentMember(ParliamentMember shadowParliamentMember) {
		this.shadowParliamentMember = shadowParliamentMember;
	}

    /**
     * Sets the user.
     *
     * @param user the new user
     */
	public void setUser(User user) {
		this.user = user;
	}

	/**
	 * Sets the version.
	 *
	 * @param version the new version
	 */
    public void setVersion(Long version) {
        this.version = version;
    }
}
