/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.application.impl.common;

import gnu.trove.THashSet;

import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.DiscriminatorValue;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.JoinTable;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Transient;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

/**
 * The Class Portal.
 */
@Entity
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
@DiscriminatorValue("Portal")
public class Portal extends AbstractAgencyConfiguration {

    /**
     * The Enum LanguageContentKey.
     */
    public enum LanguageContentKey {
        
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The agency. */
    private Agency agency;

    /** The language content. */
    private Set<LanguageContent> languageContent = new THashSet<LanguageContent>();

    /** The matches url. */
    private String matchesUrl;

    /** The title description. */
    private String titleDescription;

    /**
     * Instantiates a new portal.
     */
    public Portal() {
        super();
        setResourceType(ResourceType.Configuration);
    }

    /**
     * Gets the agency.
     *
     * @return the agency
     */
    @ManyToOne
    public Agency getAgency() {
        return agency;
        /**
         * Sets the agency.
         * 
         * @param agency the new agency
         */
    }

    /**
     * Gets the language content.
     *
     * @return the language content
     */
    @OneToMany(cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    @JoinTable(name = "PortalLanguageContent")
    public Set<LanguageContent> getLanguageContent() {
        return languageContent;
    }

    /**
     * Gets the language content by language.
     *
     * @param language the language
     * @return the language content by language
     */
    @Transient
    public Set<LanguageContent> getLanguageContentByLanguage(Language language) {
        Set<LanguageContent> languageSpecificContent= new THashSet<LanguageContent>();
        
        for (LanguageContent languageContent :getLanguageContent()) {
            if (language.getId().equals(languageContent.getLanguage().getId())) {
                languageSpecificContent.add(languageContent);
            }
            
        }
        return languageSpecificContent;
    }

    /**
     * Gets the matches url.
     *
     * @return the matches url
     */
    public String getMatchesUrl() {
        return matchesUrl;
    }

    /**
     * Gets the title description.
     *
     * @return the title description
     */
    public String getTitleDescription() {
        return titleDescription;
    }

    /**
     * Sets the agency.
     *
     * @param agency the new agency
     */
    public void setAgency(Agency agency) {
        this.agency = agency;
    }

    /**
     * Sets the language content.
     *
     * @param languageContent the new language content
     */
    public void setLanguageContent(Set<LanguageContent> languageContent) {
        this.languageContent = languageContent;
    }

    /**
     * Sets the matches url.
     *
     * @param matchesUrl the new matches url
     */
    public void setMatchesUrl(String matchesUrl) {
        this.matchesUrl = matchesUrl;
    }

    
    /**
     * Sets the title description.
     *
     * @param titleDescription the new title description
     */
    public void setTitleDescription(String titleDescription) {
        this.titleDescription = titleDescription;
    }    
}
