/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.model.application.impl.common;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.Version;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.core.impl.BaseEntity;

/**
 * The Class UserSession.
 */
@Entity
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public class UserSession extends BaseEntity {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = -2831588433419103923L;

    /** The active. */
    private boolean active;

    /** The client host. */
    private String clientHost;

    /** The created at. */
    private Date createdAt;

    /** The ended at. */
    private Date endedAt;

    /** The events. */
    private List<AbstractActionEvent> events = new ArrayList<AbstractActionEvent>();

    /** The id. */
    private Long id;

    /** The language. */
    private Language language;

    /** The portal. */
    private Portal portal;

    /** The server host. */
    private String serverHost;

    /** The session id. */
    private String sessionId;

    /** The user. */
    private User user;

    /** The user agent. */
    private String userAgent;

    /** The version. */
    private Long version=1L;

    /**
     * Instantiates a new user session.
     */
    public UserSession() {
    }

    /**
     * Instantiates a new user session.
     *
     * @param user the user
     * @param language the language
     * @param portal the portal
     * @param sessionId the session id
     * @param clientHost the client host
     * @param serverHost the server host
     * @param createdAt the created at
     * @param userAgent the user agent
     */
    public UserSession(User user, Language language, Portal portal, String sessionId, String clientHost,String serverHost, Date createdAt, String userAgent) {
        this.user = user;
        this.language = language;
        this.portal = portal;
        this.sessionId = sessionId;
        this.clientHost = clientHost;
        this.serverHost = serverHost;
        this.createdAt = createdAt;
        this.userAgent = userAgent;
        this.active = true;
        this.endedAt = null;
    }

    /**
     * Gets the active.
     *
     * @return the active
     */
    public boolean getActive() {
        return active;
    }

    /**
     * Gets the client host.
     *
     * @return the client host
     */
    public String getClientHost() {
        return clientHost;
    }

    /**
     * Gets the created at.
     *
     * @return the created at
     */
    @Temporal(TemporalType.DATE)
    public Date getCreatedAt() {
        return createdAt;
    }

    /**
     * Gets the ended at.
     *
     * @return the ended at
     */
    @Temporal(TemporalType.DATE)
    public Date getEndedAt() {
        return endedAt;
    }

    /**
     * Gets the events.
     *
     * @return the events
     */
    @OneToMany(mappedBy = "userSession", cascade = CascadeType.ALL, fetch = FetchType.LAZY)
    @Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
    public List<AbstractActionEvent> getEvents() {
        return events;
    }

    /**

    /*
     * (non-Javadoc)
     * 
     * @see org.directdemocracyportal.democracy.model.core.BaseEntity#getId()
     */
    @Override
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    public Long getId() {
        return this.id;
    }

    /**
     * Gets the language.
     *
     * @return the language
     */
    @ManyToOne
    public Language getLanguage() {
        return language;
    }

    /**
     * Gets the portal.
     *
     * @return the portal
     */
    @ManyToOne
    public Portal getPortal() {
        return portal;
    }

    /**
     * Gets the server host.
     *
     * @return the server host
     */
    public String getServerHost() {
        return serverHost;
    }

    /**
     * Gets the session id.
     *
     * @return the session id
     */
    public String getSessionId() {
        return sessionId;
    }

    /**
     * Gets the user.
     *
     * @return the user
     */
    @ManyToOne(cascade = CascadeType.ALL)
    public User getUser() {
        return user;
    }

    /**
     * Gets the user agent.
     *
     * @return the user agent
     */
    public String getUserAgent() {
        return userAgent;
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.model.core.BaseEntity#getVersion()
     */
    @Override
    @Version
    public Long getVersion() {
        return version;
    }

    /**
     * Sets the active.
     *
     * @param active the new active
     */
    public void setActive(boolean active) {
        this.active = active;
    }

 
    /**
     * Sets the client host.
     *
     * @param clientHost the new client host
     */
    public void setClientHost(String clientHost) {
        this.clientHost = clientHost;
    }

    /**
     * Sets the created at.
     *
     * @param createdAt the new created at
     */
    public void setCreatedAt(Date createdAt) {
        this.createdAt = createdAt;
    }

    /**
     * Sets the ended at.
     *
     * @param endedAt the new ended at
     */
    public void setEndedAt(Date endedAt) {
        this.endedAt = endedAt;
    }

    /**
     * Sets the events.
     *
     * @param events the new events
     */
    public void setEvents(List<AbstractActionEvent> events) {
        this.events = events;
    }
    
    /**
     * Sets the id.
     *
     * @param id the new id
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * Sets the language.
     *
     * @param language the new language
     */
    public void setLanguage(Language language) {
        this.language = language;
    }

    /**
     * Sets the portal.
     *
     * @param portal the new portal
     */
    public void setPortal(Portal portal) {
        this.portal = portal;
    }

    /**
     * Sets the server host.
     *
     * @param serverHost the new server host
     */
    public void setServerHost(String serverHost) {
        this.serverHost = serverHost;
    }

    /**
     * Sets the session id.
     *
     * @param sessionId the new session id
     */
    public void setSessionId(String sessionId) {
        this.sessionId = sessionId;
    }

    /**
     * Sets the user.
     *
     * @param user the new user
     */
    public void setUser(User user) {
        this.user = user;
    }

    /**
     * Sets the user agent.
     *
     * @param userAgent the new user agent
     */
    public void setUserAgent(String userAgent) {
        this.userAgent = userAgent;
    }

    /**
     * Sets the version.
     *
     * @param version the new version
     */
    public void setVersion(Long version) {
        this.version = version;
    }
}
