/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.application.impl.user;

import java.util.Date;

import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;

import com.hack23.cia.model.application.impl.common.UserSession;

/**
 * The Class AbstractTopListActionEvent.
 */
@Entity
public abstract class AbstractTopListActionEvent extends
        AbstractParliamentActionEvent {

    /**
     * The Enum Operation.
     */
    public enum Operation {

        /** The Top absent. */
        TopAbsent,

        /** The Top losers. */
        TopLosers,

        /** The Top loyals. */
        TopLoyals,

        /** The Top present. */
        TopPresent,

        /** The Top rebels. */
        TopRebels,

        /** The Top winners. */
        TopWinners;
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The operation. */
    private Operation operation;

    /**
     * Instantiates a new abstract top list action event.
     */
    public AbstractTopListActionEvent() {
        super();
    }

    /**
     * Instantiates a new abstract top list action event.
     *
     * @param createdDate the created date
     * @param userSession the user session
     * @param operation the operation
     */
    public AbstractTopListActionEvent(final Date createdDate,
            final UserSession userSession, final Operation operation) {
        super(createdDate, userSession);
        this.operation = operation;
    }

    /**
     * Gets the operation.
     *
     * @return the operation
     */
    @Enumerated(EnumType.STRING)
    public Operation getOperation() {
        return operation;
    }

    /**
     * Sets the operation.
     *
     * @param operation the new operation
     */
    public void setOperation(Operation operation) {
        this.operation = operation;
    }

}
