/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.application.impl.user;

import java.util.Date;

import javax.persistence.DiscriminatorValue;
import javax.persistence.Entity;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.application.impl.common.UserSession;

/**
 * The Class PartyActionEvent.
 */
@Entity
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
@DiscriminatorValue("PartyActionEvent")
public class PartyActionEvent extends AbstractTopListActionEvent {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The party. */
    private String party;

    /**
     * Instantiates a new party action event.
     */
    public PartyActionEvent() {
        super();
    }

    /**
     * Instantiates a new party action event.
     *
     * @param createdDate the created date
     * @param userSession the user session
     * @param party the party
     * @param operation the operation
     */
    public PartyActionEvent(final Date createdDate,
            final UserSession userSession, final String party,
            final Operation operation) {
        super(createdDate, userSession, operation);
        this.party = party;
    }

    /**
     * Gets the party.
     *
     * @return the party
     */
    public String getParty() {
        return party;
    }

    /**
     * Sets the party.
     *
     * @param party the new party
     */
    public void setParty(String party) {
        this.party = party;
    }

}
