/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.application.impl.user;

import java.util.Date;

import javax.persistence.DiscriminatorValue;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.application.impl.common.UserSession;

/**
 * The Class UserAccountActionEvent.
 */
@Entity
@DiscriminatorValue("UserAccountActionEvent")
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public class UserAccountActionEvent extends AbstractUserAccountActionEvent {

    /**
     * The Enum Operation.
     */
    public enum Operation {

        /** The Login. */
        Login,

/** The Logout. */
Logout,

        /** The Process_login. */
		Process_login,

        /** The Register. */
        Register;
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The operation. */
    private Operation operation;

    /**
     * Instantiates a new user account action event.
     */
    public UserAccountActionEvent() {
        super();
    }

    /**
     * Instantiates a new user account action event.
     *
     * @param createdDate the created date
     * @param userSession the user session
     * @param operation the operation
     */
    public UserAccountActionEvent(final Date createdDate,
            final UserSession userSession, final Operation operation) {
        super(createdDate, userSession);
        this.operation = operation;
    }

    /**
     * Gets the operation.
     *
     * @return the operation
     */
    @Enumerated(EnumType.STRING)
    public Operation getOperation() {
        return operation;
    }

    /**
     * Sets the operation.
     *
     * @param operation the new operation
     */
    public void setOperation(Operation operation) {
        this.operation = operation;
    }

}
