/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.core.impl;

import java.io.Serializable;

import javax.persistence.MappedSuperclass;
import javax.persistence.Transient;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;

/**
 * The Class BaseEntity.
 */
@MappedSuperclass
public abstract class BaseEntity implements Serializable {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /* (non-Javadoc)
     * @see java.lang.Object#equals(java.lang.Object)
     */
    @Override
   public final boolean equals(Object obj) {
    if (obj == null) { return false; }
    if (obj == this) { return true; }
    if (obj.getClass() != getClass()) {
      return false;
    }
    BaseEntity baseEntity = (BaseEntity) obj;
    return new EqualsBuilder().appendSuper(true)
                  .append(getId(), baseEntity.getId())
                  .append(getVersion(), baseEntity.getVersion())                 
                  .isEquals();

    }

    /**
     * Gets the id.
     *
     * @return the id
     */
    @Transient
    public abstract Long getId();

    /**
     * Gets the version.
     *
     * @return the version
     */
    @Transient
    public abstract Long getVersion();

    /* (non-Javadoc)
     * @see java.lang.Object#hashCode()
     */
    @Override
    public final int hashCode() {
        return HashCodeBuilder.reflectionHashCode(getClass().getName() + ":" + getId() + ":" + getVersion());
    }

    /**
     * Checks if is new.
     *
     * @return true, if is new
     */
    @Transient
    public boolean isNew() {
        return this.getId() == null;
    }
}
