/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.sweden.impl;

import gnu.trove.THashSet;

import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinTable;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;
import javax.persistence.Version;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.core.impl.BaseEntity;

/**
 * The Class Committee.
 */
@Entity
@Table(uniqueConstraints = { @UniqueConstraint(columnNames = { "name", "href" }) })
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public class Committee extends BaseEntity {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The href. */
    private String href;

    /** The id. */
    private Long id;

    /** The name. */
    private String name;

    /** The version. */
    private Long version=1L;
    
    /** The parliament members. */
    private Set<ParliamentMember> parliamentMembers = new THashSet<ParliamentMember>();

    /**
     * Gets the href.
     *
     * @return the href
     */
    public String getHref() {
        return href;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.model.core.BaseEntity#getId()
     */
    @Override
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    public Long getId() {
        return id;
    }

    /**
     * Gets the name.
     *
     * @return the name
     */
    public String getName() {
        return name;
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.model.core.BaseEntity#getVersion()
     */
    @Override
    @Version
    public Long getVersion() {
        return version;
    }


    /**
     * Sets the href.
     *
     * @param href the new href
     */
    public void setHref(String href) {
        this.href = href;
    }

    /**
     * Sets the id.
     *
     * @param id the new id
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * Sets the name.
     *
     * @param name the new name
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Sets the version.
     *
     * @param version the new version
     */
    public void setVersion(Long version) {
        this.version = version;
    }

    /**
     * Gets the parliament members.
     *
     * @return the parliament members
     */
    @OneToMany(cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    @JoinTable(name = "CommitteeParliamentMembers")
	public Set<ParliamentMember> getParliamentMembers() {
		return parliamentMembers;
	}

	/**
	 * Sets the parliament members.
	 *
	 * @param parliamentMembers the new parliament members
	 */
	public void setParliamentMembers(Set<ParliamentMember> parliamentMembers) {
		this.parliamentMembers = parliamentMembers;
	}

}
