/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.sweden.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
import javax.persistence.Version;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.core.impl.BaseEntity;

/**
 * The Class CommitteeReport.
 */
@Entity
@Table(uniqueConstraints = { @UniqueConstraint(columnNames = { "name", "href" }) })
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public class CommitteeReport extends BaseEntity {

    /**
     * The Enum ImportStatus.
     */
    public enum ImportStatus {

        /** The Completed. */
        Completed,

        /** The Created. */
        Created,

        /** The Waiting. */
        Waiting
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The ballots. */
    private List<Ballot> ballots = new ArrayList<Ballot>();

    /** The decision date. */
    private Date decisionDate;

    /** The href. */
    private String href;

    /** The id. */
    private Long id;

    /** The import status. */
    private ImportStatus importStatus = ImportStatus.Created;

    /** The name. */
    private String name;

    /** The version. */
    private Long version=1L;

    /**
     * Gets the ballots.
     *
     * @return the ballots
     */
    @OneToMany(mappedBy = "commiteeReport", cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    @Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
    public List<Ballot> getBallots() {
        return ballots;
    }

    /**
     * Gets the decision date.
     *
     * @return the decision date
     */
    @Temporal(TemporalType.DATE)
    public Date getDecisionDate() {
        return decisionDate;
    }

    /**
     * Gets the href.
     *
     * @return the href
     */
    public String getHref() {
        return href;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.model.core.BaseEntity#getId()
     */
    @Override
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    public Long getId() {
        return id;
    }

    /**
     * Gets the import status.
     *
     * @return the import status
     */
    @Enumerated(EnumType.STRING)
    public ImportStatus getImportStatus() {
        return importStatus;
    }

    /**
     * Gets the name.
     *
     * @return the name
     */
    public String getName() {
        return name;
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.model.core.BaseEntity#getVersion()
     */
    @Override
    @Version
    public Long getVersion() {
        return version;
    }

    /**
     * Sets the ballots.
     *
     * @param ballots the new ballots
     */
    public void setBallots(List<Ballot> ballots) {
        this.ballots = ballots;
    }

    /**
     * Sets the decision date.
     *
     * @param decisionDate the new decision date
     */
    public void setDecisionDate(Date decisionDate) {
        this.decisionDate = decisionDate;
    }

    /**
     * Sets the href.
     *
     * @param href the new href
     */
    public void setHref(String href) {
        this.href = href;
    }

    /**
     * Sets the id.
     *
     * @param id the new id
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * Sets the import status.
     *
     * @param importStatus the new import status
     */
    public void setImportStatus(ImportStatus importStatus) {
        this.importStatus = importStatus;
    }

    /**
     * Sets the name.
     *
     * @param name the new name
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Sets the version.
     *
     * @param version the new version
     */
    public void setVersion(Long version) {
        this.version = version;
    }

}
