/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.sweden.impl;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToOne;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.persistence.UniqueConstraint;
import javax.persistence.Version;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.core.impl.BaseEntity;

/**
 * The Class ParliamentMember.
 */
@Entity
@Table(uniqueConstraints = { @UniqueConstraint(columnNames = { "fuzzyKey" }) })
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public class ParliamentMember extends BaseEntity {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The electoral region. */
    private String electoralRegion;
    
    /** The english wiki href. */
    private String englishWikiHref;

    /** The fuzzy key. */
    private String fuzzyKey;

    /** The href. */
    private String href;

    /** The id. */
    private Long id;

    /** The name. */
    private String name;


    /** The parliament member ballot record. */
    private ParliamentMemberBallotRecord parliamentMemberBallotRecord;

    /** The party. */
    private String party;

    /** The political party. */
    private PoliticalParty politicalParty;

    /** The version. */
    private Long version=1L;

    /** The wiki href. */
    private String wikiHref;
    
    /**
     * Creates the fuzzy key.
     */
    @Transient
    public final void createFuzzyKey() {
        this.fuzzyKey = getName().replace(" ", "") + getParty() //$NON-NLS-1$ //$NON-NLS-2$
                + getElectoralRegion().replace(" ", ""); //$NON-NLS-1$ //$NON-NLS-2$
    }

    /**
     * Gets the electoral region.
     *
     * @return the electoral region
     */
    public String getElectoralRegion() {
        return electoralRegion;
    }

    /**
     * Gets the english wiki href.
     *
     * @return the english wiki href
     */
    public String getEnglishWikiHref() {
        return englishWikiHref;
    }


    /**
     * Gets the fuzzy key.
     *
     * @return the fuzzy key
     */
    public String getFuzzyKey() {
        return fuzzyKey;
    }

    /**
     * Gets the href.
     *
     * @return the href
     */
    public String getHref() {
        return href;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.model.core.BaseEntity#getId()
     */
    @Override
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    public Long getId() {
        return id;
    }

    /**
     * Gets the international href.
     *
     * @return the international href
     */
    @Transient
    public String getInternationalHref() {
        String intHref = null;
        if (href != null) {
            intHref = href.replace("nid=1111", "nid=1811");
        }
        return intHref;
    }

    /**
     * Gets the name.
     *
     * @return the name
     */
    public String getName() {
        return name;
    }


    /**
     * Gets the parliament member ballot record.
     *
     * @return the parliament member ballot record
     */
	@OneToOne(cascade=CascadeType.ALL)
	@JoinColumn(name="parliamentMemberBallotRecordId")
	public ParliamentMemberBallotRecord getParliamentMemberBallotRecord() {
		return parliamentMemberBallotRecord;
	}

    /**
     * Gets the party.
     *
     * @return the party
     */
    public String getParty() {
        return party;
    }

    /**
     * Gets the political party.
     *
     * @return the political party
     */
    @ManyToOne
	public PoliticalParty getPoliticalParty() {
		return politicalParty;
	}
 
    /* (non-Javadoc)
     * @see com.hack23.cia.model.core.BaseEntity#getVersion()
     */
    @Override
    @Version
    public Long getVersion() {
        return version;
    }

    /**
     * Gets the wiki href.
     *
     * @return the wiki href
     */
    public String getWikiHref() {
        return wikiHref;
    }


    /**
     * Sets the electoral region.
     *
     * @param electoralRegion the new electoral region
     */
    public void setElectoralRegion(String electoralRegion) {
        this.electoralRegion = electoralRegion;
    }

    /**
     * Sets the english wiki href.
     *
     * @param englishWikiHref the new english wiki href
     */
    public void setEnglishWikiHref(String englishWikiHref) {
        this.englishWikiHref = englishWikiHref;
    }

    /**
     * Sets the fuzzy key.
     *
     * @param fuzzyKey the new fuzzy key
     */
    public void setFuzzyKey(String fuzzyKey) {
        this.fuzzyKey = fuzzyKey;
    }


    /**
     * Sets the href.
     *
     * @param href the new href
     */
    public void setHref(String href) {
        this.href = href;
    }


    /**
     * Sets the id.
     *
     * @param id the new id
     */
    public void setId(Long id) {
        this.id = id;
    }


    /**
     * Sets the name.
     *
     * @param name the new name
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Sets the parliament member ballot record.
     *
     * @param parliamentMemberBallotRecord the new parliament member ballot record
     */
	public void setParliamentMemberBallotRecord(
			ParliamentMemberBallotRecord parliamentMemberBallotRecord) {
		this.parliamentMemberBallotRecord = parliamentMemberBallotRecord;
	}


    /**
     * Sets the party.
     *
     * @param party the new party
     */
    public void setParty(String party) {
        this.party = party;
    }

	/**
	 * Sets the political party.
	 *
	 * @param politicalParty the new political party
	 */
	public void setPoliticalParty(PoliticalParty politicalParty) {
		this.politicalParty = politicalParty;
	}

	/**
	 * Sets the version.
	 *
	 * @param version the new version
	 */
    public void setVersion(Long version) {
        this.version = version;
    }

	/**
	 * Sets the wiki href.
	 *
	 * @param wikiHref the new wiki href
	 */
    public void setWikiHref(String wikiHref) {
        this.wikiHref = wikiHref;
    }
}
