/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.sweden.impl;

import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Version;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.core.impl.BaseEntity;

/**
 * The Class VoteMetaData.
 */
@Entity
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public class VoteMetaData extends BaseEntity {

	/**
	 * The Enum Outcome.
	 */
	public enum Outcome {
    	
	    /** The Lost. */
		Lost,

/** The Won. */
Won;
    }

	
	/**
	 * The Enum PoliticalPartyBehavior.
	 */
    public enum PoliticalPartyBehavior {
    	
	    /** The Loyal. */
		Loyal,

/** The Neutral. */
Neutral,

/** The Rebel. */
Rebel;
    }    

    /**
     * The Enum ProffessionalBehavior.
     */
    public enum ProffessionalBehavior {
    	
	    /** The Absent. */
		Absent,

/** The Present. */
Present;
    }        
    
    /** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;           
    
    /** The id. */
    private Long id;

    /** The outcome. */
    private Outcome outcome;
    
    /** The political party behavior. */
    private PoliticalPartyBehavior politicalPartyBehavior;
    
    /** The proffessional behavior. */
    private ProffessionalBehavior proffessionalBehavior;
    
    /** The version. */
    private Long version=1L;

    /**
     * Instantiates a new vote meta data.
     */
    public VoteMetaData() {
		super();
	}
    
	/*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.model.core.BaseEntity#getId()
     */
    @Override
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    public Long getId() {
        return id;
    }


    /**
     * Gets the outcome.
     *
     * @return the outcome
     */
    @Enumerated(EnumType.STRING)
	public Outcome getOutcome() {
		return outcome;
	}


    /**
     * Gets the political party behavior.
     *
     * @return the political party behavior
     */
    @Enumerated(EnumType.STRING)
	public PoliticalPartyBehavior getPoliticalPartyBehavior() {
		return politicalPartyBehavior;
	}


    /**
     * Gets the proffessional behavior.
     *
     * @return the proffessional behavior
     */
    @Enumerated(EnumType.STRING)
	public ProffessionalBehavior getProffessionalBehavior() {
		return proffessionalBehavior;
	}

    /* (non-Javadoc)
     * @see com.hack23.cia.model.core.BaseEntity#getVersion()
     */
    @Override
    @Version
    public Long getVersion() {
        return version;
    }

	/**
	 * Sets the id.
	 *
	 * @param id the new id
	 */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * Sets the outcome.
     *
     * @param outcome the new outcome
     */
	public void setOutcome(Outcome outcome) {
		this.outcome = outcome;
	}

	/**
	 * Sets the political party behavior.
	 *
	 * @param politicalPartyBehavior the new political party behavior
	 */
	public void setPoliticalPartyBehavior(
			PoliticalPartyBehavior politicalPartyBehavior) {
		this.politicalPartyBehavior = politicalPartyBehavior;
	}

    /**
     * Sets the proffessional behavior.
     *
     * @param proffessionalBehavior the new proffessional behavior
     */
	public void setProffessionalBehavior(ProffessionalBehavior proffessionalBehavior) {
		this.proffessionalBehavior = proffessionalBehavior;
	}

	/**
	 * Sets the version.
	 *
	 * @param version the new version
	 */
    public void setVersion(Long version) {
        this.version = version;
    }

}
