/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.api.admin;

import com.hack23.cia.model.application.impl.admin.AgencyActionEvent.Operation;
import com.hack23.cia.model.application.impl.common.Agency;

/**
 * The Class AgencyRequest.
 */
public class AgencyRequest extends AbstractAgencyRequest {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The agency id. */
    private final Long agencyId;

    /** The operation. */
    private final Operation operation;

    /**
     * Instantiates a new agency request.
     *
     * @param userSessionId the user session id
     * @param operation the operation
     * @param agencyId the agency id
     */
    public AgencyRequest(final Long userSessionId, final Operation operation,
            final Long agencyId) {
        super(userSessionId,null);
        this.operation = operation;
        this.agencyId = agencyId;
    }

    /**
     * Instantiates a new agency request.
     *
     * @param userSessionId the user session id
     * @param operation the operation
     * @param agencyId the agency id
     * @param agency the agency
     */
    public AgencyRequest(final Long userSessionId, final Operation operation,
            final Long agencyId, final Agency agency) {
       super(userSessionId,agency);
       this.operation = operation;
       this.agencyId = agencyId;
    }


    /**
     * Gets the agency id.
     *
     * @return the agency id
     */
    public final Long getAgencyId() {
        return agencyId;
    }

    /**
     * Gets the operation.
     *
     * @return the operation
     */
    public final Operation getOperation() {
        return operation;
    }
}
