/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.api.admin;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.Language;
import com.hack23.cia.model.application.impl.common.LanguageContent;

/**
 * The Class LanguageResponse.
 */
public class LanguageResponse extends AbstractConfigurationResponse {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The language. */
    private final Language language;
    
    /** The language content. */
    private final LanguageContent languageContent;
    

    /**
     * Instantiates a new language response.
     *
     * @param userSessionDTO the user session dto
     * @param agency the agency
     */
    public LanguageResponse(final UserSessionDTO userSessionDTO, final Agency agency) {
        super(userSessionDTO,agency);
        this.language = null;
        this.languageContent=null;
    }

    /**
     * Instantiates a new language response.
     *
     * @param userSessionDTO the user session dto
     * @param agency the agency
     * @param language the language
     */
    public LanguageResponse(final UserSessionDTO userSessionDTO, final Agency agency,
            final Language language) {
        super(userSessionDTO,agency);
        this.language = language;
        this.languageContent=null;
    }

    /**
     * Instantiates a new language response.
     *
     * @param userSessionDTO the user session dto
     * @param agency the agency
     * @param languageContent the language content
     */
    public LanguageResponse(final UserSessionDTO userSessionDTO, final Agency agency,
            final LanguageContent languageContent) {
        super(userSessionDTO,agency);
        this.languageContent = languageContent;
        this.language = languageContent.getLanguage();
    }
    
    /**
     * Gets the language.
     *
     * @return the language
     */
    public final Language getLanguage() {
        return language;
    }

    /**
     * Gets the language content.
     *
     * @return the language content
     */
    public final LanguageContent getLanguageContent() {
        return languageContent;
    }

}
