/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.api.application;

import java.util.Map;

import com.hack23.cia.service.api.common.AbstractServiceRequest;

/**
 * The Class ApplicationRequest.
 */
public class ApplicationRequest extends AbstractServiceRequest {

    /**
     * The Enum HeaderAttributeKey.
     */
    public enum HeaderAttributeKey {

        /** The CLIEN t_ inf o_ address. */
        CLIENT_INFO_ADDRESS,

        /** The CLIEN t_ inf o_ host. */
        CLIENT_INFO_HOST,

        /** The CLIEN t_ inf o_ user. */
        CLIENT_INFO_USER,

        /** The HEADE r_ cookie. */
        HEADER_COOKIE,

        /** The HEADE r_ host. */
        HEADER_HOST;
    }

    /** The Constant HEADER_ACCEPT_LANGUAGE. */
    public static final String HEADER_ACCEPT_LANGUAGE = "HEADER_ACCEPT-LANGUAGE";

    /** The Constant HEADER_USER_AGENT. */
    public static final String HEADER_USER_AGENT = "HEADER_USER-AGENT";

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The user settings map. */
    private final Map<String, String> userSettingsMap;

    /**
     * Instantiates a new application request.
     *
     * @param userSettingsMap the user settings map
     */
    public ApplicationRequest(final Map<String, String> userSettingsMap) {
        super(null);
        this.userSettingsMap = userSettingsMap;
    }

    /**
     * Gets the accept language.
     *
     * @return the accept language
     */
    public final String getAcceptLanguage() {
        return userSettingsMap.get(HEADER_ACCEPT_LANGUAGE);
    }

    /**
     * Gets the header attribute.
     *
     * @param headerAttributeKey the header attribute key
     * @return the header attribute
     */
    public final String getHeaderAttribute(
            final HeaderAttributeKey headerAttributeKey) {
        String string = headerAttributeKey.toString();
        return userSettingsMap.get(string);
    }

    /**
     * Gets the user agent.
     *
     * @return the user agent
     */
    public final String getUserAgent() {
        return userSettingsMap.get(HEADER_USER_AGENT);
    }

}
