/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.service.dao;

import java.io.Serializable;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.orm.hibernate3.support.HibernateDaoSupport;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.hack23.cia.model.core.impl.BaseEntity;

/**
 * The Class GenericHibernateDAO.
 *
 * @param <T> the generic type
 * @param <ID> the generic type
 */
@Transactional(propagation = Propagation.SUPPORTS)
public abstract class GenericHibernateDAO<T extends BaseEntity, ID extends Serializable>
        extends HibernateDaoSupport implements GenericDAO<T, ID> {

    /** The Constant LOGGER. */
    private static final Log LOGGER = LogFactory
            .getLog(GenericHibernateDAO.class);

    /** The persistent class. */
    private final Class<T> persistentClass;

    /**
     * Instantiates a new generic hibernate dao.
     *
     * @param persistentClass the persistent class
     */
    protected GenericHibernateDAO(final Class<T> persistentClass) {
        this.persistentClass = persistentClass;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.GenericDAO#delete(com.hack23.cia.model.core
     * .BaseEntity)
     */
    public final void delete(final T entity) {
        this.getHibernateTemplate().delete(entity);
        LOGGER.info("Deleted: " + entity); //$NON-NLS-1$
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.dao.GenericDAO#getAll()
     */
    @Transactional(readOnly = true)
    public final List<T> getAll() {
        return getHibernateTemplate().loadAll(persistentClass);
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.dao.GenericDAO#load(java.io.Serializable)
     */
    @Transactional(readOnly = true)
    public final T load(final ID id) {
        return this.getHibernateTemplate().get(persistentClass, id);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.GenericDAO#save(com.hack23.cia.model.core.
     * BaseEntity)
     */
    public final T save(final T entity) {
        if (entity.isNew()) {
            this.getHibernateTemplate().save(entity);
        } else {
            this.getHibernateTemplate().saveOrUpdate(entity);
        }
        return entity;
    }
}
