/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.impl.admin;

import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.ImageContent;
import com.hack23.cia.model.application.impl.common.Language;
import com.hack23.cia.model.application.impl.common.LanguageContent;
import com.hack23.cia.model.application.impl.common.Portal;

/**
 * The Interface AdminService.
 */
public interface AdminService {

    /**
     * Adds the agency language content.
     *
     * @param agency the agency
     * @param language the language
     * @param key the key
     * @param content the content
     * @return the agency
     */
    Agency addAgencyLanguageContent(Agency agency,Language language,String key, String content);

    /**
     * Adds the language.
     *
     * @param agency the agency
     * @return the agency
     */
    Agency addLanguage(Agency agency);

    
    /**
     * Adds the language content.
     *
     * @param agency the agency
     * @param language the language
     * @return the language content
     */
    LanguageContent addLanguageContent(Agency agency, Language language);
    
    /**
     * Adds the portal.
     *
     * @param agency the agency
     * @return the agency
     */
    Agency addPortal(Agency agency);

    /**
     * Creates the response time graph.
     *
     * @return the image content
     */
    ImageContent createResponseTimeGraph();

    /**
     * Delete language.
     *
     * @param agency the agency
     * @param language the language
     * @return the agency
     */
    Agency deleteLanguage(Agency agency, Language language);

    /**
     * Delete language content.
     *
     * @param agency the agency
     * @param languageContent the language content
     * @return the agency
     */
    Agency deleteLanguageContent(Agency agency, LanguageContent languageContent);

    /**
     * Delete portal.
     *
     * @param portal the portal
     * @return the agency
     */
    Agency deletePortal(Portal portal);

    /**
     * Gets the recent actions graph.
     *
     * @return the recent actions graph
     */
    ImageContent getRecentActionsGraph();

    /**
     * Load agency.
     *
     * @return the agency
     */
    Agency loadAgency();

    /**
     * Load agency.
     *
     * @param agencyId the agency id
     * @return the agency
     */
    Agency loadAgency(Long agencyId);

    /**
     * Start update job.
     */
    void startUpdateJob();

    /**
     * Update agency.
     *
     * @param agency the agency
     * @return the agency
     */
    Agency updateAgency(Agency agency);

    /**
     * Update language.
     *
     * @param agency the agency
     * @param language the language
     * @return the agency
     */
    Agency updateLanguage(Agency agency, Language language);

    /**
     * Update language content.
     *
     * @param agency the agency
     * @param languageContent the language content
     * @return the agency
     */
    Agency updateLanguageContent(Agency agency, LanguageContent languageContent);

    /**
     * Update portal.
     *
     * @param portal the portal
     * @return the portal
     */
    Portal updatePortal(Portal portal);
}
