/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.service.impl.admin;

import java.util.Date;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.admin.AgencyActionEvent;
import com.hack23.cia.model.application.impl.common.ActionEvent;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.service.api.admin.AgencyRequest;
import com.hack23.cia.service.api.admin.AgencyResponse;
import com.hack23.cia.service.api.common.ServiceResponse;
import com.hack23.cia.service.impl.common.UserSessionService;

/**
 * The Class AgencyRequestService.
 */
public class AgencyRequestService extends
        AbstractAdminRequestService<AgencyRequest> {

    /**
     * Instantiates a new agency request service.
     *
     * @param userSessionService the user session service
     * @param adminService the admin service
     */
    public AgencyRequestService(final UserSessionService userSessionService,
            final AdminService adminService) {
        super(userSessionService, adminService);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.impl.common.AbstractGenericService#createActionEvent
     * (com.hack23.cia.service.api.common.AbstractServiceRequest,
     * com.hack23.cia.model.application.UserSession)
     */
    @Override
    public final ActionEvent createActionEvent(final AgencyRequest request,
            final UserSession userSession) {
        return new AgencyActionEvent(new Date(), userSession, request
                .getOperation(), request.getAgencyId());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.common.ServiceHandler#getSupportedService()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedService() {
        return AgencyRequest.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.service.common.AbstractGenericServiceHandler#
     * handleServiceRequest(com.hack23.cia.service.api.AbstractServiceRequest)
     */
    @Override
    public final ServiceResponse handleServiceRequest(
            final AgencyRequest request, final UserSessionDTO userSession) {
        AgencyResponse agencyResponse = null;
        Agency agency = null;
        
        if (request.getAgencyId() != null) {
            agency = this.getAdminService().loadAgency(request.getAgencyId());
        } else {
            agency = this.getAdminService().loadAgency();
        }


        switch (request.getOperation()) {
        case UpdateAgency:
            agencyResponse = new AgencyResponse(userSession, this
                    .getAdminService().updateAgency(request.getAgency()));
            break;
        case AddPortal:
            agencyResponse = new AgencyResponse(userSession, this
                    .getAdminService().addPortal(agency));
            break;
        case AddLanguage:
            agencyResponse = new AgencyResponse(userSession, this
                    .getAdminService().addLanguage(agency));
            break;
        case ConfigureAgency:
            agencyResponse = new AgencyResponse(userSession, agency);
            break;
        default:
            break;
        }

        return agencyResponse;
    }
}
