/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.impl.admin;

import gnu.trove.THashMap;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.ImageContent;
import com.hack23.cia.model.application.impl.common.Language;
import com.hack23.cia.model.sweden.impl.Ballot;
import com.hack23.cia.model.sweden.impl.BallotResult;
import com.hack23.cia.model.sweden.impl.CommitteeReport;
import com.hack23.cia.model.sweden.impl.ParliamentMember;
import com.hack23.cia.model.sweden.impl.ParliamentMemberBallotRecord;
import com.hack23.cia.model.sweden.impl.ParliamentMemberVoteCompareResult;
import com.hack23.cia.model.sweden.impl.PartyBallotResult;
import com.hack23.cia.model.sweden.impl.PoliticalParty;
import com.hack23.cia.model.sweden.impl.Vote;
import com.hack23.cia.model.sweden.impl.VoteMetaData;
import com.hack23.cia.model.sweden.impl.CommitteeReport.ImportStatus;
import com.hack23.cia.model.sweden.impl.Vote.Position;
import com.hack23.cia.model.sweden.impl.VoteMetaData.Outcome;
import com.hack23.cia.model.sweden.impl.VoteMetaData.PoliticalPartyBehavior;
import com.hack23.cia.model.sweden.impl.VoteMetaData.ProffessionalBehavior;
import com.hack23.cia.service.dao.AgencyDAO;
import com.hack23.cia.service.dao.BallotDAO;
import com.hack23.cia.service.dao.CommitteeReportDAO;
import com.hack23.cia.service.dao.ParliamentMemberDAO;
import com.hack23.cia.service.dao.PoliticalPartyDAO;
import com.hack23.cia.service.dao.ResourceDAO;
import com.hack23.cia.service.impl.common.ChartService;

/**
 * The Class LoaderServiceImpl.
 */
@Transactional(propagation = Propagation.REQUIRED)
public class LoaderServiceImpl implements LoaderService {

	/** The Constant LOGGER. */
	private static final Log LOGGER = LogFactory
			.getLog(LoaderServiceImpl.class);

	/** The agency dao. */
	private final AgencyDAO agencyDAO;

	/** The ballot dao. */
	private final BallotDAO ballotDAO;

	/** The chart service. */
	private final ChartService chartService;

	/** The commitee report dao. */
	private final CommitteeReportDAO commiteeReportDAO;
	
	/** The parliament member dao. */
	private final ParliamentMemberDAO parliamentMemberDAO;
	
	/** The political party dao. */
	private final PoliticalPartyDAO politicalPartyDAO;
	
	/** The resource dao. */
	private final ResourceDAO resourceDAO;

	/**
	 * Instantiates a new loader service impl.
	 *
	 * @param commiteeReportDAO the commitee report dao
	 * @param ballotDAO the ballot dao
	 * @param parliamentMemberDAO the parliament member dao
	 * @param politicalPartyDAO the political party dao
	 * @param resourceDAO the resource dao
	 * @param agencyDAO the agency dao
	 * @param chartService the chart service
	 */
	public LoaderServiceImpl(final CommitteeReportDAO commiteeReportDAO,
			final BallotDAO ballotDAO,
			final ParliamentMemberDAO parliamentMemberDAO,
			final PoliticalPartyDAO politicalPartyDAO,final ResourceDAO resourceDAO,final AgencyDAO agencyDAO,final ChartService chartService) {
		super();
		this.commiteeReportDAO = commiteeReportDAO;
		this.ballotDAO = ballotDAO;
		this.parliamentMemberDAO = parliamentMemberDAO;
		this.politicalPartyDAO = politicalPartyDAO;
		this.resourceDAO = resourceDAO;
		this.agencyDAO = agencyDAO;
		this.chartService = chartService;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.hack23.cia.service.InformationService#addBallotInformation(java.lang
	 * .Long, java.util.Set)
	 */
	@Override
	public final void addBallotInformation(final Long ballotId,
			final List<Vote> voteResult) {
		Ballot ballot = ballotDAO.load(ballotId);

		if (voteResult.size() == Ballot.TOTAL_VOTES) {

			Map<String, ParliamentMember> allMap = createMap(parliamentMemberDAO
					.getAll());

			BallotResult ballotResult = new BallotResult();
			Map<String, PartyBallotResult> partyPartyBallotResultMap = new THashMap<String, PartyBallotResult>();

			for (Vote vote : voteResult) {
				ballotResult.newVote(vote);

				PartyBallotResult partyBallotResult = partyPartyBallotResultMap
						.get(vote.getParliamentMember().getParty());

				if (partyBallotResult == null) {
					partyBallotResult = new PartyBallotResult();
					PoliticalParty politicalParty = politicalPartyDAO
							.findByShortCode(vote.getParliamentMember()
									.getParty());
					partyBallotResult.setPoliticalParty(politicalParty);
					partyPartyBallotResultMap.put(politicalParty.getShortCode(), partyBallotResult);
				}
				partyBallotResult.newVote(vote);
			}

			ballotResult.calcWinningPosition();

			ballot.setBallotResult(ballotResult);
			for (PartyBallotResult partyBallotResult : partyPartyBallotResultMap
					.values()) {
				partyBallotResult.calcWinningPosition();
				ballot.getPartyBallotResult().add(partyBallotResult);
			}

			for (Vote vote : voteResult) {
				vote.setDatum(ballot.getCommiteeReport().getDecisionDate());
				ParliamentMember parliamentMember = allMap.get(vote
						.getParliamentMember().getFuzzyKey());

				if (parliamentMember == null) {
					PoliticalParty politicalParty = politicalPartyDAO
							.findByShortCode(vote.getParliamentMember()
									.getParty());
					vote.getParliamentMember()
							.setPoliticalParty(politicalParty);

					vote.getParliamentMember().setParliamentMemberBallotRecord(new ParliamentMemberBallotRecord());
					parliamentMember = parliamentMemberDAO.save(vote
							.getParliamentMember());
					politicalParty.getParliamentMembers().add(parliamentMember);
					politicalPartyDAO.save(politicalParty);

					allMap
							.put(parliamentMember.getFuzzyKey(),
									parliamentMember);
				}
				vote.setParliamentMember(parliamentMember);
				parliamentMember.getParliamentMemberBallotRecord().newVote(vote);
				VoteMetaData voteMetaData = new VoteMetaData();
				vote.setVoteMetaData(voteMetaData);
				
					if (ballot.getBallotResult().isLosingVote(vote)) {
						parliamentMember.getParliamentMemberBallotRecord()
								.setOpponent(parliamentMember.getParliamentMemberBallotRecord().getOpponent() + 1);
						voteMetaData.setOutcome(Outcome.Lost);
					} else {
						voteMetaData.setOutcome(Outcome.Won);
					}
				
					PartyBallotResult partyBallotResult = partyPartyBallotResultMap.get(parliamentMember.getParty());
		
					if (partyBallotResult.isRebelVote(vote) ) {
						parliamentMember.getParliamentMemberBallotRecord().setRebel(parliamentMember.getParliamentMemberBallotRecord().getRebel() + 1);
						voteMetaData.setPoliticalPartyBehavior(PoliticalPartyBehavior.Rebel);
					} else {
						voteMetaData.setPoliticalPartyBehavior(PoliticalPartyBehavior.Loyal);
					}
				
					if (vote.getPosition().equals(Position.Absent)) {
						voteMetaData.setProffessionalBehavior(ProffessionalBehavior.Absent);
					} else {
						voteMetaData.setProffessionalBehavior(ProffessionalBehavior.Present);
					}

				vote.setBallot(ballot);
				ballot.getVotes().add(vote);
				parliamentMemberDAO.save(parliamentMember);
			}
			ballot.setImportStatus(Ballot.ImportStatus.Completed);
			ballotDAO.save(ballot);
			LOGGER.info("Ballot saved " + ballot.getDescription()); //$NON-NLS-1$
		} else {
			
			LOGGER.info("Ballot data Missing " + ballot.getDescription()); //$NON-NLS-1$
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.hack23.cia.service.InformationService#addBetankandeInformation(java
	 * .lang.Long, java.util.Date, java.util.List)
	 */
	@Override
	public final void addCommitteeReportInformation(final Long id,
			final Date decidedDateIfAny, final List<Ballot> findVotedballot) {
		CommitteeReport commiteeReport = commiteeReportDAO.load(id);

		commiteeReport.setImportStatus(ImportStatus.Completed);
		commiteeReport.setDecisionDate(decidedDateIfAny);

		if (findVotedballot != null) {
			for (Ballot ballot : findVotedballot) {
				ballot.setDatum(decidedDateIfAny);
				ballot.setCommiteeReport(commiteeReport);
				commiteeReport.getBallots().add(ballot);
			}
		}
		commiteeReportDAO.save(commiteeReport);
		LOGGER
				.info("CommiteeReport updated " + commiteeReport.getDecisionDate() //$NON-NLS-1$
						+ "  ballots : " + commiteeReport.getBallots().size()); //$NON-NLS-1$
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.hack23.cia.service.InformationService#addIfNotExist(com.hack23.cia
	 * .model.sweden.CommiteeReport)
	 */
	@Override
	public final void addIfNotExist(final CommitteeReport commiteeReport) {
		CommitteeReport exist = commiteeReportDAO.findByName(commiteeReport
				.getName());

		if (exist == null) {
			commiteeReportDAO.save(commiteeReport);
			LOGGER.info("CommiteeReport saved " + commiteeReport.getName()); //$NON-NLS-1$
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.hack23.cia.service.impl.admin.LoaderService#addIfNotExist(com.hack23
	 * .cia.model.sweden.impl.PoliticalParty)
	 */
	@Override
	public final void addIfNotExist(final PoliticalParty politcalParty) {
		PoliticalParty exist = politicalPartyDAO.findByName(politcalParty
				.getName());

		if (exist == null) {
			politicalPartyDAO.save(politcalParty);
			LOGGER.info("PoliticalParty saved " + politcalParty.getName()); //$NON-NLS-1$
		}
	}


	/**
	 * Calc friends.
	 *
	 * @param first the first
	 * @param parliamentMember the parliament member
	 * @param parliamentMember2 the parliament member2
	 * @return the parliament member vote compare result
	 */

	private ParliamentMemberVoteCompareResult calcFriends(
			final List<Vote> first, final ParliamentMember parliamentMember,
			final ParliamentMember parliamentMember2) {

		int total = 0;
		int with = 0;

		for (Vote vote : first) {
			Position position = vote.getPosition();

			Vote vote2 = vote.getBallot().getVoteForParliamentMember(
					parliamentMember2);

			if (vote2 != null) {
				Position position2 = vote2.getPosition();

				// Only compare when both parties are present and vote yes or no
				if (!((Position.Absent.equals(position))
						|| (Position.Absent.equals(position2))
						|| (Position.Neutral.equals(position)) || (Position.Neutral
						.equals(position2)))) {
					if (position.equals(position2)) {
						with++;
					}
					total++;
				}
			}
		}

		float result = -1f;
		if (total != 0) {
			result = (with * 100f) / total;
		} else {
			result = -1;
		}
		return new ParliamentMemberVoteCompareResult(new Date(), total, result,
				parliamentMember, parliamentMember2);
	}

	/**
	 * Creates the map.
	 *
	 * @param all the all
	 * @return the map
	 */
	private Map<String, ParliamentMember> createMap(
			final List<ParliamentMember> all) {
		Map<String, ParliamentMember> map = new THashMap<String, ParliamentMember>();
		for (ParliamentMember parliamentMember : all) {
			map.put(parliamentMember.getFuzzyKey(), parliamentMember);
		}
		return map;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @seecom.hack23.cia.service.InformationService#
	 * createParliamentMemberVoteCompareResults()
	 */
	public final void createParliamentMemberVoteCompareResults() {
		List<ParliamentMemberVoteCompareResult> result = new ArrayList<ParliamentMemberVoteCompareResult>();
		List<ParliamentMember> list = parliamentMemberDAO.getCurrentList();
		for (ParliamentMember parliamentMember : list) {
			List<Vote> position = parliamentMemberDAO
					.findVotes(parliamentMember.getId());
			for (ParliamentMember parliamentMember2 : list) {
				if (!parliamentMember.getId().equals(parliamentMember2.getId())) {
					result.add(calcFriends(position, parliamentMember,
							parliamentMember2));
				}
			}
			LOGGER
					.info("Generated friends " + parliamentMember.getName() + " " + parliamentMember.getParty()); //$NON-NLS-1$ //$NON-NLS-2$
		}
		parliamentMemberDAO.saveParliamentMemberVoteCompareResult(result);
	}


	/*
	 * (non-Javadoc)
	 * 
	 * @seecom.hack23.cia.service.InformationService#
	 * deleteParliamentMemberVoteCompareResults()
	 */
	public final void deleteParliamentMemberVoteCompareResults() {
		this.parliamentMemberDAO.deleteAllParliamentMemberVoteCompareResults();
	}

	/* (non-Javadoc)
	 * @see com.hack23.cia.service.impl.admin.LoaderService#generateBallotCharts()
	 */
	@Override
	public final void generateBallotCharts(final Long ballotId) {
		long agencyId =1;
		Agency agency = agencyDAO.load(agencyId);
		Ballot ballot = this.ballotDAO.load(ballotId);
		List<PoliticalParty> allPoliticalParties = politicalPartyDAO.getAll();
		for (Language language : agency.getLanguages()) {
			
			List<ImageContent> parliamentCharts = this.chartService.generateBallotCharts(agency,ballot,allPoliticalParties,language);
			
			for (ImageContent imageContent : parliamentCharts) {
				ImageContent oldImageContentIfExist = this.resourceDAO.getImageContentByFileName(imageContent.getFileName());
				if (oldImageContentIfExist !=null) {
					this.resourceDAO.delete(oldImageContentIfExist);
				}
				this.resourceDAO.save(imageContent);
			}
		}
	}

	/* (non-Javadoc)
	 * @see com.hack23.cia.service.impl.admin.LoaderService#generateCommitteeReportCharts()
	 */
	@Override
	public final void generateCommitteeReportCharts() {
		long agencyId =1;
		Agency agency = agencyDAO.load(agencyId);
		List<Ballot> allBallots = this.ballotDAO.getAll();
		List<PoliticalParty> allPoliticalParties = politicalPartyDAO.getAll();
		for (Language language : agency.getLanguages()) {
			
			List<ImageContent> parliamentCharts = this.chartService.generateCommitteeReportCharts(agency, allBallots,allPoliticalParties,language);
			
			for (ImageContent imageContent : parliamentCharts) {
				ImageContent oldImageContentIfExist = this.resourceDAO.getImageContentByFileName(imageContent.getFileName());
				if (oldImageContentIfExist !=null) {
					this.resourceDAO.delete(oldImageContentIfExist);
				}
				this.resourceDAO.save(imageContent);
			}
		}
	}

	/* (non-Javadoc)
	 * @see com.hack23.cia.service.impl.admin.LoaderService#generateCharts()
	 */
	@Override
	public final void generateParliamentCharts() {
		long agencyId =1;
		Agency agency = agencyDAO.load(agencyId);
		List<Ballot> allBallots = this.ballotDAO.getAll();
		List<PoliticalParty> allPoliticalParties = politicalPartyDAO.getAll();
		for (Language language : agency.getLanguages()) {
			
			List<ImageContent> parliamentCharts = this.chartService.generateParliamentCharts(agency, allBallots,allPoliticalParties,language);
			
			for (ImageContent imageContent : parliamentCharts) {
				ImageContent oldImageContentIfExist = this.resourceDAO.getImageContentByFileName(imageContent.getFileName());
				if (oldImageContentIfExist !=null) {
					this.resourceDAO.delete(oldImageContentIfExist);
				}
				this.resourceDAO.save(imageContent);
			}
		}
	}

	/* (non-Javadoc)
	 * @see com.hack23.cia.service.impl.admin.LoaderService#generateParliamentMemberCharts()
	 */
	@Override
	public final void generateParliamentMemberCharts(final Long memberId) {
		ParliamentMember parliamentMember = parliamentMemberDAO.load(memberId);
		long agencyId =1;
		Agency agency = agencyDAO.load(agencyId);
		List<Ballot> allBallots = this.ballotDAO.getAll();
		List<PoliticalParty> allPoliticalParties = politicalPartyDAO.getAll();
		for (Language language : agency.getLanguages()) {
			
			List<ImageContent> parliamentCharts = this.chartService.generateParliamentMemberCharts(agency, allBallots,parliamentMember,allPoliticalParties,language);
			
			for (ImageContent imageContent : parliamentCharts) {
				LOGGER.info("Saving Chart " + imageContent.getFileName());
				ImageContent oldImageContentIfExist = this.resourceDAO.getImageContentByFileName(imageContent.getFileName());
				if (oldImageContentIfExist !=null) {
					this.resourceDAO.delete(oldImageContentIfExist);
				}
				this.resourceDAO.save(imageContent);
			}
		}		
	}

	/* (non-Javadoc)
	 * @see com.hack23.cia.service.impl.admin.LoaderService#generatePoliticalPartyCharts()
	 */
	@Override
	public final void generatePoliticalPartyCharts(final Long politicalPartyId) {
		long agencyId =1;
		Agency agency = agencyDAO.load(agencyId);
		List<Ballot> allBallots = this.ballotDAO.getAll();
		PoliticalParty politicalParty = this.politicalPartyDAO.load(politicalPartyId);
		for (Language language : agency.getLanguages()) {
			
			List<ImageContent> parliamentCharts = this.chartService.generatePoliticalPartyCharts(agency, allBallots,politicalParty,language);
			
			for (ImageContent imageContent : parliamentCharts) {
				ImageContent oldImageContentIfExist = this.resourceDAO.getImageContentByFileName(imageContent.getFileName());
				if (oldImageContentIfExist !=null) {
					this.resourceDAO.delete(oldImageContentIfExist);
				}
				this.resourceDAO.save(imageContent);
			}
		}		
	}

	/* (non-Javadoc)
	 * @see com.hack23.cia.service.impl.admin.LoaderService#getAllBallots()
	 */
	public final List<Ballot> getAllBallots() {
		return ballotDAO.getAll();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.hack23.cia.service.InformationService#getAllCompletedBallotar()
	 */
	@Override
	public final List<Ballot> getAllCompletedBallotar() {
		return ballotDAO.getAllCompleted();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.hack23.cia.service.InformationService#getAllCreatedBallotar()
	 */
	@Override
	public final List<Ballot> getAllCreatedBallotar() {
		return ballotDAO.getAllCreated();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.hack23.cia.service.InformationService#getAllCreatedBetankanden()
	 */
	@Override
	public final List<CommitteeReport> getAllCreatedCommitteeReports() {
		return commiteeReportDAO.getAllCreated();
	}

	/* (non-Javadoc)
	 * @see com.hack23.cia.service.impl.admin.LoaderService#getAllPoliticalParties()
	 */
	public final List<PoliticalParty> getAllPoliticalParties() {
		return politicalPartyDAO.getAll();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.hack23.cia.service.InformationService#getCurrentList()
	 */
	public final List<ParliamentMember> getCurrentList() {
		return parliamentMemberDAO.getCurrentList();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.hack23.cia.service.LoaderService#updateParliamentMembersEnglishWikiHref
	 * (java.util.Map)
	 */
	@Override
	public final void updateParliamentMembersEnglishWikiHref(
			final Map<Long, String> updates) {
		List<ParliamentMember> list = new ArrayList<ParliamentMember>();
		for (Entry<Long, String> entry : updates.entrySet()) {
			ParliamentMember parliamentMember = this.parliamentMemberDAO
					.load(entry.getKey());

			if (parliamentMember != null) {
				parliamentMember.setEnglishWikiHref(entry.getValue());
				list.add(parliamentMember);
			}
		}
		this.parliamentMemberDAO.saveAll(list);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.hack23.cia.service.InformationService#updateParliamentMembersHref
	 * (java.util.Map)
	 */
	@Override
	public final void updateParliamentMembersHref(
			final Map<Long, String> updates) {
		List<ParliamentMember> list = new ArrayList<ParliamentMember>();
		for (Entry<Long, String> entry : updates.entrySet()) {
			ParliamentMember parliamentMember = this.parliamentMemberDAO
					.load(entry.getKey());

			if (parliamentMember != null) {
				parliamentMember.setHref(entry.getValue());
				list.add(parliamentMember);
			}
		}
		this.parliamentMemberDAO.saveAll(list);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.hack23.cia.service.LoaderService#updateParliamentMembersWikiHref(
	 * java.util.Map)
	 */
	@Override
	public final void updateParliamentMembersWikiHref(
			final Map<Long, String> updates) {
		List<ParliamentMember> list = new ArrayList<ParliamentMember>();
		for (Entry<Long, String> entry : updates.entrySet()) {
			ParliamentMember parliamentMember = this.parliamentMemberDAO
					.load(entry.getKey());

			if (parliamentMember != null) {
				parliamentMember.setWikiHref(entry.getValue());
				list.add(parliamentMember);
			}
		}
		this.parliamentMemberDAO.saveAll(list);
	}
	
}
