/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.impl.admin;

import gnu.trove.THashMap;

import java.util.Date;
import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.hack23.cia.model.sweden.impl.Ballot;
import com.hack23.cia.model.sweden.impl.CommitteeReport;
import com.hack23.cia.model.sweden.impl.ParliamentMember;
import com.hack23.cia.model.sweden.impl.PoliticalParty;
import com.hack23.cia.service.impl.agent.sweden.BallotAgent;
import com.hack23.cia.service.impl.agent.sweden.CommitteeReportAgent;
import com.hack23.cia.service.impl.agent.sweden.ParliamentMemberAgent;
import com.hack23.cia.service.impl.agent.sweden.PoliticalPartyAgent;

/**
 * The Class LoaderTask.
 */
public class LoaderTask implements Runnable {

    /** The Constant BET_2007_08. */
    private static final String BET_2007_08 = "bet=2009"; //$NON-NLS-1$

    /** The Constant LOGGER. */
    private static final Log LOGGER = LogFactory.getLog(LoaderTask.class);

    /** The ballot agent. */
    private final BallotAgent ballotAgent;
    
    /** The commitee report agent. */
    private final CommitteeReportAgent commiteeReportAgent;

    /** The disabled. */
    private final boolean disabled;

    /** The loader service. */
    private final LoaderService loaderService;

    /** The parliament member agent. */
    private final ParliamentMemberAgent parliamentMemberAgent;
    
    /** The political party agent. */
    private final PoliticalPartyAgent politicalPartyAgent;

    /**
     * Instantiates a new loader task.
     *
     * @param commiteeReportAgent the commitee report agent
     * @param ballotAgent the ballot agent
     * @param parliamentMemberAgent the parliament member agent
     * @param politicalPartyAgent the political party agent
     * @param loaderService the loader service
     * @param disabled the disabled
     */
    public LoaderTask(final CommitteeReportAgent commiteeReportAgent,final BallotAgent ballotAgent,
            final ParliamentMemberAgent parliamentMemberAgent,final PoliticalPartyAgent politicalPartyAgent,
            final LoaderService loaderService, final boolean disabled) {
        super();
        this.commiteeReportAgent = commiteeReportAgent;
		this.ballotAgent = ballotAgent;
        this.parliamentMemberAgent = parliamentMemberAgent;
		this.politicalPartyAgent = politicalPartyAgent;
        this.loaderService = loaderService;
        this.disabled = disabled;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Runnable#run()
     */
    @Override
    public final void run() {
        LOGGER.info("Job Started"); //$NON-NLS-1$

        if (!disabled) {
            try {
            	
            	try {            		
            		this.parliamentMemberAgent.initData();            		
            	} catch (Exception e) {
					LOGGER.error("Problem importing wiki data" );
				}

            	
            	try {
            		List<PoliticalParty> politicalParties = politicalPartyAgent.getCurrentList();
            		
            		for (PoliticalParty politcalParty : politicalParties) {
            			loaderService.addIfNotExist(politcalParty);
            		}            		
            	} catch (Exception e) {
					LOGGER.error("Problem importing parties" );
				}


            	try {
            		List<CommitteeReport> currentList = commiteeReportAgent
            		.getCurrentList();
            		
            		for (CommitteeReport commiteeReport : currentList) {
            			loaderService.addIfNotExist(commiteeReport);
            		}            		
            	} catch (Exception e) {
					LOGGER.error("Problem importing part:" );
				}

            	
            	try {
            		for (CommitteeReport commiteeReport : loaderService
            				.getAllCreatedCommitteeReports()) {
            			
            			if (commiteeReport.getHref().contains(BET_2007_08)) {
            				Date decidedDateIfAny = commiteeReportAgent
            				.getDecidedDateIfAny(commiteeReport);
            				if (decidedDateIfAny != null) {
            					loaderService.addCommitteeReportInformation(
            							commiteeReport.getId(), decidedDateIfAny,
            							ballotAgent
            							.findBallots(commiteeReport));
            				}
            			}
            		}
            		
            		
            	} catch (Exception e) {
					LOGGER.error("Problem importing part:" );
				}


                
            	try {
            		
            		for (Ballot ballot : loaderService.getAllCreatedBallotar()) {
            			try {
            				if (ballot.getCommiteeReport().getHref().contains(
            						BET_2007_08)) {
            					loaderService.addBallotInformation(ballot.getId(),
            							ballotAgent.getVoteResult(ballot));
            				}
            			} catch (RuntimeException runtimeException) {
            				LOGGER
            				.error(
            						"Rollback done : Ballot problem " + ballot.getDescription() + " " + ballot.getOverviewHref() + " " + ballot.getVoteResultsHref(), runtimeException); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
            			}
            			
            		}
            		
            	} catch (Exception e) {
					LOGGER.error("Problem importing part:" );
				}

            	
            	try {
            		
            		this.loaderService.generateParliamentCharts();
            		
            	} catch (Exception e) {
					LOGGER.error("Problem importing part:" );
				}


            	try {
            		for (PoliticalParty politicalParty : this.loaderService.getAllPoliticalParties()) {
            			this.loaderService.generatePoliticalPartyCharts(politicalParty.getId());
            		}
            		
            		for (Ballot ballot : this.loaderService.getAllBallots()) {
            			this.loaderService.generateBallotCharts(ballot.getId());
            		}
            		
            		//            	this.loaderService.generateCommitteeReportCharts();
            		//            	
            		
            		for (ParliamentMember parliamentMember : loaderService.getCurrentList()) {
            			this.loaderService.generateParliamentMemberCharts(parliamentMember.getId());
            		}
            		
            		
            	} catch (Exception e) {
					LOGGER.error("Problem importing part:" );
				}

            	
            	try {
            		
            		updateRiksLedamotsHomePagesRef();
            		updateRiksLedamotsWikiRef();
            		updateRiksLedamotsEnglishWikiRef();
            		
            	} catch (Exception e) {
					LOGGER.error("Problem importing part:" );
				}

            	try {
                    this.loaderService.deleteParliamentMemberVoteCompareResults();
                    LOGGER.info("Deleted ParliamentMemberVoteCompareResults"); //$NON-NLS-1$
                    this.loaderService.createParliamentMemberVoteCompareResults();
                    LOGGER.info("Created ParliamentMemberVoteCompareResults"); //$NON-NLS-1$            		
            	} catch (Exception e) {
					LOGGER.error("Problem importing part:" );
				}
            	

            	
            } catch (Exception e) {
                LOGGER.error("Job Failed", e); //$NON-NLS-1$
            }
        }
        LOGGER.info("Job Ended"); //$NON-NLS-1$
    }

    /**
     * Update riks ledamots english wiki ref.
     */
    private void updateRiksLedamotsEnglishWikiRef() {
        final Map<Long, String> updates = new THashMap<Long, String>();
        for (ParliamentMember parliamentMember : loaderService.getCurrentList()) {
            if (parliamentMember.getEnglishWikiHref() == null) {
                final String href = this.parliamentMemberAgent
                        .getEnglishWikiHref(parliamentMember);
                if (href != null) {
                    updates.put(parliamentMember.getId(), href);
                }
            }
        }
        loaderService.updateParliamentMembersEnglishWikiHref(updates);
    }

    /**
     * Update riks ledamots home pages ref.
     */
    private void updateRiksLedamotsHomePagesRef() {
        final Map<Long, String> updates = new THashMap<Long, String>();
        for (ParliamentMember parliamentMember : loaderService.getCurrentList()) {
            if (parliamentMember.getHref() == null) {
                final String href = this.parliamentMemberAgent
                        .getHref(parliamentMember);
                if (href != null) {
                    updates.put(parliamentMember.getId(), href);
                }
            }
        }
        loaderService.updateParliamentMembersHref(updates);
    }

    /**
     * Update riks ledamots wiki ref.
     */
    private void updateRiksLedamotsWikiRef() {
        final Map<Long, String> updates = new THashMap<Long, String>();
        for (ParliamentMember parliamentMember : loaderService.getCurrentList()) {
            if (parliamentMember.getWikiHref() == null) {
                final String href = this.parliamentMemberAgent
                        .getWikiHref(parliamentMember);
                if (href != null) {
                    updates.put(parliamentMember.getId(), href);
                }
            }
        }
        loaderService.updateParliamentMembersWikiHref(updates);
    }
}
