/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.service.impl.admin;

import java.util.Date;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.admin.MonitorActionEvent;
import com.hack23.cia.model.application.impl.common.ActionEvent;
import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.service.api.admin.MonitorRequest;
import com.hack23.cia.service.api.admin.MonitorResponse;
import com.hack23.cia.service.api.common.ServiceResponse;
import com.hack23.cia.service.impl.common.UserSessionService;

/**
 * The Class MonitorRequestService.
 */
public class MonitorRequestService extends
        AbstractAdminRequestService<MonitorRequest> {

    /**
     * Instantiates a new monitor request service.
     *
     * @param userSessionService the user session service
     * @param adminService the admin service
     */
    public MonitorRequestService(final UserSessionService userSessionService,
            final AdminService adminService) {
        super(userSessionService, adminService);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.impl.common.AbstractGenericService#createActionEvent
     * (com.hack23.cia.service.api.common.AbstractServiceRequest,
     * com.hack23.cia.model.application.UserSession)
     */
    @Override
    public final ActionEvent createActionEvent(final MonitorRequest request,
            final UserSession userSession) {
        return new MonitorActionEvent(new Date(), userSession, request
                .getOperation());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.common.ServiceHandler#getSupportedService()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedService() {
        return MonitorRequest.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.service.common.AbstractGenericServiceHandler#
     * handleServiceRequest(com.hack23.cia.service.api.AbstractServiceRequest)
     */
    @Override
    public final ServiceResponse handleServiceRequest(
            final MonitorRequest request, final UserSessionDTO userSession) {
        MonitorResponse monitorResponse = null;
        switch (request.getOperation()) {
        case RecentActions:
            monitorResponse = new MonitorResponse(userSession, this
                    .getAdminService().getRecentActionsGraph());
            break;
        case ResponseTime:
            monitorResponse = new MonitorResponse(userSession, this
                    .getAdminService().createResponseTimeGraph());
            break;
        default:
            break;
        }

        return monitorResponse;
    }
}
