/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.impl.agent.sweden;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.gargoylesoftware.htmlunit.WebClient;
import com.gargoylesoftware.htmlunit.html.HtmlPage;
import com.gargoylesoftware.htmlunit.html.HtmlTable;
import com.gargoylesoftware.htmlunit.html.HtmlTableRow;
import com.hack23.cia.model.sweden.impl.PoliticalParty;

/**
 * The Class PoliticalPartyAgentImpl.
 */
public class PoliticalPartyAgentImpl implements PoliticalPartyAgent {

	/** The Constant LAST_ELECTION_RESULT. */
	private static final String LAST_ELECTION_RESULT = "http://www.val.se/val/val2006/slutlig/R/rike/roster.html";

	/** The Constant LOGGER. */
	private static final Log LOGGER = LogFactory
			.getLog(PoliticalPartyAgentImpl.class);

	/** The web client. */
	private final WebClient webClient;

	/**
	 * Instantiates a new political party agent impl.
	 *
	 * @param webClient the web client
	 */
	public PoliticalPartyAgentImpl(final WebClient webClient) {
		super();
		this.webClient = webClient;
		this.webClient.setJavaScriptEnabled(false);
	}

	/* (non-Javadoc)
	 * @see com.hack23.cia.service.impl.agent.sweden.PoliticalPartyAgent#getCurrentList()
	 */
	@Override
	public final List<PoliticalParty> getCurrentList() {
		List<PoliticalParty> result = new ArrayList<PoliticalParty>();

		try {
			HtmlPage page = (HtmlPage) webClient.getPage(LAST_ELECTION_RESULT);

			List<HtmlTable> tables = page.getDocumentElement()
					.getElementsByAttribute("table", "class",
							"rostfordelning");

			HtmlTable htmlTable = tables.get(0);
			List<HtmlTableRow> rows = htmlTable.getRows();
			int startRow = 2;

			for (int i = startRow; i < (rows.size() - 1); i++) {
				HtmlTableRow htmlTableRow = rows.get(i);

				PoliticalParty politicalParty = new PoliticalParty();
				politicalParty.setShortCode(htmlTableRow.getCell(0).asText().toLowerCase().trim());
				politicalParty.setName(htmlTableRow.getCell(1).asText());
				result.add(politicalParty);
			}
		} catch (Exception e) {
			LOGGER.warn("Problem accessing Politicalparties", e); //$NON-NLS-1$
		}

		return result;
	}

}
