/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.impl.application;

import gnu.trove.THashMap;

import java.util.List;
import java.util.Map;

import com.hack23.cia.service.api.application.ApplicationManager;
import com.hack23.cia.service.api.common.ServiceRequest;
import com.hack23.cia.service.api.common.ServiceResponse;
import com.hack23.cia.service.impl.common.BusinessService;

/**
 * The Class ApplicationManagerImpl.
 */
public class ApplicationManagerImpl implements ApplicationManager {

    /** The default business service. */
    private final BusinessService defaultBusinessService;

    /** The service request business service map. */
    private Map<Class<ServiceRequest>, BusinessService> serviceRequestBusinessServiceMap = new THashMap<Class<ServiceRequest>, BusinessService>();
    
    /**
     * Instantiates a new application manager impl.
     *
     * @param businessServices the business services
     * @param defaultBusinessService the default business service
     */
    public ApplicationManagerImpl(final List<BusinessService> businessServices,final BusinessService defaultBusinessService) {
        super();
        this.defaultBusinessService = defaultBusinessService;
        for (BusinessService serviceHandler : businessServices) {
            serviceRequestBusinessServiceMap.put(serviceHandler
                    .getSupportedService(), serviceHandler);
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.ApplicationManager#service(com.hack23.cia.service
     * .api.ServiceRequest)
     */
    @Override
    public final ServiceResponse service(final ServiceRequest serviceRequest) {
        BusinessService businessService = serviceRequestBusinessServiceMap
                .get(serviceRequest.getClass());
        ServiceResponse serviceResponse = null;

        if (businessService != null) {
            serviceResponse = businessService.processService(serviceRequest);
        } else {
            serviceResponse = defaultBusinessService.processService(serviceRequest);
        }

        return serviceResponse;
    }

}
