/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.service.impl.application;

import java.util.Date;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.ActionEvent;
import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.model.application.impl.user.ApplicationActionEvent;
import com.hack23.cia.service.api.application.ApplicationRequest;
import com.hack23.cia.service.api.application.ApplicationResponse;
import com.hack23.cia.service.api.application.ApplicationRequest.HeaderAttributeKey;
import com.hack23.cia.service.api.common.AbstractServiceRequest;
import com.hack23.cia.service.api.common.ErrorResponse;
import com.hack23.cia.service.api.common.ServiceResponse;
import com.hack23.cia.service.impl.common.AbstractGenericService;
import com.hack23.cia.service.impl.common.ParliamentService;
import com.hack23.cia.service.impl.common.UserSessionService;

/**
 * The Class ApplicationRequestService.
 */
public class ApplicationRequestService extends
        AbstractGenericService<ApplicationRequest> {

    /** The parliament service. */
    private final ParliamentService parliamentService;

    /**
     * Instantiates a new application request service.
     *
     * @param userSessionService the user session service
     * @param parliamentService the parliament service
     */
    public ApplicationRequestService(
            final UserSessionService userSessionService,
            final ParliamentService parliamentService) {
        super(userSessionService);
        this.parliamentService = parliamentService;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.impl.common.AbstractGenericService#createActionEvent
     * (com.hack23.cia.service.api.common.AbstractServiceRequest,
     * com.hack23.cia.model.application.UserSession)
     */
    @Override
    public final ActionEvent createActionEvent(
            final ApplicationRequest request, final UserSession userSession) {
        return new ApplicationActionEvent(new Date(), userSession);
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.common.ServiceHandler#getSupportedService()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedService() {
        return ApplicationRequest.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.service.common.AbstractGenericServiceHandler#
     * handleServiceRequest(com.hack23.cia.service.api.AbstractServiceRequest)
     */
    @Override
    public final ServiceResponse handleServiceRequest(
            final ApplicationRequest request, final UserSessionDTO userSessionDTO) {
        ServiceResponse serviceResponse = null;
        UserSession userSession = userSessionDTO.getUserSession();

        if ((userSession.getPortal() != null)
                && (userSession.getLanguage() != null)) {
            serviceResponse = new ApplicationResponse(userSessionDTO, userSession
                    .getPortal().getAgency(), parliamentService
                    .getLastDecidedCommiteeReports(),parliamentService.getPoliticalParties());
        } else { 
            serviceResponse = new ErrorResponse(userSessionDTO,
                    "No matching portal or language:");
        }

        return serviceResponse;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.common.AbstractGenericService#lookupUserSession
     * (com.hack23.cia.service.api.AbstractServiceRequest)
     */
    @Override
    public final UserSession lookupUserSession(
            final AbstractServiceRequest request) {
        ApplicationRequest applicationRequest = (ApplicationRequest) request;

        UserSession userSession = getUserSessionService()
                .createUserSession(
                        applicationRequest
                                .getHeaderAttribute(HeaderAttributeKey.HEADER_COOKIE),
                        applicationRequest
                                .getHeaderAttribute(HeaderAttributeKey.CLIENT_INFO_ADDRESS),
                        applicationRequest
                                .getHeaderAttribute(HeaderAttributeKey.HEADER_HOST),
                        applicationRequest.getAcceptLanguage(),applicationRequest.getUserAgent());
        return userSession;
    }
}
