/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.service.impl.common;

import java.util.List;

import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.ImageContent;
import com.hack23.cia.model.application.impl.common.Language;
import com.hack23.cia.model.sweden.impl.Ballot;
import com.hack23.cia.model.sweden.impl.ParliamentMember;
import com.hack23.cia.model.sweden.impl.PoliticalParty;

/**
 * The Interface ChartService.
 */
public interface ChartService {

    /**
     * Creates the recent actions graph.
     *
     * @param actionEventHistory the action event history
     * @return the image content
     */
	@SuppressWarnings("unchecked")
	ImageContent createRecentActionsGraph(List actionEventHistory);

    /**
     * Creates the response time graph.
     *
     * @param responseTimeHistory the response time history
     * @return the image content
     */
    @SuppressWarnings("unchecked")
	ImageContent createResponseTimeGraph(List responseTimeHistory);

    /**
     * Generate ballot charts.
     *
     * @param agency the agency
     * @param ballot the ballot
     * @param allPoliticalParties the all political parties
     * @param language the language
     * @return the list
     */
	List<ImageContent> generateBallotCharts(Agency agency,
			Ballot ballot, List<PoliticalParty> allPoliticalParties,
			Language language);

	/**
	 * Generate committee report charts.
	 *
	 * @param agency the agency
	 * @param allBallots the all ballots
	 * @param allPoliticalParties the all political parties
	 * @param language the language
	 * @return the list
	 */
	List<ImageContent> generateCommitteeReportCharts(Agency agency,
			List<Ballot> allBallots, List<PoliticalParty> allPoliticalParties,
			Language language);

	/**
	 * Generate parliament charts.
	 *
	 * @param agency the agency
	 * @param ballots the ballots
	 * @param politicalParties the political parties
	 * @param language the language
	 * @return the list
	 */
    List<ImageContent> generateParliamentCharts(Agency agency, List<Ballot> ballots,List<PoliticalParty> politicalParties, Language language);

	/**
	 * Generate parliament member charts.
	 *
	 * @param agency the agency
	 * @param allBallots the all ballots
	 * @param parliamentMember the parliament member
	 * @param allPoliticalParties the all political parties
	 * @param language the language
	 * @return the list
	 */
	List<ImageContent> generateParliamentMemberCharts(Agency agency,
			List<Ballot> allBallots,ParliamentMember parliamentMember, List<PoliticalParty> allPoliticalParties,
			Language language);

	/**
	 * Generate political party charts.
	 *
	 * @param agency the agency
	 * @param allBallots the all ballots
	 * @param politicalParty the political party
	 * @param language the language
	 * @return the list
	 */
	List<ImageContent> generatePoliticalPartyCharts(Agency agency,
			List<Ballot> allBallots, PoliticalParty politicalParty,
			Language language);

    
}