/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.service.impl.common;

import java.util.Date;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.ActionEvent;
import com.hack23.cia.model.application.impl.common.ApplicationErrorActionEvent;
import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.service.api.common.AbstractServiceRequest;
import com.hack23.cia.service.api.common.ErrorResponse;
import com.hack23.cia.service.api.common.ServiceRequest;
import com.hack23.cia.service.api.common.ServiceResponse;

/**
 * The Class DefaultRequestService.
 */
public class DefaultRequestService extends
        AbstractGenericService<AbstractServiceRequest> {

    /**
     * Instantiates a new default request service.
     *
     * @param userSessionService the user session service
     */
    public DefaultRequestService(
            final UserSessionService userSessionService) {
        super(userSessionService);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.impl.common.AbstractGenericService#createActionEvent
     * (com.hack23.cia.service.api.common.AbstractServiceRequest,
     * com.hack23.cia.model.application.UserSession)
     */
    @Override
    public final ActionEvent createActionEvent(
            final AbstractServiceRequest request, final UserSession userSession) {
        
        return new ApplicationErrorActionEvent(new Date(), userSession,null,"Request not implemented:" + request.getClass().getSimpleName());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.common.ServiceHandler#getSupportedService()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedService() {
        return ServiceRequest.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.service.common.AbstractGenericServiceHandler#
     * handleServiceRequest(com.hack23.cia.service.api.AbstractServiceRequest)
     */
    @Override
    public final ServiceResponse handleServiceRequest(
            final AbstractServiceRequest request, final UserSessionDTO userSession) {
        ErrorResponse response = new ErrorResponse(userSession, "Request not implemented:" + request.getClass().getSimpleName());
        return response;
    }
    
    /* (non-Javadoc)
     * @see com.hack23.cia.service.impl.common.AbstractGenericService#lookupUserSession(com.hack23.cia.service.api.common.AbstractServiceRequest)
     */
    @Override
    public final UserSession lookupUserSession(
            final AbstractServiceRequest request) {
        UserSession userSession = getUserSessionService().loadUserSessionById(
                request.getUserSessionId());
        return userSession;
    }


}
