/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.service.impl.common;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.hack23.cia.model.application.impl.common.ImageContent;
import com.hack23.cia.service.api.common.ImageContentRequest;
import com.hack23.cia.service.api.common.ImageContentResponse;
import com.hack23.cia.service.api.common.ServiceRequest;
import com.hack23.cia.service.api.common.ServiceResponse;
import com.hack23.cia.service.dao.ResourceDAO;

/**
 * The Class ImageContentRequestService.
 */
@Transactional(propagation = Propagation.REQUIRED)
public  class ImageContentRequestService
        implements BusinessService {
    
    /** The Constant LOGGER. */
    private static final Log LOGGER = LogFactory
            .getLog(ImageContentRequestService.class);

    /** The resource dao. */
    private final ResourceDAO resourceDAO;

    /**
     * Instantiates a new image content request service.
     *
     * @param resourceDAO the resource dao
     */
    public ImageContentRequestService(final ResourceDAO resourceDAO) {
        super();
		this.resourceDAO = resourceDAO;
    }

	/* (non-Javadoc)
	 * @see com.hack23.cia.service.impl.common.BusinessService#getSupportedService()
	 */
	@Override
	public final Class getSupportedService() {
		return ImageContentRequest.class;
	}

	/* (non-Javadoc)
	 * @see com.hack23.cia.service.impl.common.BusinessService#processService(com.hack23.cia.service.api.common.ServiceRequest)
	 */
	@Override
	public final ServiceResponse processService(final ServiceRequest serviceRequest) {
		ImageContentRequest request = (ImageContentRequest) serviceRequest;
    	ImageContent imageContent = resourceDAO.getImageContentByFileName(request.getFileName());
    	LOGGER.info("Got image :"  + imageContent);
		return new ImageContentResponse(null, imageContent);
	}

}
