/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.impl.common;

import java.util.List;

import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.hack23.cia.model.application.impl.common.ImageContent;
import com.hack23.cia.model.application.impl.common.Language;
import com.hack23.cia.model.application.impl.common.ParliamentChart;
import com.hack23.cia.model.sweden.impl.Ballot;
import com.hack23.cia.model.sweden.impl.CommitteeReport;
import com.hack23.cia.model.sweden.impl.ParliamentMember;
import com.hack23.cia.model.sweden.impl.ParliamentMemberVoteCompareResult;
import com.hack23.cia.model.sweden.impl.PoliticalParty;
import com.hack23.cia.model.sweden.impl.RegisterInformation;
import com.hack23.cia.model.sweden.impl.Vote;
import com.hack23.cia.service.dao.BallotDAO;
import com.hack23.cia.service.dao.CommitteeReportDAO;
import com.hack23.cia.service.dao.ParliamentMemberDAO;
import com.hack23.cia.service.dao.PoliticalPartyDAO;
import com.hack23.cia.service.dao.ResourceDAO;
import com.hack23.cia.service.impl.agent.sweden.ParliamentMemberRegisterAgent;

/**
 * The Class ParliamentServiceImpl.
 */
@Transactional(propagation=Propagation.REQUIRED)
public class ParliamentServiceImpl implements ParliamentService {

	/** The ballot dao. */
    private final BallotDAO ballotDAO;
	
    /** The commitee report dao. */
    private final CommitteeReportDAO commiteeReportDAO;

    /** The parliament member dao. */
    private final ParliamentMemberDAO parliamentMemberDAO;

    /** The parliament member register agent. */
    private final ParliamentMemberRegisterAgent parliamentMemberRegisterAgent;

    /** The political party dao. */
	private final PoliticalPartyDAO politicalPartyDAO;
    
    /** The resource dao. */
    private final ResourceDAO resourceDAO;
    
    
    
    /**
     * Instantiates a new parliament service impl.
     *
     * @param politicalPartyDAO the political party dao
     * @param commiteeReportDAO the commitee report dao
     * @param parliamentMemberDAO the parliament member dao
     * @param parliamentMemberRegisterAgent the parliament member register agent
     * @param resourceDAO the resource dao
     * @param ballotDAO the ballot dao
     */
    public ParliamentServiceImpl(final PoliticalPartyDAO politicalPartyDAO,final CommitteeReportDAO commiteeReportDAO,
            final ParliamentMemberDAO parliamentMemberDAO,
            final ParliamentMemberRegisterAgent parliamentMemberRegisterAgent,final ResourceDAO resourceDAO,final BallotDAO ballotDAO) {
        super();
		this.politicalPartyDAO = politicalPartyDAO;
        this.commiteeReportDAO = commiteeReportDAO;
        this.parliamentMemberDAO = parliamentMemberDAO;
        this.parliamentMemberRegisterAgent = parliamentMemberRegisterAgent;
		this.resourceDAO = resourceDAO;
		this.ballotDAO = ballotDAO;

        try {
            this.parliamentMemberRegisterAgent.init();
        } catch (Exception e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#findLastVotes(java.lang.Long)
     */
    @Override
    public final List<Vote> findLastVotes(final Long id) {
        return parliamentMemberDAO.findLastVotes(id);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#findLastVotesByBallotId(java
     * .lang.Long)
     */
    @Override
    public final List<Vote> findLastVotesByBallotId(final Long id) {
        return parliamentMemberDAO.findLastVotesByBallotId(id);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#findParliamentMembersByName
     * (java.lang.String)
     */
    @Override
    public final List<ParliamentMember> findParliamentMembersByName(
            final String searchString) {

        return parliamentMemberDAO.findListByName(searchString);
    }

    /* (non-Javadoc)
	 * @see com.hack23.cia.service.impl.common.ParliamentService#findPoliticalPartyByShortCode(java.lang.String)
	 */
	@Override
	public final PoliticalParty findPoliticalPartyByShortCode(final String partyShortCode) {
		return politicalPartyDAO.findByShortCode(partyShortCode);
	}

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.InformationService#findVotes(java.lang.Long)
     */
    @Override
    public final List<Vote> findVotes(final Long id) {
        return parliamentMemberDAO.findVotes(id);
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.InformationService#getAllBetankanden()
     */
    @Override
    public final List<CommitteeReport> getAllCommiteeReports() {
        return commiteeReportDAO.getAllLastDecided();
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.InformationService#getCurrentList()
     */
    public final List<ParliamentMember> getCurrentList() {
        return parliamentMemberDAO.getCurrentList();
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#getCurrentTopListAbsent(int)
     */
    @Override
    public final List<ParliamentMember> getCurrentTopListAbsent(final int number) {
        return parliamentMemberDAO.getCurrentTopListAbsent(number);

    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#getCurrentTopListAbsentInParty
     * (int, java.lang.String)
     */
    @Override
    public final List<ParliamentMember> getCurrentTopListAbsentInParty(
            final int i, final String party) {
        return parliamentMemberDAO.getCurrentTopListAbsentByParty(i, party);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#getCurrentTopListLosers(int)
     */
    @Override
    public final List<ParliamentMember> getCurrentTopListLosers(final int i) {
        return parliamentMemberDAO.getCurrentTopListLosers(i);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#getCurrentTopListLosersInParty
     * (int, java.lang.String)
     */
    @Override
    public final List<ParliamentMember> getCurrentTopListLosersInParty(
            final int i, final String party) {
        return parliamentMemberDAO.getCurrentTopListLosersByParty(i, party);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#getCurrentTopListLoyal(int)
     */
    @Override
    public final List<ParliamentMember> getCurrentTopListLoyal(final int i) {
        return parliamentMemberDAO.getCurrentTopListLoyal(i);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#getCurrentTopListLoyalInParty
     * (int, java.lang.String)
     */
    @Override
    public final List<ParliamentMember> getCurrentTopListLoyalInParty(
            final int i, final String party) {
        return parliamentMemberDAO.getCurrentTopListLoyalByParty(i, party);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#getCurrentTopListPresent(int)
     */
    @Override
    public final List<ParliamentMember> getCurrentTopListPresent(final int i) {
        return parliamentMemberDAO.getCurrentTopListPresent(i);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#getCurrentTopListPresentInParty
     * (int, java.lang.String)
     */
    @Override
    public final List<ParliamentMember> getCurrentTopListPresentInParty(
            final int i, final String party) {
        return parliamentMemberDAO.getCurrentTopListPresentByParty(i, party);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#getCurrentTopListRebels(int)
     */
    @Override
    public final List<ParliamentMember> getCurrentTopListRebels(final int i) {
        return parliamentMemberDAO.getCurrentTopListRebels(i);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#getCurrentTopListRebelsInParty
     * (int, java.lang.String)
     */
    @Override
    public final List<ParliamentMember> getCurrentTopListRebelsInParty(
            final int i, final String party) {
        return parliamentMemberDAO.getCurrentTopListRebelsByParty(i, party);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#getCurrentTopListWinners(int)
     */
    @Override
    public final List<ParliamentMember> getCurrentTopListWinners(final int i) {
        return parliamentMemberDAO.getCurrentTopListWinners(i);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#getCurrentTopListWinnersInParty
     * (int, java.lang.String)
     */
    @Override
    public final List<ParliamentMember> getCurrentTopListWinnersInParty(
            final int i, final String party) {
        return parliamentMemberDAO.getCurrentTopListWinnersByParty(i, party);
    }

    /* (non-Javadoc)
	 * @see com.hack23.cia.service.impl.common.ParliamentService#getGraph(com.hack23.cia.model.application.impl.common.ParliamentChart, java.lang.Long, com.hack23.cia.model.application.impl.common.Language)
	 */
	@Override
	public final ImageContent getGraph(final ParliamentChart chart, final Ballot ballot,
			final Language language) {
		return resourceDAO.getImageContentByFileName(ParliamentChart.getFileName(chart, ballot, language));
	}

    /* (non-Javadoc)
	 * @see com.hack23.cia.service.impl.common.ParliamentService#getGraph(com.hack23.cia.model.application.impl.common.ParliamentChart, com.hack23.cia.model.sweden.impl.CommitteeReport, com.hack23.cia.model.application.impl.common.Language)
	 */
	@Override
	public final ImageContent getGraph(final ParliamentChart chart, final CommitteeReport committeeReport,
			final Language language) {
		return resourceDAO.getImageContentByFileName(ParliamentChart.getFileName(chart, committeeReport, language));
	}

    /* (non-Javadoc)
	 * @see com.hack23.cia.service.impl.common.ParliamentService#getGraph(com.hack23.cia.model.application.impl.common.ParliamentChart)
	 */
	public final ImageContent getGraph(final ParliamentChart chart,final Language language) {
		return resourceDAO.getImageContentByFileName(ParliamentChart.getFileName(chart, language));
	}

    /* (non-Javadoc)
	 * @see com.hack23.cia.service.impl.common.ParliamentService#getGraph(com.hack23.cia.model.application.impl.common.ParliamentChart, com.hack23.cia.model.sweden.impl.ParliamentMember)
	 */
	public final ImageContent getGraph(final ParliamentChart chart,final ParliamentMember parliamentMember,final Language language) {
		return resourceDAO.getImageContentByFileName(ParliamentChart.getFileName(chart, parliamentMember, language));
	}

    /* (non-Javadoc)
	 * @see com.hack23.cia.service.impl.common.ParliamentService#getGraph(com.hack23.cia.model.application.impl.common.ParliamentChart, com.hack23.cia.model.sweden.impl.PoliticalParty)
	 */
	public final ImageContent getGraph(final ParliamentChart chart,final PoliticalParty politicalParty,final Language language) {
		return resourceDAO.getImageContentByFileName(ParliamentChart.getFileName(chart, politicalParty, language));
	}

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#getLastDecidedCommiteeReports()
     */
    @Override
    public final List<CommitteeReport> getLastDecidedCommiteeReports() {
        return commiteeReportDAO.getLastDecided();
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#getParliamentMember(com.hack23
     * .cia.model.sweden.ParliamentMember)
     */
    @Override
    public final ParliamentMember getParliamentMember(
            final Long parliamentMemberId) {
        return this.parliamentMemberDAO.load(parliamentMemberId);
    }

	/*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#getParliamentMemberEnemies(
     * com.hack23.cia.model.sweden.ParliamentMember)
     */
    @Override
    public final List<ParliamentMemberVoteCompareResult> getParliamentMemberEnemies(
            final ParliamentMember parliamentMember) {
        return parliamentMemberDAO.getTopEnemies(parliamentMember);
    }
	
	/*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#getParliamentMemberFriends(
     * com.hack23.cia.model.sweden.ParliamentMember)
     */
    @Override
    public final List<ParliamentMemberVoteCompareResult> getParliamentMemberFriends(
            final ParliamentMember parliamentMember) {
        return parliamentMemberDAO.getTopFriends(parliamentMember);
    }
	
	/*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#getParliamentMemberPartyEnemies
     * (com.hack23.cia.model.sweden.ParliamentMember)
     */
    @Override
    public final List<ParliamentMemberVoteCompareResult> getParliamentMemberPartyEnemies(
            final ParliamentMember parliamentMember) {
        return this.parliamentMemberDAO
                .getTopEnemiesSameParty(parliamentMember);
    }

	/*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#getParliamentMemberPartyFriends
     * (com.hack23.cia.model.sweden.ParliamentMember)
     */
    @Override
    public final List<ParliamentMemberVoteCompareResult> getParliamentMemberPartyFriends(
            final ParliamentMember parliamentMember) {
        return this.parliamentMemberDAO
                .getTopFriendsInSameParty(parliamentMember);
    }

	/* (non-Javadoc)
	 * @see com.hack23.cia.service.impl.common.ParliamentService#getPoliticalParties()
	 */
	@Override
	public final List<PoliticalParty> getPoliticalParties() {
		return politicalPartyDAO.getAll();
	}	
	
	/* (non-Javadoc)
	 * @see com.hack23.cia.service.impl.common.ParliamentService#loadBallotById(java.lang.Long)
	 */
	@Override
	public final Ballot loadBallotById(final Long ballotId) {
		return ballotDAO.load(ballotId);
	}

	/*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.user.UserService#loadCommitteeReportById(java.
     * lang.Long)
     */
    @Override
    public final CommitteeReport loadCommitteeReportById(
            final Long committeeReportId) {
        return commiteeReportDAO.load(committeeReportId);
    }

	/*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#lookupRegisterInformation(com
     * .hack23.cia.model.sweden.ParliamentMember)
     */
    @Override
    public final RegisterInformation lookupRegisterInformation(
            final ParliamentMember member) {
        return parliamentMemberRegisterAgent.lookupRegisterInformation(member);
    }	

}
