/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.impl.common;

import com.hack23.cia.model.application.impl.common.ActionEvent;
import com.hack23.cia.model.application.impl.common.UserSession;

/**
 * The Interface UserSessionService.
 */
public interface UserSessionService {

    /**
     * Adds the action event.
     *
     * @param actionEvent the action event
     * @param userSession the user session
     * @return the user session
     */
    UserSession addActionEvent(ActionEvent actionEvent, UserSession userSession);

    /**
     * Creates the user session.
     *
     * @param sessionId the session id
     * @param headerHost the header host
     * @param serverHost the server host
     * @param acceptLanguageKeys the accept language keys
     * @param userAgent the user agent
     * @return the user session
     */
    UserSession createUserSession(String sessionId, String headerHost,
            String serverHost, String acceptLanguageKeys, String userAgent);

    /**
     * Load user session by id.
     *
     * @param userSessionId the user session id
     * @return the user session
     */
    UserSession loadUserSessionById(Long userSessionId);

    /**
     * Login.
     *
     * @param name the name
     * @param encodedPassword the encoded password
     * @param userSession the user session
     * @return the user session
     */
    UserSession login(String name, String encodedPassword,
            UserSession userSession);

    /**
     * Logout.
     *
     * @param userSession the user session
     * @return the user session
     */
    UserSession logout(UserSession userSession);
}
