/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.impl.common;

import java.util.Date;

import net.sf.ehcache.Cache;
import net.sf.ehcache.CacheManager;
import net.sf.ehcache.Element;

import org.hibernate.Hibernate;

import com.hack23.cia.model.application.impl.common.AbstractActionEvent;
import com.hack23.cia.model.application.impl.common.ActionEvent;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.Language;
import com.hack23.cia.model.application.impl.common.Portal;
import com.hack23.cia.model.application.impl.common.User;
import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.model.application.impl.common.User.UserRole;
import com.hack23.cia.service.dao.AgencyDAO;
import com.hack23.cia.service.dao.UserDAO;
import com.hack23.cia.service.dao.UserSessionDAO;

/**
 * The Class UserSessionServiceImpl.
 */
public class UserSessionServiceImpl implements UserSessionService {

    /** The agency dao. */
    private final AgencyDAO agencyDAO;

    /** The agency id. */
    private final long agencyId = 1;

    /** The user dao. */
    private final UserDAO userDAO;

    /** The user session dao. */
    private final UserSessionDAO userSessionDAO;
    
    /** The cache manager. */
    private final CacheManager cacheManager;

	/** The cache. */
	private Cache cache;

    /**
     * Instantiates a new user session service impl.
     *
     * @param agencyDAO the agency dao
     * @param userDAO the user dao
     * @param userSessionDAO the user session dao
     * @param cacheManager the cache manager
     */
    public UserSessionServiceImpl(final AgencyDAO agencyDAO,
            final UserDAO userDAO, final UserSessionDAO userSessionDAO,final CacheManager cacheManager) {
        super();
        this.agencyDAO = agencyDAO;
        this.userDAO = userDAO;
        this.userSessionDAO = userSessionDAO;
		this.cacheManager = cacheManager;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.impl.common.UserSessionService#addActionEvent(
     * com.hack23.cia.model.application.common.ActionEvent,
     * com.hack23.cia.model.application.common.UserSession)
     */
    @Override
    public final UserSession addActionEvent(final ActionEvent actionEvent,
            final UserSession userSession) {
        userSession.getEvents().add((AbstractActionEvent) actionEvent);
        return this.userSessionDAO.save(userSession);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.common.InformationService#createUserSession(java
     * .lang.String, java.lang.String, com.hack23.cia.model.application.Portal)
     */
    @Override
    public final UserSession createUserSession(final String sessionId,
            final String clientHost, final String serverHost,
            final String acceptLanguageKeys,final String userAgent) {
        Agency agency = loadAgency();
        Portal portal = agency.findMatchingPortal(serverHost);
        Language language = agency.findMatchingLanguage(acceptLanguageKeys);

        User user = new User();
        user.setCreatedDate(new Date());
        user.setUserRole(UserRole.ANYNOMOUS);
        UserSession userSession = new UserSession(user,language,portal,sessionId,clientHost,serverHost,new Date(),userAgent);
        return userSessionDAO.save(userSession);
    }

    /**
     * Load agency.
     *
     * @return the agency
     */
    private Agency loadAgency() {
    	
    	if (cache == null) {
    		cache = cacheManager.getCache("agencyCache");
    	}
 
    	Element element = cache.get(agencyId);
    	    	
    	Agency agency;
		if (element == null ) {
    		agency = this.agencyDAO.load(agencyId);
    		Hibernate.initialize(agency.getLanguageContent());
    		Hibernate.initialize(agency.getLanguages());
    		Hibernate.initialize(agency.getPortals());    		
    		
    		Element agencyElement = new Element(agencyId, agency);
    		cache.put(agencyElement);
    	} else {
    		agency = (Agency) element.getValue();
    	}
        
        return agency;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.user.UserService#loadUserSessionById(java.lang
     * .Long)
     */
    @Override
    public final UserSession loadUserSessionById(final Long userSessionId) {
        return this.userSessionDAO.load(userSessionId);
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.UserService#login(java.lang.String,
     * java.lang.String)
     */
    @Override
    public final UserSession login(final String name,
            final String encodedPassword, final UserSession userSession) {
        User ifValidUser = userDAO.getIfValidUser(name, encodedPassword);
        if (ifValidUser != null) {
            userSession.setUser(ifValidUser);
            this.userSessionDAO.save(userSession);
            return userSession;
        }
        return null;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.impl.user.UserService#logout(java.lang.Long,
     * com.hack23.cia.model.application.common.UserSession)
     */
    @Override
    public final UserSession logout(final UserSession userSession) {
        return userSession;
    }

}
