/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.service.impl.user;

import java.util.Date;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.ActionEvent;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.model.application.impl.user.ExternalUrlActionEvent;
import com.hack23.cia.service.api.common.ServiceResponse;
import com.hack23.cia.service.api.user.ExternalUrlRequest;
import com.hack23.cia.service.api.user.ExternalUrlResponse;
import com.hack23.cia.service.impl.common.UserSessionService;

/**
 * The Class ExternalUrlRequestService.
 */
public class ExternalUrlRequestService extends
        AbstractUserRequestService<ExternalUrlRequest> {

    /**
     * Instantiates a new external url request service.
     *
     * @param userSessionService the user session service
     */
    public ExternalUrlRequestService(final UserSessionService userSessionService) {
        super(userSessionService);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.impl.common.AbstractGenericService#createActionEvent
     * (com.hack23.cia.service.api.common.AbstractServiceRequest,
     * com.hack23.cia.model.application.UserSession)
     */
    @Override
    public final ActionEvent createActionEvent(
            final ExternalUrlRequest request, final UserSession userSession) {
        return new ExternalUrlActionEvent(new Date(), userSession, request
                .getOperation());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.common.ServiceHandler#getSupportedService()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedService() {
        return ExternalUrlRequest.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.service.common.AbstractGenericServiceHandler#
     * handleServiceRequest(com.hack23.cia.service.api.AbstractServiceRequest)
     */
    @Override
    public final ServiceResponse handleServiceRequest(
            final ExternalUrlRequest request, final UserSessionDTO userSessionDTO) {
        ExternalUrlResponse externalUrlResponse = null;

        switch (request.getOperation()) {
        case ShowProjectInformation:
            externalUrlResponse = new ExternalUrlResponse(userSessionDTO,
                    userSessionDTO.getLanguageResource(Agency.LanguageContentKey.PROJECT_INFORMATION), "http://cia.sourceforge.net/");
            break;
        case ShowDonateToProject:
           	externalUrlResponse = new ExternalUrlResponse(
				        userSessionDTO,
				        userSessionDTO.getLanguageResource(Agency.LanguageContentKey.DONATE_TO_PROJECT), "https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=6760739");
            break;
        case ShowWikiLeaks:
            externalUrlResponse = new ExternalUrlResponse(userSessionDTO,
                    "WikiLeaks : Be careful, Big Brother is watching you!",
                    "http://wikileaks.org");
            break;
        default:
            break;
        }
        return externalUrlResponse;
    }
}
