/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.service.impl.user;

import java.util.Date;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.ActionEvent;
import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.model.application.impl.user.UserAccountActionEvent;
import com.hack23.cia.model.application.impl.user.UserAccountActionEvent.Operation;
import com.hack23.cia.service.api.common.ErrorResponse;
import com.hack23.cia.service.api.common.ServiceResponse;
import com.hack23.cia.service.api.user.LoginRequest;
import com.hack23.cia.service.api.user.UserAccountResponse;
import com.hack23.cia.service.impl.common.ParliamentService;
import com.hack23.cia.service.impl.common.UserSessionService;

/**
 * The Class LoginRequestService.
 */
public class LoginRequestService extends
        AbstractUserRequestService<LoginRequest> {

	  /** The parliament service. */
    private final ParliamentService parliamentService;

    /**
     * Instantiates a new login request service.
     *
     * @param userSessionService the user session service
     * @param parliamentService the parliament service
     */
    public LoginRequestService(final UserSessionService userSessionService,final ParliamentService parliamentService) {
        super(userSessionService);
		this.parliamentService = parliamentService;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.impl.common.AbstractGenericService#createActionEvent
     * (com.hack23.cia.service.api.common.AbstractServiceRequest,
     * com.hack23.cia.model.application.UserSession)
     */
    @Override
    public final ActionEvent createActionEvent(final LoginRequest request,
            final UserSession userSession) {
        return new UserAccountActionEvent(new Date(), userSession,
                request.getOperation());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.common.ServiceHandler#getSupportedService()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedService() {
        return LoginRequest.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.service.common.AbstractGenericServiceHandler#
     * handleServiceRequest(com.hack23.cia.service.api.AbstractServiceRequest)
     */
    @Override
    public final ServiceResponse handleServiceRequest(
            final LoginRequest request, final UserSessionDTO userSession) {
        if (request.getOperation().equals(Operation.Process_login)) {
            UserSession loggedInUserSession = this.getUserSessionService().login(
                    request.getUserName(), request.getPassword(), userSession.getUserSession());
    
            if (loggedInUserSession != null) {
                return new UserAccountResponse(new UserSessionDTO(loggedInUserSession),parliamentService.getPoliticalParties());
            } else {
                return new ErrorResponse(userSession,
                        "Invalid Username/password");
            }
        } else {
            return new UserAccountResponse(userSession,parliamentService.getPoliticalParties());
        }
    }
}
