/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.service.impl.user;

import java.util.Date;
import java.util.List;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.ActionEvent;
import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.model.application.impl.user.SearchActionEvent;
import com.hack23.cia.model.sweden.impl.ParliamentMember;
import com.hack23.cia.service.api.common.ServiceResponse;
import com.hack23.cia.service.api.user.SearchRequest;
import com.hack23.cia.service.api.user.SearchResponse;
import com.hack23.cia.service.impl.common.ParliamentService;
import com.hack23.cia.service.impl.common.UserSessionService;

/**
 * The Class SearchRequestService.
 */
public class SearchRequestService extends
        AbstractParliamentRequestService<SearchRequest> {

    /**
     * Instantiates a new search request service.
     *
     * @param userSessionService the user session service
     * @param parliamentService the parliament service
     */
    public SearchRequestService(final UserSessionService userSessionService,
            final ParliamentService parliamentService) {
        super(userSessionService, parliamentService);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.impl.common.AbstractGenericService#createActionEvent
     * (com.hack23.cia.service.api.common.AbstractServiceRequest,
     * com.hack23.cia.model.application.UserSession)
     */
    @Override
    public final ActionEvent createActionEvent(final SearchRequest request,
            final UserSession userSession) {
        return new SearchActionEvent(new Date(), userSession, request
                .getSearchArgument());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.common.ServiceHandler#getSupportedService()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedService() {
        return SearchRequest.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.service.common.AbstractGenericServiceHandler#
     * handleServiceRequest(com.hack23.cia.service.api.AbstractServiceRequest)
     */
    @Override
    public final ServiceResponse handleServiceRequest(
            final SearchRequest request, final UserSessionDTO userSession) {
        List<ParliamentMember> findParliamentMembersByName = getParliamentService()
                .findParliamentMembersByName(request.getSearchArgument());
        SearchResponse searchResponse = new SearchResponse(userSession,
                findParliamentMembersByName);
        return searchResponse;
    }
}
