/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.web.action.user;

import com.hack23.cia.model.application.impl.user.UserAccountActionEvent.Operation;

/**
 * The Class UserAccountAction.
 */
public class UserAccountAction extends AbstractUserAction {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The encoded password. */
    private final String encodedPassword;

    /** The operation. */
    private final Operation operation;
    
    /** The username. */
    private final String username;
    
    /**
     * Instantiates a new user account action.
     *
     * @param operation the operation
     */
    public UserAccountAction(final Operation operation) {
        super();
        this.operation = operation;
        this.username = null;
        this.encodedPassword = null;
    }
    
    

    /**
     * Instantiates a new user account action.
     *
     * @param operation the operation
     * @param username the username
     * @param encodedPassword the encoded password
     */
    public UserAccountAction(final Operation operation, final String username,
            final String encodedPassword) {
        super();
        this.operation = operation;
        this.username = username;
        this.encodedPassword = encodedPassword;
    }



    /**
     * Gets the encoded password.
     *
     * @return the encoded password
     */
    public final String getEncodedPassword() {
        return encodedPassword;
    }



    /**
     * Gets the operation.
     *
     * @return the operation
     */
    public final Operation getOperation() {
        return operation;
    }



    /**
     * Gets the username.
     *
     * @return the username
     */
    public final String getUsername() {
        return username;
    }

}
