/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.web.common;

import org.springframework.context.ApplicationContext;
import org.springframework.context.MessageSource;
import org.springframework.context.support.ResourceBundleMessageSource;

import com.hack23.cia.service.api.application.ApplicationManager;
import com.hack23.cia.service.impl.common.ParliamentService;
import com.hack23.cia.web.action.common.ControllerActionListener;

/**
 * The Class BeanLocator.
 */
public class BeanLocator {

    /** The Constant APPLICATION_ACTION_LISTENER. */
    private static final String APPLICATION_ACTION_LISTENER = "applicationActionListener"; //$NON-NLS-1$

    /** The Constant MESSAGE_SOURCE. */
    private static final String MESSAGE_SOURCE = "messageSource"; //$NON-NLS-1$

    /**
     * Gets the application action listener.
     *
     * @return the application action listener
     */
    public static ControllerActionListener getApplicationActionListener() {
        return (ControllerActionListener) getApplicationContext().getBean(
                APPLICATION_ACTION_LISTENER);
    }

    /**
     * Gets the application context.
     *
     * @return the application context
     */
    private static ApplicationContext getApplicationContext() {
        return StaticContextLoaderListener.getWebApplicationContext();
    }

    /**
     * Gets the application manager.
     *
     * @return the application manager
     */
	public static ApplicationManager getApplicationManager() {
		return (ApplicationManager) getApplicationContext().getBean("applicationManager");
	}

    
    /**
     * Gets the parliament service.
     *
     * @return the parliament service
     */
    public static ParliamentService getParliamentService() {
        return (ParliamentService) getApplicationContext().getBean("parliamentService");
    }

	/**
	 * Gets the resource bundle message source.
	 *
	 * @return the resource bundle message source
	 */
    public static MessageSource getResourceBundleMessageSource() {
        return (ResourceBundleMessageSource) getApplicationContext().getBean(
                MESSAGE_SOURCE);
    }

	/**
	 * Instantiates a new bean locator.
	 */
    protected BeanLocator() {
        super();
    }

}
