/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.web.common;

import javax.servlet.ServletContextEvent;

import org.springframework.web.context.ContextLoaderListener;
import org.springframework.web.context.WebApplicationContext;
import org.springframework.web.context.support.WebApplicationContextUtils;

/**
 * The listener interface for receiving staticContextLoader events.
 * The class that is interested in processing a staticContextLoader
 * event implements this interface, and the object created
 * with that class is registered with a component using the
 * component's <code>addStaticContextLoaderListener<code> method. When
 * the staticContextLoader event occurs, that object's appropriate
 * method is invoked.
 *
 * @see StaticContextLoaderEvent
 */
public class StaticContextLoaderListener extends ContextLoaderListener {

    /** The web app ctx. */
    private static WebApplicationContext webAppCtx = null;

	/**
	 * Gets the web application context.
	 *
	 * @return the web application context
	 */
    protected static WebApplicationContext getWebApplicationContext() {
        return webAppCtx;
    }

    /**
     * Instantiates a new static context loader listener.
     */
    public StaticContextLoaderListener() {
		super();
	}

    /*
     * (non-Javadoc)
     * 
     * @see
     * org.springframework.web.context.ContextLoaderListener#contextDestroyed
     * (javax.servlet.ServletContextEvent)
     */
    @Override
    public final void contextDestroyed(final ServletContextEvent event) {
    	super.contextDestroyed(event);
        StaticContextLoaderListener.webAppCtx = null;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * org.springframework.web.context.ContextLoaderListener#contextInitialized
     * (javax.servlet.ServletContextEvent)
     */
    @Override
    public final void contextInitialized(final ServletContextEvent event) {
        super.contextInitialized(event);
        StaticContextLoaderListener.webAppCtx = WebApplicationContextUtils
                .getRequiredWebApplicationContext(event.getServletContext());
    }
}
