/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.web.controller.application;

import gnu.trove.THashMap;

import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.hack23.cia.web.action.common.ApplicationErrorAction;
import com.hack23.cia.web.action.common.ControllerAction;
import com.hack23.cia.web.controller.common.ActionHandler;

/**
 * The Class FrontController.
 */
public class FrontController implements Controller {

    /** The Constant LOGGER. */
    private static final Log LOGGER = LogFactory.getLog(FrontController.class);

    /** The action handlers map. */

    private Map<Class<ControllerAction>, ActionHandler> actionHandlersMap = new THashMap<Class<ControllerAction>, ActionHandler>();

    /** The default action handler. */
    private ActionHandler defaultActionHandler;

    /**
     * Instantiates a new front controller.
     *
     * @param actionHandlers the action handlers
     * @param defaultActionHandler the default action handler
     */
    public FrontController(final List<ActionHandler> actionHandlers,final ActionHandler defaultActionHandler) {
        super();
        this.defaultActionHandler = defaultActionHandler;
        for (ActionHandler actionHandler : actionHandlers) {
            actionHandlersMap.put(actionHandler.getSupportedAction(),
                    actionHandler);
        }
    }

    /**
     * Gets the action handlers map.
     *
     * @return the action handlers map
     */
    public final Map<Class<ControllerAction>, ActionHandler> getActionHandlersMap() {
        return actionHandlersMap;
    }

    /**
     * Gets the default action handler.
     *
     * @return the default action handler
     */
    public final ActionHandler getDefaultActionHandler() {
        return defaultActionHandler;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.web.controller.Controller#handleAction(com.hack23.cia.
     * web.action.ControllerAction)
     */
    //@Secured("IS_AUTHENTICATED_ANONYMOUSLY")
    public final void handleAction(final ControllerAction action)
            throws Exception {
        
        if (action != null) {
        	LOGGER.info("Action Received: " + action.toString()); //$NON-NLS-1$        
	        ActionHandler actionHandler = actionHandlersMap.get(action.getClass());
	
	        try {
	            if (actionHandler != null) {
	                actionHandler.processAction(action);
	            } else {
	               defaultActionHandler.processAction(action);
	            }
	        } catch (Exception e) {
	        	e.printStackTrace();
	            ApplicationErrorAction applicationErrorAction = new ApplicationErrorAction(e.getStackTrace(),"Exception from ActionHandler");
	            actionHandlersMap.get(applicationErrorAction.getClass()).processAction(applicationErrorAction);            
	        }
	        LOGGER.info("Action Completed: " + action); //$NON-NLS-1$
        } else {
        	LOGGER.warn("No action received");
        }
        
    }

}
