/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.controller.user;

import com.hack23.cia.service.api.application.ApplicationManager;
import com.hack23.cia.service.api.user.TopListRequest;
import com.hack23.cia.service.api.user.TopListResponse;
import com.hack23.cia.web.action.user.TopListAction;
import com.hack23.cia.web.viewfactory.api.common.ModelAndView;
import com.hack23.cia.web.viewfactory.api.common.ViewFactoryService;
import com.hack23.cia.web.viewfactory.api.user.ParliamentMemberListModelAndView;
import com.hack23.cia.web.viewfactory.api.user.ParliamentMemberListModelAndView.ParliamentMemberListViewSpecification;

/**
 * The Class TopListActionHandler.
 */
public class TopListActionHandler
        extends
        AbstractTopListActionHandler<TopListAction, TopListRequest, TopListResponse> {

    /**
     * Instantiates a new top list action handler.
     *
     * @param viewFactoryService the view factory service
     * @param applicationManager the application manager
     */
    public TopListActionHandler(final ViewFactoryService viewFactoryService,
            final ApplicationManager applicationManager) {
        super(viewFactoryService, applicationManager);
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.controller.common.AbstractGenericHandler#
     * createServiceRequest(com.hack23.cia.web.action.common.AbstractAction)
     */
    @Override
    public final TopListRequest createServiceRequest(final TopListAction action) {
        return new TopListRequest(getUserStateService().getUserSessionId(),
                action.getOperation());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.web.controller.ActionHandler#getSupportedAction()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedAction() {
        return TopListAction.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.controller.common.AbstractGenericHandler#
     * handleSuccessResponse(com.hack23.cia.web.action.common.AbstractAction,
     * com.hack23.cia.service.api.common.AbstractServiceResponse)
     */
    @Override
    public final ModelAndView handleSuccessResponse(final TopListAction action,
            final TopListResponse response) {
        ModelAndView modelAndView = null;

        switch (action.getOperation()) {
        case TopAbsent:
            modelAndView = new ParliamentMemberListModelAndView(response
                    .getUserSessionDTO(), action,
                    ParliamentMemberListViewSpecification.TopAbsentView,
                    response.getParliamentMembers());
            break;
        case TopPresent:
            modelAndView = new ParliamentMemberListModelAndView(response
                    .getUserSessionDTO(), action,
                    ParliamentMemberListViewSpecification.TopPresentView,
                    response.getParliamentMembers());
            break;
        case TopWinners:
            modelAndView = new ParliamentMemberListModelAndView(response
                    .getUserSessionDTO(), action,
                    ParliamentMemberListViewSpecification.TopWinnersView,
                    response.getParliamentMembers());
            break;
        case TopLosers:
            modelAndView = new ParliamentMemberListModelAndView(response
                    .getUserSessionDTO(), action,
                    ParliamentMemberListViewSpecification.TopLosersView,
                    response.getParliamentMembers());
            break;
        case TopRebels:
            modelAndView = new ParliamentMemberListModelAndView(response
                    .getUserSessionDTO(), action,
                    ParliamentMemberListViewSpecification.TopRebelsView,
                    response.getParliamentMembers());
            break;
        case TopLoyals:
            modelAndView = new ParliamentMemberListModelAndView(response
                    .getUserSessionDTO(), action,
                    ParliamentMemberListViewSpecification.TopLoyalsView,
                    response.getParliamentMembers());
            break;
        default:
            break;
        }
        return modelAndView;
    }

}
