/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.controller.user;

import com.hack23.cia.service.api.application.ApplicationManager;
import com.hack23.cia.service.api.user.AbstractUserAccountRequest;
import com.hack23.cia.service.api.user.AbstractUserAccountResponse;
import com.hack23.cia.service.api.user.LoginRequest;
import com.hack23.cia.service.api.user.LogoutRequest;
import com.hack23.cia.web.action.user.UserAccountAction;
import com.hack23.cia.web.viewfactory.api.common.ModelAndView;
import com.hack23.cia.web.viewfactory.api.common.ViewFactoryService;
import com.hack23.cia.web.viewfactory.api.user.UserModelAndView;
import com.hack23.cia.web.viewfactory.api.user.UserModelAndView.UserViewSpecification;

/**
 * The Class UserAccountActionHandler.
 */
public class UserAccountActionHandler
        extends
        AbstractUserActionHandler<UserAccountAction, AbstractUserAccountRequest, AbstractUserAccountResponse> {

    /**
     * Instantiates a new user account action handler.
     *
     * @param viewFactoryService the view factory service
     * @param applicationManager the application manager
     */
    public UserAccountActionHandler(
            final ViewFactoryService viewFactoryService,
            final ApplicationManager applicationManager) {
        super(viewFactoryService, applicationManager);
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.controller.common.AbstractGenericHandler#
     * createServiceRequest(com.hack23.cia.web.action.common.AbstractAction)
     */
    @Override
    public final AbstractUserAccountRequest createServiceRequest(
            final UserAccountAction action) {
        AbstractUserAccountRequest userRequest = null;

        switch (action.getOperation()) {
        case Login:
                userRequest = new LoginRequest(getUserStateService()
                        .getUserSessionId(),action.getOperation(),null,null);            
            break;
        case Process_login:
            userRequest = new LoginRequest(getUserStateService()
                    .getUserSessionId(),action.getOperation(), action.getUsername(),
                    action.getEncodedPassword());

            break;            
        case Logout:
            userRequest = new LogoutRequest(getUserStateService()
                    .getUserSessionId(),action.getOperation());
            break;
        case Register:

            break;
        default:
            break;
        }

        return userRequest;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.web.controller.ActionHandler#getSupportedAction()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedAction() {
        return UserAccountAction.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.controller.common.AbstractGenericHandler#
     * handleSuccessResponse(com.hack23.cia.web.action.common.AbstractAction,
     * com.hack23.cia.service.api.common.AbstractServiceResponse)
     */
    @Override
    public final ModelAndView handleSuccessResponse(
            final UserAccountAction action,
            final AbstractUserAccountResponse response) {

        ModelAndView modelAndView = null;
        switch (action.getOperation()) {
        case Login:
            modelAndView = new UserModelAndView(response.getUserSessionDTO(),response.getPoliticalParties(),
                    action, UserViewSpecification.LoginView);
            break;
        case Process_login:
            modelAndView = new UserModelAndView(response.getUserSessionDTO(),response.getPoliticalParties(),
                    action, UserViewSpecification.UserHomeView);            
            break;
        case Logout:
            modelAndView = new UserModelAndView(response.getUserSessionDTO(),response.getPoliticalParties(),
                    action, UserViewSpecification.LogoutView);
            break;
        case Register:

            break;
        default:
            break;
        }

        return modelAndView;
    }

}
