/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.controller.user;

import com.hack23.cia.service.api.application.ApplicationManager;
import com.hack23.cia.service.api.user.UserRequest;
import com.hack23.cia.service.api.user.UserResponse;
import com.hack23.cia.web.action.user.UserAction;
import com.hack23.cia.web.viewfactory.api.common.ModelAndView;
import com.hack23.cia.web.viewfactory.api.common.ViewFactoryService;
import com.hack23.cia.web.viewfactory.api.user.UserModelAndView;
import com.hack23.cia.web.viewfactory.api.user.UserModelAndView.UserViewSpecification;

/**
 * The Class UserActionHandler.
 */
public class UserActionHandler extends
        AbstractUserActionHandler<UserAction, UserRequest, UserResponse> {

    /**
     * Instantiates a new user action handler.
     *
     * @param viewFactoryService the view factory service
     * @param applicationManager the application manager
     */
    public UserActionHandler(final ViewFactoryService viewFactoryService,
            final ApplicationManager applicationManager) {
        super(viewFactoryService, applicationManager);
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.controller.common.AbstractGenericHandler#
     * createServiceRequest(com.hack23.cia.web.action.common.AbstractAction)
     */
    @Override
    public final UserRequest createServiceRequest(final UserAction action) {
        return new UserRequest(getUserStateService().getUserSessionId(), action
                .getOperation());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.web.controller.ActionHandler#getSupportedAction()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedAction() {
        return UserAction.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.controller.common.AbstractGenericHandler#
     * handleSuccessResponse(com.hack23.cia.web.action.common.AbstractAction,
     * com.hack23.cia.service.api.common.AbstractServiceResponse)
     */
    @Override
    public final ModelAndView handleSuccessResponse(final UserAction action,
            final UserResponse response) {

        ModelAndView modelAndView = null;
        switch (action.getOperation()) {
        case StartPage:
            modelAndView = new UserModelAndView(response.getUserSessionDTO(),response.getPoliticalParties(),
                    action, UserViewSpecification.WelcomePageView);
            break;
        case UserHistory:
            modelAndView = new UserModelAndView(response.getUserSessionDTO(),response.getPoliticalParties(),
                    action, UserViewSpecification.UserHistoryView);
            break;
        default:
            break;
        }

        return modelAndView;
    }

}
