/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.service;

import java.io.IOException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.util.FileCopyUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.AbstractController;

import com.hack23.cia.model.application.impl.common.ImageContent;
import com.hack23.cia.service.api.application.ApplicationManager;
import com.hack23.cia.service.api.common.ImageContentRequest;
import com.hack23.cia.service.api.common.ImageContentResponse;
import com.hack23.cia.service.api.common.ServiceRequest;
import com.hack23.cia.service.api.common.ServiceResponse;
import com.hack23.cia.service.api.common.ServiceResponse.ServiceResult;

/**
 * The Class ImageResourcesService.
 */
public class ImageResourcesService extends AbstractController {

	/** The application manager. */
	private final ApplicationManager applicationManager;
	
    /**
     * Instantiates a new image resources service.
     *
     * @param applicationManager the application manager
     */
    public ImageResourcesService(final ApplicationManager applicationManager) {
		super();
		this.applicationManager = applicationManager;
	}

	/* (non-Javadoc)
     * @see org.springframework.web.servlet.mvc.AbstractController#handleRequestInternal(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
     */
    @Override
    protected final ModelAndView handleRequestInternal(final HttpServletRequest request,
            final HttpServletResponse response) throws Exception {

    	loadAndWriteFile(request, response);
        
        return null;
    }

	/**
	 * Load and write file.
	 *
	 * @param request the request
	 * @param response the response
	 * @throws IOException Signals that an I/O exception has occurred.
	 */
	public final void loadAndWriteFile(final HttpServletRequest request,
			final HttpServletResponse response) throws IOException {
		String fileName = request.getParameter("filename");
    	ImageContent resource = null;
    	
    	if (fileName !=null) {
    		ServiceRequest serviceRequest = new ImageContentRequest(null, fileName);
			ServiceResponse serviceResponse = applicationManager.service(serviceRequest);
    		if (ServiceResult.SUCCESS.equals(serviceResponse.getResult())) {    			
    			ImageContentResponse imageContentResponse = (ImageContentResponse) serviceResponse;
    			resource = imageContentResponse.getImageContent();
    		}			
    	}
    		
    	String filename ="file.png";
		byte[] content = "".getBytes();
		String mimetype = "image/png";

    	if (resource != null ) {
    		filename =resource.getFileName();
    		content = resource.getImageContent();
    		mimetype = resource.getMimetype();
    	}
        response.setContentLength(content.length);
        response.setContentType(mimetype);
        FileCopyUtils.copy(content , response.getOutputStream());
	}

}
