/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.viewfactory.api.admin;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.ImageContent;
import com.hack23.cia.web.action.common.ControllerAction;

/**
 * The Class MonitorModelAndView.
 */
public class MonitorModelAndView extends AbstractAdminModelAndView {

    /**
     * The Enum MonitorViewSpecification.
     */
    public enum MonitorViewSpecification {

        /** The Recent actions view. */
        RecentActionsView,

        /** The Response time view. */
        ResponseTimeView
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The graph file path. */
    private final ImageContent graphFilePath;

    /** The monitor view specification. */
    private final MonitorViewSpecification monitorViewSpecification;

    /**
     * Instantiates a new monitor model and view.
     *
     * @param userSessionDTO the user session dto
     * @param controllerAction the controller action
     * @param monitorViewSpecification the monitor view specification
     * @param imageContent the image content
     */
    public MonitorModelAndView(final UserSessionDTO userSessionDTO,
            final ControllerAction controllerAction,
            final MonitorViewSpecification monitorViewSpecification,
            final ImageContent imageContent) {
        super(userSessionDTO, controllerAction);
        this.monitorViewSpecification = monitorViewSpecification;
        this.graphFilePath = imageContent;
    }

    /**
     * Gets the graph file path.
     *
     * @return the graph file path
     */
    public final ImageContent getGraphFilePath() {
        return graphFilePath;
    }

    /**
     * Gets the monitor view specification.
     *
     * @return the monitor view specification
     */
    public final MonitorViewSpecification getMonitorViewSpecification() {
        return monitorViewSpecification;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.api.common.AbstractModelAndView#
     * getViewSpecificationDescription()
     */
    @Override
    public final String getViewSpecificationDescription() {
        return monitorViewSpecification.toString();
    }
}
