/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.viewfactory.api.admin;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.web.action.common.ControllerAction;

/**
 * The Class TaskModelAndView.
 */
public class TaskModelAndView extends AbstractAdminModelAndView {

    /**
     * The Enum TaskViewSpecification.
     */
    public enum TaskViewSpecification {

        /** The Task view. */
        TaskView
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The task view specification. */
    private final TaskViewSpecification taskViewSpecification;

    /**
     * Instantiates a new task model and view.
     *
     * @param userSessionDTO the user session dto
     * @param controllerAction the controller action
     * @param taskViewSpecification the task view specification
     */
    public TaskModelAndView(final UserSessionDTO userSessionDTO,
            final ControllerAction controllerAction,
            final TaskViewSpecification taskViewSpecification) {
        super(userSessionDTO, controllerAction);
        this.taskViewSpecification = taskViewSpecification;
    }

    /**
     * Gets the task view specification.
     *
     * @return the task view specification
     */
    public final TaskViewSpecification getTaskViewSpecification() {
        return taskViewSpecification;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.api.common.AbstractModelAndView#
     * getViewSpecificationDescription()
     */
    @Override
    public final String getViewSpecificationDescription() {
        return taskViewSpecification.toString();
    }

}
