/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.viewfactory.api.application;

import java.util.List;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.sweden.impl.CommitteeReport;
import com.hack23.cia.model.sweden.impl.PoliticalParty;
import com.hack23.cia.web.action.common.ControllerAction;
import com.hack23.cia.web.viewfactory.api.common.AbstractModelAndView;

/**
 * The Class ApplicationModelAndView.
 */
public class ApplicationModelAndView extends AbstractModelAndView {

    /**
     * The Enum ApplicationViewSpecification.
     */
    public enum ApplicationViewSpecification {

        /** The Application view. */
        ApplicationView
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The agency. */
    private final Agency agency;

    /** The application view specification. */
    private final ApplicationViewSpecification applicationViewSpecification;

    /** The committee reports. */
    private final List<CommitteeReport> committeeReports;

	/** The political parties. */
	private final List<PoliticalParty> politicalParties;

    /**
     * Instantiates a new application model and view.
     *
     * @param userSessionDTO the user session dto
     * @param controllerAction the controller action
     * @param applicationViewSpecification the application view specification
     * @param agency the agency
     * @param committeeReports the committee reports
     * @param politicalParties the political parties
     */
    public ApplicationModelAndView(final UserSessionDTO userSessionDTO,
            final ControllerAction controllerAction,
            final ApplicationViewSpecification applicationViewSpecification,
            final Agency agency, final List<CommitteeReport> committeeReports,final List<PoliticalParty> politicalParties) {
        super(userSessionDTO, controllerAction);
        this.applicationViewSpecification = applicationViewSpecification;
        this.agency = agency;
        this.committeeReports = committeeReports;
		this.politicalParties = politicalParties;
    }

    /**
     * Gets the agency.
     *
     * @return the agency
     */
    public final Agency getAgency() {
        return agency;
    }

    /**
     * Gets the application view specification.
     *
     * @return the application view specification
     */
    public final ApplicationViewSpecification getApplicationViewSpecification() {
        return applicationViewSpecification;
    }

    /**
     * Gets the committee reports.
     *
     * @return the committee reports
     */
    public final List<CommitteeReport> getCommitteeReports() {
        return committeeReports;
    }

    /**
     * Gets the political parties.
     *
     * @return the political parties
     */
	public final List<PoliticalParty> getPoliticalParties() {
		return politicalParties;
	}

	/*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.api.common.AbstractModelAndView#
     * getViewSpecificationDescription()
     */
    @Override
    public final String getViewSpecificationDescription() {
        return applicationViewSpecification.toString();
    }

}
