/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.viewfactory.api.user;

import java.util.List;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.sweden.impl.CommitteeReport;
import com.hack23.cia.web.action.common.ControllerAction;

/**
 * The Class CommitteeReportsModelAndView.
 */
public class CommitteeReportsModelAndView extends
        AbstractParliamentModelAndView {

    /**
     * The Enum CommitteeReportsViewSpecification.
     */
    public enum CommitteeReportsViewSpecification {

        /** The Committee reports tree view. */
        CommitteeReportsTreeView
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The commitee reports. */
    private final List<CommitteeReport> commiteeReports;

    /** The committee reports view specification. */
    private final CommitteeReportsViewSpecification committeeReportsViewSpecification;

    /**
     * Instantiates a new committee reports model and view.
     *
     * @param userSessionDTO the user session dto
     * @param controllerAction the controller action
     * @param committeeReportsViewSpecification the committee reports view specification
     * @param commiteeReports the commitee reports
     */
    public CommitteeReportsModelAndView(
            final UserSessionDTO userSessionDTO,
            final ControllerAction controllerAction,
            final CommitteeReportsViewSpecification committeeReportsViewSpecification,
            final List<CommitteeReport> commiteeReports) {
        super(userSessionDTO, controllerAction);
        this.committeeReportsViewSpecification = committeeReportsViewSpecification;
        this.commiteeReports = commiteeReports;
    }

    /**
     * Gets the commitee reports.
     *
     * @return the commitee reports
     */
    public final List<CommitteeReport> getCommiteeReports() {
        return commiteeReports;
    }

    /**
     * Gets the committee reports view specification.
     *
     * @return the committee reports view specification
     */
    public final CommitteeReportsViewSpecification getCommitteeReportsViewSpecification() {
        return committeeReportsViewSpecification;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.api.common.AbstractModelAndView#
     * getViewSpecificationDescription()
     */
    @Override
    public final String getViewSpecificationDescription() {
        return committeeReportsViewSpecification.toString();
    }

}
