/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.viewfactory.api.user;

import java.util.List;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.sweden.impl.ParliamentMember;
import com.hack23.cia.web.action.common.ControllerAction;

/**
 * The Class ParliamentMemberListModelAndView.
 */
public class ParliamentMemberListModelAndView extends
        AbstractParliamentModelAndView {

    /**
     * The Enum ParliamentMemberListViewSpecification.
     */
    public enum ParliamentMemberListViewSpecification {

        /** The Search result view. */
        SearchResultView,

        /** The Top absent in party view. */
        TopAbsentInPartyView,

        /** The Top absent view. */
        TopAbsentView,

        /** The Top losers in party view. */
        TopLosersInPartyView,

        /** The Top losers view. */
        TopLosersView,

        /** The Top loyals in party view. */
        TopLoyalsInPartyView,

        /** The Top loyals view. */
        TopLoyalsView,

        /** The Top present in party view. */
        TopPresentInPartyView,

        /** The Top present view. */
        TopPresentView,

        /** The Top rebels in party view. */
        TopRebelsInPartyView,

        /** The Top rebels view. */
        TopRebelsView,

        /** The Top winners in party view. */
        TopWinnersInPartyView,

        /** The Top winners view. */
        TopWinnersView
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The parliament member list. */
    private final List<ParliamentMember> parliamentMemberList;

    /** The parliament member list view specification. */
    private final ParliamentMemberListViewSpecification parliamentMemberListViewSpecification;

    /**
     * Instantiates a new parliament member list model and view.
     *
     * @param userSessionDTO the user session dto
     * @param controllerAction the controller action
     * @param parliamentMemberListViewSpecification the parliament member list view specification
     * @param parliamentMemberList the parliament member list
     */
    public ParliamentMemberListModelAndView(
            final UserSessionDTO userSessionDTO,
            final ControllerAction controllerAction,
            final ParliamentMemberListViewSpecification parliamentMemberListViewSpecification,
            final List<ParliamentMember> parliamentMemberList) {
        super(userSessionDTO, controllerAction);
        this.parliamentMemberListViewSpecification = parliamentMemberListViewSpecification;
        this.parliamentMemberList = parliamentMemberList;
    }

    /**
     * Gets the parliament member list.
     *
     * @return the parliament member list
     */
    public final List<ParliamentMember> getParliamentMemberList() {
        return parliamentMemberList;
    }

    /**
     * Gets the parliament member list view specification.
     *
     * @return the parliament member list view specification
     */
    public final ParliamentMemberListViewSpecification getParliamentMemberListViewSpecification() {
        return parliamentMemberListViewSpecification;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.api.common.AbstractModelAndView#
     * getViewSpecificationDescription()
     */
    @Override
    public final String getViewSpecificationDescription() {
        return parliamentMemberListViewSpecification.toString();
    }

}
