/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.viewfactory.api.user;

import java.util.List;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.sweden.impl.ParliamentMember;
import com.hack23.cia.model.sweden.impl.ParliamentMemberVoteCompareResult;
import com.hack23.cia.model.sweden.impl.RegisterInformation;
import com.hack23.cia.model.sweden.impl.Vote;
import com.hack23.cia.web.action.common.ControllerAction;

/**
 * The Class ParliamentMemberSummaryModelAndView.
 */
public class ParliamentMemberSummaryModelAndView extends
        AbstractParliamentMemberModelAndView {

    /**
     * The Enum ParliamentMemberSummaryViewSpecification.
     */
    public enum ParliamentMemberSummaryViewSpecification {

        /** The Parliament member summary view. */
        ParliamentMemberSummaryView
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The enemy list. */
    private final List<ParliamentMemberVoteCompareResult> enemyList;

    /** The enemy party list. */
    private final List<ParliamentMemberVoteCompareResult> enemyPartyList;

    /** The friend list. */
    private final List<ParliamentMemberVoteCompareResult> friendList;

    /** The friend party list. */
    private final List<ParliamentMemberVoteCompareResult> friendPartyList;

    /** The parliament member summary view specification. */
    private final ParliamentMemberSummaryViewSpecification parliamentMemberSummaryViewSpecification;

    /** The register information. */
    private final RegisterInformation registerInformation;

    /** The votes. */
    private final List<Vote> votes;

    /**
     * Instantiates a new parliament member summary model and view.
     *
     * @param userSessionDTO the user session dto
     * @param controllerAction the controller action
     * @param parliamentMemberSummaryViewSpecification the parliament member summary view specification
     * @param parliamentMember the parliament member
     * @param friendList the friend list
     * @param enemyList the enemy list
     * @param friendPartyList the friend party list
     * @param enemyPartyList the enemy party list
     * @param votes the votes
     * @param registerInformation the register information
     */
    public ParliamentMemberSummaryModelAndView(
            final UserSessionDTO userSessionDTO,
            final ControllerAction controllerAction,
            final ParliamentMemberSummaryViewSpecification parliamentMemberSummaryViewSpecification,
            final ParliamentMember parliamentMember,
            final List<ParliamentMemberVoteCompareResult> friendList,
            final List<ParliamentMemberVoteCompareResult> enemyList,
            final List<ParliamentMemberVoteCompareResult> friendPartyList,
            final List<ParliamentMemberVoteCompareResult> enemyPartyList,
            final List<Vote> votes,
            final RegisterInformation registerInformation) {
        super(userSessionDTO, controllerAction, parliamentMember);
        this.parliamentMemberSummaryViewSpecification = parliamentMemberSummaryViewSpecification;
        this.friendList = friendList;
        this.enemyList = enemyList;
        this.friendPartyList = friendPartyList;
        this.enemyPartyList = enemyPartyList;
        this.votes = votes;
        this.registerInformation = registerInformation;
    }

    /**
     * Gets the enemy list.
     *
     * @return the enemy list
     */
    public final List<ParliamentMemberVoteCompareResult> getEnemyList() {
        return enemyList;
    }

    /**
     * Gets the enemy party list.
     *
     * @return the enemy party list
     */
    public final List<ParliamentMemberVoteCompareResult> getEnemyPartyList() {
        return enemyPartyList;
    }

    /**
     * Gets the friend list.
     *
     * @return the friend list
     */
    public final List<ParliamentMemberVoteCompareResult> getFriendList() {
        return friendList;
    }

    /**
     * Gets the friend party list.
     *
     * @return the friend party list
     */
    public final List<ParliamentMemberVoteCompareResult> getFriendPartyList() {
        return friendPartyList;
    }

    /**
     * Gets the parliament member summary view specification.
     *
     * @return the parliament member summary view specification
     */
    public final ParliamentMemberSummaryViewSpecification getParliamentMemberSummaryViewSpecification() {
        return parliamentMemberSummaryViewSpecification;
    }

    /**
     * Gets the register information.
     *
     * @return the register information
     */
    public final RegisterInformation getRegisterInformation() {
        return registerInformation;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.api.common.AbstractModelAndView#
     * getViewSpecificationDescription()
     */
    @Override
    public final String getViewSpecificationDescription() {
        return parliamentMemberSummaryViewSpecification.toString();
    }

    /**
     * Gets the votes.
     *
     * @return the votes
     */
    public final List<Vote> getVotes() {
        return votes;
    }
}
