/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.viewfactory.api.user;

import java.util.List;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.sweden.impl.Vote;
import com.hack23.cia.web.action.common.ControllerAction;

/**
 * The Class VotesModelAndView.
 */
public class VotesModelAndView extends AbstractParliamentModelAndView {

    /**
     * The Enum VotesViewSpecification.
     */
    public enum VotesViewSpecification {

        /** The Ballot view. */
        BallotView
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The votes. */
    private final List<Vote> votes;

    /** The votes view specification. */
    private final VotesViewSpecification votesViewSpecification;

    /**
     * Instantiates a new votes model and view.
     *
     * @param userSessionDTO the user session dto
     * @param controllerAction the controller action
     * @param votesViewSpecification the votes view specification
     * @param votes the votes
     */
    public VotesModelAndView(final UserSessionDTO userSessionDTO,
            final ControllerAction controllerAction,
            final VotesViewSpecification votesViewSpecification,
            final List<Vote> votes) {
        super(userSessionDTO, controllerAction);
        this.votesViewSpecification = votesViewSpecification;
        this.votes = votes;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.api.common.AbstractModelAndView#
     * getViewSpecificationDescription()
     */
    @Override
    public final String getViewSpecificationDescription() {
        return votesViewSpecification.toString();
    }

    /**
     * Gets the votes.
     *
     * @return the votes
     */
    public final List<Vote> getVotes() {
        return votes;
    }

    /**
     * Gets the votes view specification.
     *
     * @return the votes view specification
     */
    public final VotesViewSpecification getVotesViewSpecification() {
        return votesViewSpecification;
    }
}
