/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.web.viewfactory.impl.application;

import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import thinwire.ui.Frame;
import thinwire.ui.Menu;
import thinwire.ui.Panel;
import thinwire.ui.layout.TableLayout;

import com.hack23.cia.model.application.dto.common.ApplicationProperties;
import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.Portal;
import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.model.application.impl.user.UserActionEvent;
import com.hack23.cia.model.sweden.impl.CommitteeReport;
import com.hack23.cia.model.sweden.impl.PoliticalParty;
import com.hack23.cia.web.action.application.ApplicationAction;
import com.hack23.cia.web.action.user.UserAction;
import com.hack23.cia.web.common.ImageConstants;
import com.hack23.cia.web.viewfactory.api.application.ApplicationModelAndView;
import com.hack23.cia.web.viewfactory.impl.common.AbstractViewFactoryImpl;
import com.hack23.cia.web.viewfactory.impl.user.MenuFactory;
import com.hack23.cia.web.views.common.ActiveUserView;
import com.hack23.cia.web.views.user.ActionBarPanel;
import com.hack23.cia.web.views.user.PositionBarPanel;
import com.hack23.cia.web.views.user.WelcomePanel;

/**
 * The Class ApplicationViewFactoryImpl.
 */
public class ApplicationViewFactoryImpl extends
        AbstractViewFactoryImpl<ApplicationModelAndView> {


    /** The Constant LOGGER. */
    private static final Log LOGGER = LogFactory
            .getLog(ApplicationViewFactoryImpl.class);

    /** The menufactory. */
    private final MenuFactory menufactory;

    /** The top number. */
    private final int topNumber;

    /**
     * Instantiates a new application view factory impl.
     *
     * @param menufactory the menufactory
     * @param topNumber the top number
     */
    public ApplicationViewFactoryImpl(final MenuFactory menufactory,
            final int topNumber) {
        super();
        this.menufactory = menufactory;
        this.topNumber = topNumber;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.web.controller.ViewFactoryService#createFrame(thinwire
     * .ui.Frame)
     */
    /**
     * Creates the frame.
     *
     * @param frame the frame
     * @param userSessionDTO the user session dto
     * @param agency the agency
     * @param committeeReports the committee reports
     * @param politicalParties the political parties
     */
    public final void createFrame(final Frame frame,
            final UserSessionDTO userSessionDTO, final Agency agency,
            final List<CommitteeReport> committeeReports,final List<PoliticalParty> politicalParties) {
    	LOGGER.info("createFrame " + userSessionDTO.getUserSession().getUser().getUserRole());
        UserSession userSession = userSessionDTO.getUserSession();
        ApplicationProperties applicationProperties = new ApplicationProperties();
        Portal portal = userSession.getPortal();
        String portalName = null;
        String portalTitleDescription = null;

        if (portal != null) {
            portalName = portal.getName();
            portalTitleDescription = portal.getTitleDescription();
        } else {
            portalName = applicationProperties.getName();
            portalTitleDescription = userSessionDTO
                    .getLanguageResource(Agency.LanguageContentKey.TRACKING_POLITICIANS_LIKE_BUGS);
            Portal defaultPortal = new Portal();
            defaultPortal.setName(portalName);
            defaultPortal.setTitleDescription(portalTitleDescription);
        }

        frame.setTitle(portalName + " -::- " //$NON-NLS-1$
                + portalTitleDescription + " " + applicationProperties.getVersion());
        frame.setLayout(new TableLayout(new double[][] { { 0.15, 0.85 }, // Column
                // Widths
                { 0.08, 0.92 } }, // Row Heights
                1, // Margin around edge of container
                0)); // Spacing between cells

        Menu menu = this.menufactory.createApplicationMenu(userSessionDTO,politicalParties,
                topNumber);
        frame.setMenu(menu);

        PositionBarPanel positionBarPanel = new PositionBarPanel(userSessionDTO);
        positionBarPanel.setLimit("0,0,2,1"); //$NON-NLS-1$
        frame.getChildren().add(positionBarPanel);
        ActiveUserView.getCurrentPositionAndHistoryView().set(positionBarPanel);

        Panel actionBarPanel = new ActionBarPanel(userSessionDTO,ImageConstants.HOME_ICON,
                userSessionDTO.getLanguageResource(Agency.LanguageContentKey.HOME_PAGE),
                new UserAction(UserActionEvent.Operation.StartPage),
                committeeReports);
        actionBarPanel.setLimit("0,1,1,1"); //$NON-NLS-1$
        frame.getChildren().add(actionBarPanel);

        Panel contentView = new WelcomePanel(userSessionDTO);
        contentView.setLimit("1,1,1,1"); //$NON-NLS-1$
        frame.getChildren().add(contentView);

        ActiveUserView.getActiveContentView().set(contentView);
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.impl.common.ViewFactory#
     * getSupportedModelAndView()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedModelAndView() {
        return ApplicationModelAndView.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.impl.common.AbstractViewFactoryImpl#
     * processSpecificView
     * (com.hack23.cia.web.viewfactory.api.common.AbstractModelAndView)
     */
    @Override
    public final void processSpecificView(
            final ApplicationModelAndView modelAndView) {
        ApplicationAction action = (ApplicationAction) modelAndView
                .getControllerAction();

        ApplicationModelAndView newApplicationInstanceModelAndView = modelAndView;
        createFrame(action.getFrame(), newApplicationInstanceModelAndView
                .getUserSessionDTO(), newApplicationInstanceModelAndView
                .getAgency(), newApplicationInstanceModelAndView
                .getCommitteeReports(),newApplicationInstanceModelAndView.getPoliticalParties());
    }

}
