/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.web.viewfactory.impl.application;

import gnu.trove.THashMap;

import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.hack23.cia.web.viewfactory.api.common.ModelAndView;
import com.hack23.cia.web.viewfactory.api.common.ViewFactoryService;
import com.hack23.cia.web.viewfactory.impl.common.ViewFactory;

/**
 * The Class ViewFactoryServiceImpl.
 */
public class ViewFactoryServiceImpl implements ViewFactoryService {

    /** The Constant LOGGER. */
    private static final Log LOGGER = LogFactory
            .getLog(ViewFactoryServiceImpl.class);

    /** The model and view lookup view factory map. */
    private Map<Class<ModelAndView>, ViewFactory> modelAndViewLookupViewFactoryMap = new THashMap<Class<ModelAndView>, ViewFactory>();

    /**
     * Instantiates a new view factory service impl.
     *
     * @param viewFactories the view factories
     */
    public ViewFactoryServiceImpl(final List<ViewFactory> viewFactories) {
        super();
        for (ViewFactory viewFactory : viewFactories) {
            modelAndViewLookupViewFactoryMap.put(viewFactory
                    .getSupportedModelAndView(), viewFactory);
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.web.controller.viewFactory.ViewFactoryService#processView
     * (com.hack23.cia.web.controller.viewFactory.ModelAndView)
     */
    @Override
    public final void processView(final ModelAndView modelAndView) {
        if (modelAndView != null) {
            LOGGER.info("Processing View :"
                    + modelAndView.getViewSpecificationDescription());
            ViewFactory viewFactory = modelAndViewLookupViewFactoryMap
                    .get(modelAndView.getClass());
            if (viewFactory != null) {
                LOGGER.info("Found viewFactory :" + viewFactory.getClass().getSimpleName());                        
                viewFactory.processView(modelAndView);
            } else {
                LOGGER.error("ViewFactory missing for :"
                        + modelAndView.getClass().getSimpleName());
            }
        } else {
            LOGGER.error("ModelAndView missing :");
        }
    }
}
