/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.web.viewfactory.impl.user;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.ParliamentChart;
import com.hack23.cia.web.common.ImageConstants;
import com.hack23.cia.web.viewfactory.api.user.ParliamentMemberListModelAndView;
import com.hack23.cia.web.views.common.ActiveUserView;
import com.hack23.cia.web.views.components.gridboxes.TopAbsenceGridBox;
import com.hack23.cia.web.views.components.gridboxes.TopLosersGridBox;
import com.hack23.cia.web.views.components.gridboxes.TopLoyalsGridBox;
import com.hack23.cia.web.views.components.gridboxes.TopPresenceGridBox;
import com.hack23.cia.web.views.components.gridboxes.TopRebelsGridBox;
import com.hack23.cia.web.views.components.gridboxes.TopWinnersGridBox;
import com.hack23.cia.web.views.components.panels.ImagePanel;
import com.hack23.cia.web.views.components.panels.SimpleComponentPanel;
import com.hack23.cia.web.views.user.ParliamentMemberSearchResultPanel;

/**
 * The Class ParliamentMemberListViewFactoryImpl.
 */
public class ParliamentMemberListViewFactoryImpl extends
        AbstractParliamentViewFactoryImpl<ParliamentMemberListModelAndView> {

    /**
     * Instantiates a new parliament member list view factory impl.
     */
    public ParliamentMemberListViewFactoryImpl() {
        super();
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.impl.common.ViewFactory#
     * getSupportedModelAndView()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedModelAndView() {
        return ParliamentMemberListModelAndView.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.impl.common.AbstractViewFactoryImpl#
     * processSpecificView
     * (com.hack23.cia.web.viewfactory.api.common.AbstractModelAndView)
     */
    @Override
    public final void processSpecificView(
            final ParliamentMemberListModelAndView modelAndView) {
        UserSessionDTO userSessionDTO = modelAndView.getUserSessionDTO();
        
        switch (modelAndView.getParliamentMemberListViewSpecification()) {
        case TopWinnersView:
            ActiveUserView.changeContentView(new SimpleComponentPanel(
                    userSessionDTO.getLanguageResource(Agency.LanguageContentKey.WINNERS),
                    ImageConstants.WINNER_ICON_SMALL, new TopWinnersGridBox(modelAndView.getUserSessionDTO(),
                            (modelAndView).getParliamentMemberList()),userSessionDTO.getLanguageResource(Agency.LanguageContentKey.CHARTS),
                            ImageConstants.CHART_IMAGE_SMALL, new ImagePanel(ParliamentChart.getFileName(ParliamentChart.Outcome, userSessionDTO.getUserSession().getLanguage())),userSessionDTO));
            return;
        case TopLosersView:
            ActiveUserView.changeContentView(new SimpleComponentPanel(
                    userSessionDTO.getLanguageResource(Agency.LanguageContentKey.LOSERS),
                    ImageConstants.LOSER_ICON_SMALL, new TopLosersGridBox(modelAndView.getUserSessionDTO(),
                            (modelAndView).getParliamentMemberList()),userSessionDTO.getLanguageResource(Agency.LanguageContentKey.CHARTS),
                            ImageConstants.CHART_IMAGE_SMALL, new ImagePanel(ParliamentChart.getFileName(ParliamentChart.Outcome, userSessionDTO.getUserSession().getLanguage())),userSessionDTO));
            return;
        case TopPresentView:
            ActiveUserView.changeContentView(new SimpleComponentPanel(
                    userSessionDTO.getLanguageResource(Agency.LanguageContentKey.PRESENCE),
                    ImageConstants.PRESENCE_ICON_SMALL, new TopPresenceGridBox(modelAndView.getUserSessionDTO(),
                            (modelAndView).getParliamentMemberList()),userSessionDTO.getLanguageResource(Agency.LanguageContentKey.CHARTS),
                            ImageConstants.CHART_IMAGE_SMALL, new ImagePanel(ParliamentChart.getFileName(ParliamentChart.ProffessionalBehavior, userSessionDTO.getUserSession().getLanguage())),userSessionDTO));
            return;
        case TopAbsentView:
            ActiveUserView.changeContentView(new SimpleComponentPanel(
                    userSessionDTO
                            .getLanguageResource(Agency.LanguageContentKey.ABSENCE),
                    ImageConstants.ABSENCE_ICON_SMALL, new TopAbsenceGridBox(modelAndView.getUserSessionDTO(),
                            (modelAndView).getParliamentMemberList()),userSessionDTO.getLanguageResource(Agency.LanguageContentKey.CHARTS),
                            ImageConstants.CHART_IMAGE_SMALL, new ImagePanel(ParliamentChart.getFileName(ParliamentChart.ProffessionalBehavior, userSessionDTO.getUserSession().getLanguage())),userSessionDTO));
            return;
        case TopRebelsView:
            ActiveUserView
                    .changeContentView(new SimpleComponentPanel(
                            userSessionDTO
                                    .getLanguageResource(Agency.LanguageContentKey.REBELS),
                            ImageConstants.REBEL_ICON_SMALL,
                            new TopRebelsGridBox(modelAndView.getUserSessionDTO(),(modelAndView)
                                    .getParliamentMemberList()),userSessionDTO.getLanguageResource(Agency.LanguageContentKey.CHARTS),
                                    ImageConstants.CHART_IMAGE_SMALL, new ImagePanel(ParliamentChart.getFileName(ParliamentChart.PoliticalPartyBehavior, userSessionDTO.getUserSession().getLanguage())),userSessionDTO));
            return;
        case TopLoyalsView:
            ActiveUserView.changeContentView(new SimpleComponentPanel(
                    userSessionDTO.getLanguageResource(Agency.LanguageContentKey.LOYAL),
                    ImageConstants.LOYAL_ICON_SMALL, new TopLoyalsGridBox(modelAndView.getUserSessionDTO(),
                            (modelAndView).getParliamentMemberList()),userSessionDTO.getLanguageResource(Agency.LanguageContentKey.CHARTS),
                            ImageConstants.CHART_IMAGE_SMALL, new ImagePanel(ParliamentChart.getFileName(ParliamentChart.PoliticalPartyBehavior, userSessionDTO.getUserSession().getLanguage())),userSessionDTO));
            return;
        case SearchResultView:
            ActiveUserView
                    .changeContentView(new ParliamentMemberSearchResultPanel(modelAndView.getUserSessionDTO(),
                            (modelAndView).getParliamentMemberList()));
            return;
        case TopLosersInPartyView:
        	ActiveUserView.changeContentView(new SimpleComponentPanel(
                            userSessionDTO
                                    .getLanguageResource(Agency.LanguageContentKey.LOSERS),
                            ImageConstants.LOSER_ICON_SMALL,
                            new TopLosersGridBox(modelAndView.getUserSessionDTO(),(modelAndView)
                                    .getParliamentMemberList()),userSessionDTO.getLanguageResource(Agency.LanguageContentKey.CHARTS),
                                    ImageConstants.CHART_IMAGE_SMALL, new ImagePanel(ParliamentChart.getFileName(ParliamentChart.Outcome,modelAndView.getParliamentMemberList().get(0).getPoliticalParty(), userSessionDTO.getUserSession().getLanguage())),userSessionDTO));
            return;
        case TopWinnersInPartyView:
            ActiveUserView.changeContentView(new SimpleComponentPanel(
                    userSessionDTO
                            .getLanguageResource(Agency.LanguageContentKey.WINNERS),
                    ImageConstants.WINNER_ICON_SMALL, new TopWinnersGridBox(modelAndView.getUserSessionDTO(),
                            (modelAndView).getParliamentMemberList()),userSessionDTO.getLanguageResource(Agency.LanguageContentKey.CHARTS),
                            ImageConstants.CHART_IMAGE_SMALL, new ImagePanel(ParliamentChart.getFileName(ParliamentChart.Outcome,modelAndView.getParliamentMemberList().get(0).getPoliticalParty(), userSessionDTO.getUserSession().getLanguage())),userSessionDTO));
            return;
        case TopAbsentInPartyView:
            ActiveUserView.changeContentView(new SimpleComponentPanel(
                    userSessionDTO
                            .getLanguageResource(Agency.LanguageContentKey.ABSENCE),
                    ImageConstants.ABSENCE_ICON_SMALL, new TopAbsenceGridBox(modelAndView.getUserSessionDTO(),
                            (modelAndView).getParliamentMemberList()),userSessionDTO.getLanguageResource(Agency.LanguageContentKey.CHARTS),
                            ImageConstants.CHART_IMAGE_SMALL, new ImagePanel(ParliamentChart.getFileName(ParliamentChart.ProffessionalBehavior,modelAndView.getParliamentMemberList().get(0).getPoliticalParty(), userSessionDTO.getUserSession().getLanguage())),userSessionDTO));
            return;
        case TopPresentInPartyView:
            ActiveUserView.changeContentView(new SimpleComponentPanel(
                    userSessionDTO
                            .getLanguageResource(Agency.LanguageContentKey.PRESENCE),
                    ImageConstants.PRESENCE_ICON_SMALL, new TopPresenceGridBox(modelAndView.getUserSessionDTO(),
                            (modelAndView).getParliamentMemberList()),userSessionDTO.getLanguageResource(Agency.LanguageContentKey.CHARTS),
                            ImageConstants.CHART_IMAGE_SMALL, new ImagePanel(ParliamentChart.getFileName(ParliamentChart.ProffessionalBehavior,modelAndView.getParliamentMemberList().get(0).getPoliticalParty(), userSessionDTO.getUserSession().getLanguage())),userSessionDTO));
            return;
        case TopRebelsInPartyView:
            ActiveUserView.changeContentView(new SimpleComponentPanel(
                    userSessionDTO
                            .getLanguageResource(Agency.LanguageContentKey.REBELS),
                    ImageConstants.REBEL_ICON_SMALL, new TopRebelsGridBox(modelAndView.getUserSessionDTO(),
                            (modelAndView).getParliamentMemberList()),userSessionDTO.getLanguageResource(Agency.LanguageContentKey.CHARTS),
                            ImageConstants.CHART_IMAGE_SMALL, new ImagePanel(ParliamentChart.getFileName(ParliamentChart.PoliticalPartyBehavior,modelAndView.getParliamentMemberList().get(0).getPoliticalParty(), userSessionDTO.getUserSession().getLanguage())),userSessionDTO));
            return;
        case TopLoyalsInPartyView:
            ActiveUserView.changeContentView(new SimpleComponentPanel(
                    userSessionDTO
                            .getLanguageResource(Agency.LanguageContentKey.LOYAL),
                    ImageConstants.LOYAL_ICON_SMALL, new TopLoyalsGridBox(modelAndView.getUserSessionDTO(),
                            (modelAndView).getParliamentMemberList()),userSessionDTO.getLanguageResource(Agency.LanguageContentKey.CHARTS),
                            ImageConstants.CHART_IMAGE_SMALL, new ImagePanel(ParliamentChart.getFileName(ParliamentChart.PoliticalPartyBehavior,modelAndView.getParliamentMemberList().get(0).getPoliticalParty(), userSessionDTO.getUserSession().getLanguage())),userSessionDTO));
            return;
        default:
            return;
        }
    }
}
