/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.web.viewfactory.impl.user;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.hack23.cia.web.viewfactory.api.user.UserModelAndView;
import com.hack23.cia.web.views.common.ActiveUserView;
import com.hack23.cia.web.views.user.LoginPanel;
import com.hack23.cia.web.views.user.WelcomePanel;

/**
 * The Class UserViewFactoryImpl.
 */
public class UserViewFactoryImpl extends
        AbstractUserViewFactoryImpl<UserModelAndView> {

    /** The Constant LOGGER. */
    private static final Log LOGGER = LogFactory
            .getLog(UserViewFactoryImpl.class);

    /** The menu factory. */
    private final MenuFactory menuFactory;

    /** The top number. */
    private final int topNumber;

    /**
     * Instantiates a new user view factory impl.
     *
     * @param menuFactory the menu factory
     * @param topNumber the top number
     */
    public UserViewFactoryImpl(final MenuFactory menuFactory,
            final int topNumber) {
        super();
        this.menuFactory = menuFactory;
        this.topNumber = topNumber;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.impl.common.ViewFactory#
     * getSupportedModelAndView()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedModelAndView() {
        return UserModelAndView.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.impl.common.AbstractViewFactoryImpl#
     * processSpecificView
     * (com.hack23.cia.web.viewfactory.api.common.AbstractModelAndView)
     */
    @Override
    public final void processSpecificView(final UserModelAndView modelAndView) {
        switch (modelAndView.getUserViewSpecification()) {
        case WelcomePageView:
            ActiveUserView.changeContentView(new WelcomePanel(modelAndView.getUserSessionDTO()));
            return;
        case LoginView: 
            ActiveUserView.changeContentView(new LoginPanel(modelAndView.getUserSessionDTO()));
            return;           
        case LogoutView:
            ActiveUserView.changeContentView(new WelcomePanel(modelAndView.getUserSessionDTO()));
            ActiveUserView.changeActiveMenu(menuFactory.createApplicationMenu(
                    modelAndView.getUserSessionDTO(),modelAndView.getPoliticalParties(), topNumber));
            return;
        case UserHomeView:
            ActiveUserView.changeContentView(new WelcomePanel(modelAndView.getUserSessionDTO()));
            ActiveUserView.changeActiveMenu(menuFactory.createApplicationMenu(
                    modelAndView.getUserSessionDTO(),modelAndView.getPoliticalParties(), topNumber));
            return;
        default:
            LOGGER
                    .warn("Not implemented :" + modelAndView.getUserViewSpecification()); //$NON-NLS-1$
            return;
        }
    }
}
