/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.views.admin;

import thinwire.ui.Button;
import thinwire.ui.GridBox;
import thinwire.ui.Label;
import thinwire.ui.Panel;
import thinwire.ui.TabFolder;
import thinwire.ui.TabSheet;
import thinwire.ui.TextField;
import thinwire.ui.event.ActionEvent;
import thinwire.ui.event.ActionListener;
import thinwire.ui.layout.TableLayout;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.admin.AgencyActionEvent;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.web.action.admin.AgencyAction;
import com.hack23.cia.web.common.BeanLocator;
import com.hack23.cia.web.views.components.gridboxes.LanguagesGridBox;
import com.hack23.cia.web.views.components.gridboxes.PortalsGridBox;

/**
 * The Class AbstractAdminPanel.
 */
public abstract class AbstractAdminPanel extends Panel {

    /** The add language action listener. */
    private final ActionListener addLanguageActionListener = new ActionListener() {
        public void actionPerformed(final ActionEvent ev) {
            ((Button) ev.getSource()).setUserObject(new AgencyAction(
                    AgencyActionEvent.Operation.AddLanguage, agency.getId()));
            BeanLocator.getApplicationActionListener().actionPerformed(ev);
        }
    };

    /** The agency. */
    private final Agency agency;

    /** The agency name field. */
    private final TextField agencyNameField = new TextField();

    /** The cancel action listener. */
    private final ActionListener cancelActionListener = new ActionListener() {
        public void actionPerformed(final ActionEvent ev) {
            agencyNameField.setText(agency.getName());
        }
    };

    /** The new portal action listener. */
    private final ActionListener newPortalActionListener = new ActionListener() {
        public void actionPerformed(final ActionEvent ev) {
            ((Button) ev.getSource()).setUserObject(new AgencyAction(
                    AgencyActionEvent.Operation.AddPortal, agency.getId()));
            BeanLocator.getApplicationActionListener().actionPerformed(ev);
        }
    };


    /** The ok action listener. */
    private final ActionListener okActionListener = new ActionListener() {
        public void actionPerformed(final ActionEvent ev) {
            agency.setName(agencyNameField.getText());
            ((Button) ev.getSource()).setUserObject(new AgencyAction(
                    AgencyActionEvent.Operation.UpdateAgency, agency.getId(),agency));
            BeanLocator.getApplicationActionListener().actionPerformed(ev);
        }
    };

    /** The tab folder. */
    private final TabFolder tabFolder = new TabFolder();

    /** The user session dto. */
    private final UserSessionDTO userSessionDTO;

    /**
     * Instantiates a new abstract admin panel.
     *
     * @param userSessionDTO the user session dto
     * @param agency the agency
     */
    public AbstractAdminPanel(final UserSessionDTO userSessionDTO,final Agency agency) {
        this.userSessionDTO = userSessionDTO;
        this.agency = new Agency();
        this.agency.setId(agency.getId());
        this.agency.setName(agency.getName());
        setLayout(new TableLayout(new double[][] { { 0 }, // Column Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        TabSheet gridBoxTabSheet = createAgencyTabSheet(agency);

        tabFolder.getChildren().add(gridBoxTabSheet);
        getChildren().add(tabFolder);
    }

    /**
     * Creates the agency tab sheet.
     *
     * @param agency the agency
     * @return the tab sheet
     */
    private TabSheet createAgencyTabSheet(final Agency agency) {
        TabSheet tabSheet = new TabSheet();
        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.CONFIGURE_AGENCY));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0, 0, 0 }, // Column
                // Widths
                { 0, 0, 0, 0 } }, // Row Heights
                10, // Margin around edge of container
                5));

        final Label nameLabel = new Label(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.NAME));
        nameLabel.setLimit("0,0"); //$NON-NLS-1$
        tabSheet.getChildren().add(nameLabel);

        agencyNameField.setLimit("1,0,2,1"); //$NON-NLS-1$
        agencyNameField.setText(agency.getName());
        tabSheet.getChildren().add(agencyNameField);

        final Label portalsLabel = new Label(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.PORTALS));
        portalsLabel.setLimit("0,1"); //$NON-NLS-1$
        tabSheet.getChildren().add(portalsLabel);

        GridBox portalGridBox = new PortalsGridBox(userSessionDTO,agency.getPortals());
        portalGridBox.setLimit("1,1,2,1"); //$NON-NLS-1$
        tabSheet.getChildren().add(portalGridBox);

        final Button addLanguageButton = new Button(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.ADD_LANGUAGE));
        addLanguageButton.setLimit("0,2"); //$NON-NLS-1$
        addLanguageButton.addActionListener(ACTION_CLICK,
                addLanguageActionListener);
        tabSheet.getChildren().add(addLanguageButton);

        GridBox languagesGridBox = new LanguagesGridBox(userSessionDTO,agency);
        languagesGridBox.setLimit("1,2,2,1"); //$NON-NLS-1$
        tabSheet.getChildren().add(languagesGridBox);

        final Button newPortalButton = new Button(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.BUTTON_NEW_PORTAL));
        newPortalButton.setLimit("0,3"); //$NON-NLS-1$
        newPortalButton
                .addActionListener(ACTION_CLICK, newPortalActionListener);
        tabSheet.getChildren().add(newPortalButton);

        final Button cancelButton = new Button(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.BUTTON_CANCEL));
        cancelButton.setLimit("1,3"); //$NON-NLS-1$
        cancelButton.addActionListener(ACTION_CLICK, cancelActionListener);
        tabSheet.getChildren().add(cancelButton);

        final Button okButton = new Button(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.BUTTON_OK));
        okButton.setLimit("2,3"); //$NON-NLS-1$
        okButton.addActionListener(ACTION_CLICK, okActionListener);
        tabSheet.getChildren().add(okButton);
        return tabSheet;
    }

 
    /**
     * Gets the agency.
     *
     * @return the agency
     */
    public final Agency getAgency() {
        return agency;
    }

    /**
     * Gets the tab folder.
     *
     * @return the tab folder
     */
    public final TabFolder getTabFolder() {
        return tabFolder;
    }

    /**
     * Gets the user session dto.
     *
     * @return the user session dto
     */
    public final UserSessionDTO getUserSessionDTO() {
        return userSessionDTO;
    }

}
