/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.views.admin;

import thinwire.ui.Button;
import thinwire.ui.Label;
import thinwire.ui.TabSheet;
import thinwire.ui.TextField;
import thinwire.ui.event.ActionEvent;
import thinwire.ui.event.ActionListener;
import thinwire.ui.layout.TableLayout;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.admin.LanguageContentActionEvent;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.LanguageContent;
import com.hack23.cia.web.action.admin.LanguageContentAction;
import com.hack23.cia.web.common.BeanLocator;

/**
 * The Class ConfigureLanguageContentPanel.
 */
public class ConfigureLanguageContentPanel extends AbstractAdminPanel {

    /** The cancel language content action listener. */
    private final ActionListener cancelLanguageContentActionListener = new ActionListener() {
        public void actionPerformed(final ActionEvent ev) {
            contentPropertyNameField.setText(languageContent.getContentPropertyName());
            contentField.setText(languageContent.getContentPropertyName());
        }
    };


    /** The content field. */
    private final TextField contentField = new TextField();


    /** The content property name field. */
    private final TextField contentPropertyNameField = new TextField();

    /** The delete language content action listener. */
    private final ActionListener deleteLanguageContentActionListener = new ActionListener() {
        public void actionPerformed(final ActionEvent ev) {
            ((Button) ev.getSource()).setUserObject(new LanguageContentAction(
                    LanguageContentActionEvent.Operation.Delete,getAgency(),languageContent));
            BeanLocator.getApplicationActionListener().actionPerformed(ev);
        }
    };

    /** The language content. */
    private LanguageContent languageContent;



    /** The ok language content action listener. */
    private final ActionListener okLanguageContentActionListener = new ActionListener() {
        public void actionPerformed(final ActionEvent ev) {
            languageContent.setContentPropertyName(contentPropertyNameField.getText());
            languageContent.setContent(contentField.getText());
            ((Button) ev.getSource()).setUserObject(new LanguageContentAction(
                    LanguageContentActionEvent.Operation.Update,getAgency(),languageContent));
            BeanLocator.getApplicationActionListener().actionPerformed(ev);
        }
    };

    /**
     * Instantiates a new configure language content panel.
     *
     * @param userSessionDTO the user session dto
     * @param agency the agency
     * @param languageContent the language content
     */
    public ConfigureLanguageContentPanel(final UserSessionDTO userSessionDTO,final Agency agency, final LanguageContent languageContent) {
        super(userSessionDTO,agency);
        this.languageContent = new LanguageContent();
        this.languageContent.setId(languageContent.getId());
        this.languageContent.setContentPropertyName(languageContent.getContentPropertyName());
        this.languageContent.setContent(languageContent.getContent());
        this.languageContent.setLanguage(languageContent.getLanguage());
        TabSheet gridBoxTabSheet = createLanguageContentTabSheet(languageContent);
        getTabFolder().getChildren().add(gridBoxTabSheet);
        getTabFolder().setCurrentIndex(1);

    }

    /**
     * Creates the language content tab sheet.
     *
     * @param languageContent the language content
     * @return the tab sheet
     */
    private TabSheet createLanguageContentTabSheet(final LanguageContent languageContent) {
        TabSheet tabSheet = new TabSheet();
        tabSheet.setText(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.CONFIGURE_LANGUAGE));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0, 0, 0 }, // Column
                // Widths
                { 0, 0, 0, 0, 0 } }, // Row Heights
                10, // Margin around edge of container
                5));

        final Label languageContentKeyLabel = new Label(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.LANGUAGE_CONTENT_KEY));
        languageContentKeyLabel.setLimit("0,0"); //$NON-NLS-1$
        tabSheet.getChildren().add(languageContentKeyLabel);

        contentPropertyNameField.setLimit("1,0,2,1"); //$NON-NLS-1$
        contentPropertyNameField.setText(languageContent.getContentPropertyName());
        tabSheet.getChildren().add(contentPropertyNameField);

        final Label languageContentLabel = new Label(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.LANGUAGE_CONTENT_VALUE));
        languageContentLabel.setLimit("0,1"); //$NON-NLS-1$
        tabSheet.getChildren().add(languageContentLabel);

        contentField.setLimit("1,1,2,1"); //$NON-NLS-1$
        contentField.setText(languageContent.getContent());
        tabSheet.getChildren().add(contentField);

        final Button deleteButton = new Button(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.BUTTON_DELETE));
        deleteButton.setLimit("0,3"); //$NON-NLS-1$
        deleteButton.addActionListener(ACTION_CLICK,
                deleteLanguageContentActionListener);
        tabSheet.getChildren().add(deleteButton);

        final Button cancelButton = new Button(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.BUTTON_CANCEL));
        cancelButton.setLimit("1,3"); //$NON-NLS-1$
        cancelButton.addActionListener(ACTION_CLICK,
                cancelLanguageContentActionListener);
        tabSheet.getChildren().add(cancelButton);

        final Button okButton = new Button(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.BUTTON_OK));
        okButton.setLimit("2,3"); //$NON-NLS-1$
        okButton.addActionListener(ACTION_CLICK, okLanguageContentActionListener);
        tabSheet.getChildren().add(okButton);
        return tabSheet;
    }

}
