/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.web.views.common;

import thinwire.ui.Application;
import thinwire.ui.Menu;
import thinwire.ui.Panel;

/**
 * The Class ActiveUserView.
 */
public class ActiveUserView {

    /** The active content view. */
    private static Application.Local<Panel> activeContentView = new Application.Local<Panel>();

    /** The current position and history view. */
    private static Application.Local<Panel> currentPositionAndHistoryView = new Application.Local<Panel>();

    /**
     * Change active menu.
     *
     * @param menu the menu
     */
    public static void changeActiveMenu(final Menu menu) {
        Application.current().getFrame().setMenu(menu);
    }

    /**
     * Change content view.
     *
     * @param view the view
     */
    public static void changeContentView(final Panel view) {
        Panel oldView = activeContentView.get();
        view.setLimit(oldView.getLimit());
        Application.current().getFrame().getChildren().remove(oldView);
        Application.current().getFrame().getChildren().add(view);
        activeContentView.set(view);
    }

    /**
     * Gets the active content view.
     *
     * @return the active content view
     */
    public static Application.Local<Panel> getActiveContentView() {
        return activeContentView;
    }

    /**
     * Gets the current position and history view.
     *
     * @return the current position and history view
     */
    public static Application.Local<Panel> getCurrentPositionAndHistoryView() {
        return currentPositionAndHistoryView;
    }

    /**
     * Instantiates a new active user view.
     */
    protected ActiveUserView() {
        super();
    }
}
