/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.views.components.gridboxes;

import java.util.List;

import thinwire.ui.GridBox;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.sweden.impl.ParliamentMember;
import com.hack23.cia.web.common.BeanLocator;

/**
 * The Class AbstractParliamentMemberGridBox.
 */
public abstract class AbstractParliamentMemberGridBox extends GridBox {

    /** The user session dto. */
    private final UserSessionDTO userSessionDTO;

    /**
     * Instantiates a new abstract parliament member grid box.
     *
     * @param userSessionDTO the user session dto
     * @param currentList the current list
     */
    public AbstractParliamentMemberGridBox(final UserSessionDTO userSessionDTO,
            final List<ParliamentMember> currentList) {
        super();
        this.userSessionDTO = userSessionDTO;
        this.setVisibleHeader(true);
        this.addActionListener(ACTION_CLICK, BeanLocator
                .getApplicationActionListener());

        addGridBoxColumns();

        this.getColumns().add(GridBoxColumnFactory.getRegisteredVotesHeader(userSessionDTO));
        this.getColumns().add(GridBoxColumnFactory.getNameHeader(userSessionDTO));
        this.getColumns().add(GridBoxColumnFactory.getPartyHeader(userSessionDTO));
        this.getColumns().add(GridBoxColumnFactory.getElectoralAreaHeader(userSessionDTO));
        this.getColumns().add(GridBoxColumnFactory.getFirstVoteHeader(userSessionDTO));
        this.getColumns().add(GridBoxColumnFactory.getLastVoteHeader(userSessionDTO));

        int rank = 1;
        for (ParliamentMember parliamentMember : currentList) {
            this.getRows().add(createRow(rank++, parliamentMember));
        }
    }

    /**
     * Adds the grid box columns.
     */
    abstract void addGridBoxColumns();

    /**
     * Creates the row.
     *
     * @param row the row
     * @param parliamentMember the parliament member
     * @return the grid box. row
     */
    abstract GridBox.Row createRow(int row, ParliamentMember parliamentMember);

    /**
     * Gets the user session dto.
     *
     * @return the user session dto
     */
    public final UserSessionDTO getUserSessionDTO() {
        return userSessionDTO;
    }

}
