/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.views.components.gridboxes;

import thinwire.ui.GridBox;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.sweden.impl.RegisterInformation;

/**
 * The Class RegisterInformationGridbox.
 */
public class RegisterInformationGridbox extends GridBox {

    /**
     * Instantiates a new register information gridbox.
     *
     * @param userSessionDTO the user session dto
     * @param registerInformation the register information
     */
    public RegisterInformationGridbox(final UserSessionDTO userSessionDTO,
            final RegisterInformation registerInformation) {
        super();
        this.setVisibleHeader(true);
        GridBox.Column categoryHeader = new GridBox.Column();
        categoryHeader.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.CATEGORY));
        categoryHeader.setWidth(240);
        this.getColumns().add(categoryHeader);

        GridBox.Column votePositionHeader = new GridBox.Column();
        votePositionHeader.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.LOYALTIES));
        this.getColumns().add(votePositionHeader);

        if (registerInformation != null) {
            GridBox.Row row = null;

            for (String dataStr : registerInformation.getStocks()) {
                row = new GridBox.Row(userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.STOCKS), dataStr);
                this.getRows().add(row);
            }

            for (String dataStr : registerInformation.getHouses()) {
                row = new GridBox.Row(userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.HOUSES), dataStr);
                this.getRows().add(row);
            }

            for (String dataStr : registerInformation.getIncomeActivity()) {
                row = new GridBox.Row(userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.INCOME_ACTIVITY), dataStr);
                this.getRows().add(row);
            }

            for (String dataStr : registerInformation.getAgreements()) {
                row = new GridBox.Row(userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.AGREEMENTS), dataStr);
                this.getRows().add(row);
            }

            for (String dataStr : registerInformation.getRoles()) {
                row = new GridBox.Row(userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.ROLES), dataStr);
                this.getRows().add(row);
            }

            for (String dataStr : registerInformation.getPublicRoles()) {
                row = new GridBox.Row(userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.PUBLIC_ROLES), dataStr);
                this.getRows().add(row);
            }

            for (String dataStr : registerInformation.getAllowances()) {
                row = new GridBox.Row(userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.ALLOWANCES), dataStr);
                this.getRows().add(row);
            }

            if (registerInformation.getNothingDeclared().length() > 0) {
                row = new GridBox.Row(userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.NOTHING_DECLARED),
                        registerInformation.getNothingDeclared());
                this.getRows().add(row);
            }

        } else {
            GridBox.Row row = null;
            row = new GridBox.Row(
                    userSessionDTO
                            .getLanguageResource(Agency.LanguageContentKey.NO_REGISTER_INFORMATION),
                    userSessionDTO
                            .getLanguageResource(Agency.LanguageContentKey.NO_REGISTER_INFORMATION_MSG));
            this.getRows().add(row);
        }
    }
}
