/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.views.components.gridboxes;

import java.util.List;

import thinwire.ui.GridBox;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.sweden.impl.ParliamentMember;
import com.hack23.cia.web.action.user.ParliamentMemberAction;

/**
 * The Class TopAbsenceGridBox.
 */
public class TopAbsenceGridBox extends AbstractParliamentMemberGridBox {

    /**
     * Instantiates a new top absence grid box.
     *
     * @param userSessionDTO the user session dto
     * @param currentList the current list
     */
    public TopAbsenceGridBox(final UserSessionDTO userSessionDTO,final List<ParliamentMember> currentList) {
        super(userSessionDTO,currentList);
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.views.gridboxes.AbstractParliamentMemberGridBox#
     * addGridBoxColumns()
     */
    @Override
    final void addGridBoxColumns() {
        this.getColumns().add(GridBoxColumnFactory.getRankHeader(getUserSessionDTO()));

        GridBox.Column absentHeader = new GridBox.Column();
        absentHeader.setName(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.ABSENCE_PERCENTAGE));
        this.getColumns().add(absentHeader);

        GridBox.Column absentOccassionsHeader = new GridBox.Column();
        absentOccassionsHeader.setName(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.ABSENT_OCCASSIONS));
        this.getColumns().add(absentOccassionsHeader);
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.web.views.AbstractTopListPanel#createRow(int,
     * com.hack23.cia.model.sweden.ParliamentMember)
     */
    @Override
    final Row createRow(final int rank, final ParliamentMember parliamentMember) {
        GridBox.Row row = new GridBox.Row(rank, Long.valueOf(parliamentMember.getParliamentMemberBallotRecord()
                .getPercentageAbsent()), parliamentMember.getParliamentMemberBallotRecord().getAbsentVotes(),
                parliamentMember.getParliamentMemberBallotRecord().getTotalVotes(), parliamentMember.getName(),
                parliamentMember.getParty(), parliamentMember
                        .getElectoralRegion(), parliamentMember.getParliamentMemberBallotRecord()
                        .getFirstVoteDate(), parliamentMember.getParliamentMemberBallotRecord().getLastVoteDate());
        row.setUserObject(new ParliamentMemberAction(parliamentMember.getId()));
        return row;
    }
}
