/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.views.components.gridboxes;

import java.util.List;

import thinwire.ui.GridBox;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.sweden.impl.Vote;
import com.hack23.cia.web.action.user.BallotAction;
import com.hack23.cia.web.common.BeanLocator;

/**
 * The Class VoteGridBox.
 */
public class VoteGridBox extends GridBox {

    /**
     * Instantiates a new vote grid box.
     *
     * @param userSessionDTO the user session dto
     * @param votes the votes
     */
    public VoteGridBox(final UserSessionDTO userSessionDTO,final List<Vote> votes) {
        super();
        this.setVisibleHeader(true);
        this.addActionListener(ACTION_CLICK, BeanLocator
                .getApplicationActionListener());

        GridBox.Column dateHeader = new GridBox.Column();
        dateHeader.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.DECISION_DATE));
        this.getColumns().add(dateHeader);

        GridBox.Column votePositionHeader = new GridBox.Column();
        votePositionHeader.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.VOTE_POSITION));
        this.getColumns().add(votePositionHeader);

        GridBox.Column winningSideHeader = new GridBox.Column();
        winningSideHeader.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.WINNING_SIDE));
        this.getColumns().add(winningSideHeader);

        GridBox.Column winningSideInPartyHeader = new GridBox.Column();
        winningSideInPartyHeader.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.WINNING_SIDE_IN_PARTY));
        this.getColumns().add(winningSideInPartyHeader);

        GridBox.Column commiteeReportHeader = new GridBox.Column();
        commiteeReportHeader.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.COMMITEE_REPORT));
        this.getColumns().add(commiteeReportHeader);

        GridBox.Column ballotHeader = new GridBox.Column();
        ballotHeader.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.BALLOT));
        this.getColumns().add(ballotHeader);

        for (Vote vote : votes) {
            GridBox.Row row = new GridBox.Row(vote.getDatum().toString(),
                    userSessionDTO.getLanguageResource(vote.getPosition()), userSessionDTO
                            .getLanguageResource(vote.getBallot().getBallotResult()
                                    .getWinningPosition()),
                    userSessionDTO.getLanguageResource(vote.getBallot().getPartyBallotResult(
                                    vote.getParliamentMember().getParty())
                            .getWinningPosition()), vote.getBallot()
                            .getCommiteeReport().getName(), vote.getBallot()
                            .getDescription());
            row.setUserObject(new BallotAction(vote.getBallot().getId()));
            this.getRows().add(row);
        }
    }

}
