/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.web.views.user;

import thinwire.ui.TabFolder;
import thinwire.ui.TabSheet;
import thinwire.ui.layout.TableLayout;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;


/**
 * The Class AbstractParliamentOperationPanel.
 */
public abstract class AbstractParliamentOperationPanel extends AbstractParliamentPanel {

	
	
	/** The user session dto. */
	private final UserSessionDTO userSessionDTO;

	/**
	 * Instantiates a new abstract parliament operation panel.
	 *
	 * @param userSessionDTO the user session dto
	 */
	protected AbstractParliamentOperationPanel(UserSessionDTO userSessionDTO) {
		this.userSessionDTO = userSessionDTO;
	}

	/**
	 * Creates the tab folder citizen operation.
	 *
	 * @return the tab sheet
	 */
	protected final TabSheet createTabFolderCitizenOperation() {
	    	  TabSheet tabSheet = new TabSheet();

	          tabSheet.setText(userSessionDTO
	                  .getLanguageResource(Agency.LanguageContentKey.CITIZEN_OPERATION));
	          tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
	                  // Widths
	                  { 0 } }, // Row Heights
	                  1, // Margin around edge of container
	                  5)); // Spacing between cells

	          TabFolder tabFolder = new TabFolder();
	          tabFolder.setLimit("0,0"); //$NON-NLS-1$

	          tabFolder.getChildren().add(
	                  createTabFolderGrading());
	          tabFolder.getChildren().add(
	                  createTabFolderForum());
	          tabFolder.getChildren().add(
	                  createTabFolderOpinions());
	          tabFolder.getChildren().add(
	                  createTabFolderShortComment());
	          tabFolder.getChildren().add(
	                  createTabFolderVote());
	          
	          tabFolder.setCurrentIndex(0);
	          tabSheet.getChildren().add(tabFolder);
	        
	        return tabSheet;
		}
	
	/**
	 * Creates the tab folder forum.
	 *
	 * @return the tab sheet
	 */
	private TabSheet createTabFolderForum() {     
		TabSheet tabSheet = new TabSheet();

	        tabSheet.setText(userSessionDTO
	                .getLanguageResource(Agency.LanguageContentKey.FORUM));
	        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
	                // Widths
	                { 0 } }, // Row Heights
	                1, // Margin around edge of container
	                5)); // Spacing between cells
	        
	        return tabSheet;
	}

	/**
	 * Creates the tab folder grading.
	 *
	 * @return the tab sheet
	 */
	private TabSheet createTabFolderGrading() {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.GRADING));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        
        return tabSheet;
	}

	/**
	 * Creates the tab folder opinions.
	 *
	 * @return the tab sheet
	 */
	private TabSheet createTabFolderOpinions() {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.OPINIONS));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        
        return tabSheet;
	}

    /**
     * Creates the tab folder short comment.
     *
     * @return the tab sheet
     */
	private TabSheet createTabFolderShortComment() {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.SHORT_COMMENT));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        
        return tabSheet;
	}

	/**
	 * Creates the tab folder vote.
	 *
	 * @return the tab sheet
	 */
	private TabSheet createTabFolderVote() {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.VOTE));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        
        return tabSheet;
	}

}
