/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.web.views.user;

import java.util.List;

import thinwire.ui.Button;
import thinwire.ui.Component;
import thinwire.ui.Label;
import thinwire.ui.Panel;
import thinwire.ui.layout.TableLayout;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.sweden.impl.CommitteeReport;
import com.hack23.cia.web.common.BeanLocator;

/**
 * The Class ActionBarPanel.
 */
public class ActionBarPanel extends Panel {

    /** The user session dto. */
    private final UserSessionDTO userSessionDTO;

    /**
     * Instantiates a new action bar panel.
     *
     * @param userSessionDTO the user session dto
     * @param filePath the file path
     * @param actionDescription the action description
     * @param userObject the user object
     * @param commiteeReports the commitee reports
     */
    public ActionBarPanel(final UserSessionDTO userSessionDTO,final String filePath,
            final String actionDescription, final Object userObject,
            final List<CommitteeReport> commiteeReports) {
        super();
        this.userSessionDTO = userSessionDTO;
        setLayout(new TableLayout(new double[][] { { 0 }, // Column Widths
                { 0, 0, 0, 0, 0, 0, 0, 0, 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        Button actionButton = new Button(actionDescription, filePath);
        actionButton.setLimit("0,0,1,1"); //$NON-NLS-1$
        actionButton.setUserObject(userObject);
        actionButton.addActionListener(Component.ACTION_CLICK, BeanLocator
                .getApplicationActionListener());

        Panel searchPanel = new SearchPanel(userSessionDTO);
        searchPanel.setLimit("0,1,1,2"); //$NON-NLS-1$

        Label treeViewDescription = new Label(
                userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.LAST_TEN_DECIDED_COMMITEE_REPORTS_DESCRIPTION));
        treeViewDescription.setWrapText(true);
        treeViewDescription.setLimit("0,3,1,1"); //$NON-NLS-1$

        Panel committeeReportsPanel = new CommitteeReportPanel(userSessionDTO,commiteeReports);

        committeeReportsPanel.setLimit("0,4,1,5"); //$NON-NLS-1$
        committeeReportsPanel.setUserObject(userObject);

        getChildren().add(actionButton);
        getChildren().add(searchPanel);
        getChildren().add(treeViewDescription);
        getChildren().add(committeeReportsPanel);
    }

}
