/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.web.views.user;

import java.util.List;

import thinwire.ui.Tree;
import thinwire.ui.Tree.Item;
import thinwire.ui.layout.TableLayout;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.sweden.impl.Ballot;
import com.hack23.cia.model.sweden.impl.CommitteeReport;
import com.hack23.cia.web.action.user.BallotAction;
import com.hack23.cia.web.action.user.CommitteeReportAction;
import com.hack23.cia.web.common.BeanLocator;

/**
 * The Class CommitteeReportPanel.
 */
public class CommitteeReportPanel extends AbstractParliamentPanel {

    /** The user session dto. */
    private final UserSessionDTO userSessionDTO;

    /**
     * Instantiates a new committee report panel.
     *
     * @param userSessionDTO the user session dto
     * @param commiteeReports the commitee reports
     */
    public CommitteeReportPanel(final UserSessionDTO userSessionDTO,final List<CommitteeReport> commiteeReports) {
        this.userSessionDTO = userSessionDTO;
        setLayout(new TableLayout(new double[][] { { 0 }, // Column Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        Tree globalPortalTree = createRootTree(commiteeReports);
        globalPortalTree.setLimit("0,0,1,1"); //$NON-NLS-1$
        getChildren().add(globalPortalTree);
    }

    /**
     * Creates the root tree.
     *
     * @param commiteeReports the commitee reports
     * @return the tree
     */
    private Tree createRootTree(final List<CommitteeReport> commiteeReports) {
        Tree tree = new Tree();
        tree.addActionListener(ACTION_CLICK, BeanLocator
                .getApplicationActionListener());
        tree.addActionListener(ACTION_DOUBLE_CLICK, BeanLocator
                .getApplicationActionListener());

        tree.setRootItemVisible(true);

        Tree.Item root = tree.getRootItem();
        root.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.LAST_TEN_DECIDED_COMMITEE_REPORTS));
        root.setExpanded(true);

        if (commiteeReports != null) {
            for (CommitteeReport commiteeReport : commiteeReports) {
                createTree(root, commiteeReport);
            }
        }
        return tree;
    }

    /**
     * Creates the tree.
     *
     * @param parent the parent
     * @param ballot the ballot
     */
    private void createTree(final Item parent, final Ballot ballot) {
        if (ballot != null) {
            Tree.Item ballotItem = new Tree.Item(ballot.getDescription());
            ballotItem.setUserObject(new BallotAction(ballot.getId()));
            parent.getChildren().add(ballotItem);
        }
    }

    /**
     * Creates the tree.
     *
     * @param parent the parent
     * @param commiteeReport the commitee report
     */
    private void createTree(final Item parent,
            final CommitteeReport commiteeReport) {
        if (commiteeReport != null) {
            Tree.Item commiteeReportItem = new Tree.Item(commiteeReport
                    .getName());
            commiteeReportItem.setUserObject(new CommitteeReportAction(
                    commiteeReport.getId()));
            parent.getChildren().add(commiteeReportItem);

            if (commiteeReport.getDecisionDate() != null) {
                Tree.Item datumItem = new Tree.Item(userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.DECISION_DATE)
                        + " " + commiteeReport.getDecisionDate().toString()); //$NON-NLS-1$
                commiteeReportItem.getChildren().add(datumItem);

                if (commiteeReport.getBallots().size() > 0) {
                    Tree.Item ballotItem = new Tree.Item(
                            userSessionDTO
                                    .getLanguageResource(Agency.LanguageContentKey.BALLOTS));
                    commiteeReportItem.getChildren().add(ballotItem);

                    for (Ballot ballot : commiteeReport.getBallots()) {
                        createTree(ballotItem, ballot);
                    }
                }
            }
        }
    }
}
