/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.views.user;

import thinwire.ui.TabFolder;
import thinwire.ui.TabSheet;
import thinwire.ui.WebBrowser;
import thinwire.ui.layout.TableLayout;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.ParliamentChart;
import com.hack23.cia.model.sweden.impl.CommitteeReport;
import com.hack23.cia.web.common.ImageConstants;
import com.hack23.cia.web.views.components.panels.ImagePanel;

/**
 * The Class CommitteeReportSummaryPanel.
 */
public class CommitteeReportSummaryPanel extends AbstractParliamentOperationPanel {

    /** The user session dto. */
    private final UserSessionDTO userSessionDTO;

	/**
	 * Instantiates a new committee report summary panel.
	 *
	 * @param userSessionDTO the user session dto
	 * @param commiteeReport the commitee report
	 */
    public CommitteeReportSummaryPanel(final UserSessionDTO userSessionDTO, final CommitteeReport commiteeReport) {
        super(userSessionDTO);
		this.userSessionDTO = userSessionDTO;
        setLayout(new TableLayout(new double[][] { { 0 }, // Column Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        final TabFolder tabFolder = createTabFolder(commiteeReport);
        
        tabFolder.getChildren().add(
                createTabFolderCharts(commiteeReport));
        tabFolder.getChildren().add(
                createTabFolderCitizenOperation());
        
        tabFolder.setLimit("0,0,1,1"); //$NON-NLS-1$
        getChildren().add(tabFolder);
    }

    /**
     * Creates the tab folder.
     *
     * @param commiteeReport the commitee report
     * @return the tab folder
     */
    private TabFolder createTabFolder(final CommitteeReport commiteeReport) {
        final TabFolder tabFolder = new TabFolder();

        if (commiteeReport.getHref() != null) {
            TabSheet homePageTab = createTabHomePage(commiteeReport);
            tabFolder.getChildren().add(homePageTab);
        }
        return tabFolder;
    }

	/**
	 * Creates the tab folder chart outcome.
	 *
	 * @param commiteeReport the commitee report
	 * @return the tab sheet
	 */
	private TabSheet createTabFolderChartOutcome(
			final CommitteeReport commiteeReport) {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.OUTCOME));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        ImagePanel imagePanel = new ImagePanel(ParliamentChart.getFileName(ParliamentChart.Outcome, commiteeReport, userSessionDTO.getUserSession().getLanguage()));
        imagePanel.setLimit("0,0");
        tabSheet.getChildren().add(imagePanel);
        
        return tabSheet;
	}
	
	/**
	 * Creates the tab folder chart political party behavior.
	 *
	 * @param commiteeReport the commitee report
	 * @return the tab sheet
	 */
	private TabSheet createTabFolderChartPoliticalPartyBehavior(
			final CommitteeReport commiteeReport) {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.POLITICAL_PARTY_BEHAVIOR));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        ImagePanel imagePanel = new ImagePanel(ParliamentChart.getFileName(ParliamentChart.PoliticalPartyBehavior, commiteeReport, userSessionDTO.getUserSession().getLanguage()));
        imagePanel.setLimit("0,0");
        tabSheet.getChildren().add(imagePanel);
        
        return tabSheet;
	}

	/**
	 * Creates the tab folder chart proffessional behavior.
	 *
	 * @param commiteeReport the commitee report
	 * @return the tab sheet
	 */
	private TabSheet createTabFolderChartProffessionalBehavior(final CommitteeReport commiteeReport) {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.PROFFESSIONAL_BEHAVIOR));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        ImagePanel imagePanel = new ImagePanel(ParliamentChart.getFileName(ParliamentChart.ProffessionalBehavior, commiteeReport, userSessionDTO.getUserSession().getLanguage()));
        imagePanel.setLimit("0,0");
        tabSheet.getChildren().add(imagePanel);
        
        return tabSheet;
	}

	/**
	 * Creates the tab folder charts.
	 *
	 * @param commiteeReport the commitee report
	 * @return the tab sheet
	 */
    private TabSheet createTabFolderCharts(final CommitteeReport commiteeReport) {
     	  TabSheet tabSheet = new TabSheet();

          tabSheet.setText(userSessionDTO
                  .getLanguageResource(Agency.LanguageContentKey.CHARTS));
          tabSheet.setImage(ImageConstants.CHART_IMAGE_SMALL);
          tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                  // Widths
                  { 0 } }, // Row Heights
                  1, // Margin around edge of container
                  5)); // Spacing between cells

          TabFolder tabFolder = new TabFolder();
          tabFolder.setLimit("0,0"); //$NON-NLS-1$

          tabFolder.getChildren().add(
                  createTabFolderChartSummary(commiteeReport));
          tabFolder.getChildren().add(
                  createTabFolderChartOutcome(commiteeReport));
          tabFolder.getChildren().add(
                  createTabFolderChartPoliticalPartyBehavior(commiteeReport));
          tabFolder.getChildren().add(
                  createTabFolderChartProffessionalBehavior(commiteeReport));
       
          
          tabFolder.setCurrentIndex(0);
          tabSheet.getChildren().add(tabFolder);
          return tabSheet;
	}


	/**
	 * Creates the tab folder chart summary.
	 *
	 * @param commiteeReport the commitee report
	 * @return the tab sheet
	 */
	private TabSheet createTabFolderChartSummary(
			final CommitteeReport commiteeReport) {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.SUMMARY));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        ImagePanel imagePanel = new ImagePanel(ParliamentChart.getFileName(ParliamentChart.Summary, commiteeReport, userSessionDTO.getUserSession().getLanguage()));
        imagePanel.setLimit("0,0");
        tabSheet.getChildren().add(imagePanel);
        
        return tabSheet;
	}

    /**
     * Creates the tab home page.
     *
     * @param commiteeReport the commitee report
     * @return the tab sheet
     */
    private TabSheet createTabHomePage(final CommitteeReport commiteeReport) {
        TabSheet homePage = new TabSheet();

        homePage.setText(commiteeReport.getName());

        homePage.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        final WebBrowser comp = new WebBrowser();
        comp.setLimit("0,0"); //$NON-NLS-1$
        comp.setLocation(commiteeReport.getHref());
        homePage.getChildren().add(comp);
        return homePage;
    }

}
